@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,7 +25,7 @@
 
 package test.javafx.binding;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.*;
 
 import java.util.Arrays;
 import java.util.Collection;
@@ -47,12 +47,10 @@ import javafx.beans.property.SimpleStringProperty;
 import javafx.beans.property.StringProperty;
 import javafx.beans.value.*;
 
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;;
 
-@RunWith(Parameterized.class)
 public class BindingsEqualsTest<T> {
 
     private static final float EPSILON_FLOAT = 1e-5f;
@@ -67,32 +65,31 @@ public class BindingsEqualsTest<T> {
         void check(T op1, T op2, BooleanBinding exp);
     }
 
-    private final ObservableValue op1;
-    private final ObservableValue op2;
-    private final Functions<T> func;
-    private final T[] v;
+    private  ObservableValue op1;
+    private  ObservableValue op2;
+    private  Functions<T> func;
+    private  T[] v;
     private InvalidationListenerMock observer;
 
-    public BindingsEqualsTest(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
-        this.op1 = op1;
-        this.op2 = op2;
-        this.func = func;
-        this.v = v;
-    }
-
     private static String makeSafe(String value) {
         return value == null? "" : value;
     }
 
-    @Before
-    public void setUp() {
+
+    private void setUp(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        this.op1 = op1;
+        this.op2 = op2;
+        this.func = func;
+        this.v = v;
         func.setOp1(v[0]);
         func.setOp2(v[1]);
         observer = new InvalidationListenerMock();
     }
 
-    @Test
-    public void test_Expression_Expression() {
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_Expression_Expression(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
         final BooleanBinding binding = func.generateExpressionExpression(op1, op2);
         binding.addListener(observer);
 
@@ -118,8 +115,10 @@ public class BindingsEqualsTest<T> {
         observer.check(binding, 1);
     }
 
-    @Test
-    public void test_Self() {
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_Self(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
         // using same FloatValue twice
         final BooleanBinding binding = func.generateExpressionExpression(op1, op1);
         binding.addListener(observer);
@@ -133,18 +132,24 @@ public class BindingsEqualsTest<T> {
         observer.check(binding, 1);
     }
 
-    @Test(expected=NullPointerException.class)
-    public void test_null_Expression() {
-        func.generateExpressionExpression(null, op1);
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_null_Expression(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
+        assertThrows(NullPointerException.class, () -> func.generateExpressionExpression(null, op1));
     }
 
-    @Test(expected=NullPointerException.class)
-    public void test_Expression_null() {
-        func.generateExpressionExpression(op1, null);
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_Expression_null(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
+        assertThrows(NullPointerException.class, () -> func.generateExpressionExpression(op1, null));
     }
 
-    @Test
-    public void test_Expression_Primitive() {
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_Expression_Primitive(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
         final BooleanBinding binding = func.generateExpressionPrimitive(op1, v[1]);
         binding.addListener(observer);
 
@@ -164,13 +169,17 @@ public class BindingsEqualsTest<T> {
         observer.check(binding, 1);
     }
 
-    @Test(expected=NullPointerException.class)
-    public void test_null_Primitive() {
-        func.generateExpressionPrimitive(null, v[0]);
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_null_Primitive(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
+        assertThrows(NullPointerException.class, () -> func.generateExpressionPrimitive(null, v[0]));
     }
 
-    @Test
-    public void test_Primitive_Expression() {
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_Primitive_Expression(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
         final BooleanBinding binding = func.generatePrimitiveExpression(v[1], op1);
         binding.addListener(observer);
 
@@ -190,12 +199,13 @@ public class BindingsEqualsTest<T> {
         observer.check(binding, 1);
     }
 
-    @Test(expected=NullPointerException.class)
-    public void test_Primitive_null() {
-        func.generatePrimitiveExpression(v[0], null);
+    @ParameterizedTest
+    @MethodSource("parameters")
+    public void test_Primitive_null(ObservableValue op1, ObservableValue op2, Functions<T> func, T... v) {
+        setUp(op1, op2, func, v);
+        assertThrows(NullPointerException.class, () -> func.generatePrimitiveExpression(v[0], null));
     }
 
-    @Parameterized.Parameters
     public static Collection<Object[]> parameters() {
         final FloatProperty float1 = new SimpleFloatProperty();
         final FloatProperty float2 = new SimpleFloatProperty();
