@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,11 +33,11 @@ import javafx.beans.property.SimpleListProperty;
 import javafx.collections.FXCollections;
 import javafx.collections.ObservableList;
 import test.com.sun.javafx.binding.ErrorLoggingUtiltity;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
-import static org.junit.Assert.*;
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  */
@@ -54,12 +54,12 @@ public class BindingsListTest {
     private ObservableList<Object> list2;
     private IntegerProperty index;
 
-    @BeforeClass
+    @BeforeAll
     public static void setUpClass() {
         ErrorLoggingUtiltity.reset();
     }
 
-    @Before
+    @BeforeEach
     public void setUp() {
         property = new SimpleListProperty<>();
         list1 = FXCollections.<Object>observableArrayList(data1, data2);
@@ -85,11 +85,14 @@ public class BindingsListTest {
         assertEquals(0, size.get());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testSize_Null() {
-        Bindings.size((ObservableList<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.size((ObservableList<Object>) null);
+        });
     }
 
+
     @Test
     public void testIsEmpty() {
         final BooleanBinding empty = Bindings.isEmpty(property);
@@ -108,11 +111,14 @@ public class BindingsListTest {
         assertTrue(empty.get());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIsEmpty_Null() {
-        Bindings.isEmpty((ObservableList<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.isEmpty((ObservableList<Object>) null);
+        });
     }
 
+
     @Test
     public void testIsNotEmpty() {
         final BooleanBinding notEmpty = Bindings.isNotEmpty(property);
@@ -131,11 +137,14 @@ public class BindingsListTest {
         assertFalse(notEmpty.get());
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIsNotEmpty_Null() {
-        Bindings.isNotEmpty((ObservableList<Object>) null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.isNotEmpty((ObservableList<Object>) null);
+        });
     }
 
+
     @Test
     public void testValueAt_Constant() {
         final ObjectBinding<Object> binding0 = Bindings.valueAt(property, 0);
@@ -187,16 +196,22 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testValueAt_Constant_Null() {
-        Bindings.valueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.valueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testValueAt_Constant_NegativeIndex() {
-        Bindings.valueAt(property, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            Bindings.valueAt(property, -1);
+        });
     }
 
+
     @Test
     public void testValueAt_Variable() {
         final ObjectBinding<Object> binding = Bindings.valueAt(property, index);
@@ -260,16 +275,22 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testValueAt_Variable_Null() {
-        Bindings.valueAt((ObservableList<Object>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.valueAt((ObservableList<Object>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testValueAt_Variable_NullIndex() {
-        Bindings.valueAt(property, null);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.valueAt(property, null);
+        });
     }
 
+
     @Test
     public void testBooleanValueAt_Constant() {
         final boolean defaultData = false;
@@ -328,17 +349,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testBooleanValueAt_Constant_Null() {
-        Bindings.booleanValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.booleanValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testBooleanValueAt_Constant_NegativeIndex() {
-        final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
-        Bindings.booleanValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
+            Bindings.booleanValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testBooleanValueAt_Variable() {
         final boolean defaultData = false;
@@ -420,17 +447,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testBooleanValueAt_Variable_Null() {
-        Bindings.booleanValueAt((ObservableList<Boolean>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.booleanValueAt((ObservableList<Boolean>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testBooleanValueAt_Variable_NullIndex() {
-        final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
-        Bindings.booleanValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Boolean> localProperty = new SimpleListProperty<>();
+            Bindings.booleanValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testDoubleValueAt_Constant() {
         final double defaultData = 0.0;
@@ -489,17 +522,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testDoubleValueAt_Constant_Null() {
-        Bindings.doubleValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.doubleValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testDoubleValueAt_Constant_NegativeIndex() {
-        final ListProperty<Double> localProperty = new SimpleListProperty<>();
-        Bindings.doubleValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Double> localProperty = new SimpleListProperty<>();
+            Bindings.doubleValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testDoubleValueAt_Variable() {
         final double defaultData = 0.0;
@@ -581,17 +620,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testDoubleValueAt_Variable_Null() {
-        Bindings.doubleValueAt((ObservableList<Double>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.doubleValueAt((ObservableList<Double>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testDoubleValueAt_Variable_NullIndex() {
-        final ListProperty<Double> localProperty = new SimpleListProperty<>();
-        Bindings.doubleValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Double> localProperty = new SimpleListProperty<>();
+            Bindings.doubleValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testFloatValueAt_Constant() {
         final float defaultData = 0.0f;
@@ -650,17 +695,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testFloatValueAt_Constant_Null() {
-        Bindings.floatValueAt((ObservableList) null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.floatValueAt((ObservableList) null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testFloatValueAt_Constant_NegativeIndex() {
-        final ListProperty<Float> localProperty = new SimpleListProperty<>();
-        Bindings.floatValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Float> localProperty = new SimpleListProperty<>();
+            Bindings.floatValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testFloatValueAt_Variable() {
         final float defaultData = 0.0f;
@@ -742,17 +793,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testFloatValueAt_Variable_Null() {
-        Bindings.floatValueAt((ObservableList<Float>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.floatValueAt((ObservableList<Float>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testFloatValueAt_Variable_NullIndex() {
-        final ListProperty<Float> localProperty = new SimpleListProperty<>();
-        Bindings.floatValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Float> localProperty = new SimpleListProperty<>();
+            Bindings.floatValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testIntegerValueAt_Constant() {
         final int defaultData = 0;
@@ -811,17 +868,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIntegerValueAt_Constant_Null() {
-        Bindings.integerValueAt((ObservableList) null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.integerValueAt((ObservableList) null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testIntegerValueAt_Constant_NegativeIndex() {
-        final ListProperty<Integer> localProperty = new SimpleListProperty<>();
-        Bindings.integerValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Integer> localProperty = new SimpleListProperty<>();
+            Bindings.integerValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testIntegerValueAt_Variable() {
         final int defaultData = 0;
@@ -903,17 +966,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testIntegerValueAt_Variable_Null() {
-        Bindings.integerValueAt((ObservableList<Integer>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.integerValueAt((ObservableList<Integer>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testIntegerValueAt_Variable_NullIndex() {
-        final ListProperty<Integer> localProperty = new SimpleListProperty<>();
-        Bindings.integerValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Integer> localProperty = new SimpleListProperty<>();
+            Bindings.integerValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testLongValueAt_Constant() {
         final long defaultData = 0L;
@@ -972,17 +1041,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testLongValueAt_Constant_Null() {
-        Bindings.longValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.longValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testLongValueAt_Constant_NegativeIndex() {
-        final ListProperty<Long> localProperty = new SimpleListProperty<>();
-        Bindings.longValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<Long> localProperty = new SimpleListProperty<>();
+            Bindings.longValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testLongValueAt_Variable() {
         final long defaultData = 0;
@@ -1064,17 +1139,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testLongValueAt_Variable_Null() {
-        Bindings.longValueAt((ObservableList<Long>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.longValueAt((ObservableList<Long>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testLongValueAt_Variable_NullIndex() {
-        final ListProperty<Long> localProperty = new SimpleListProperty<>();
-        Bindings.longValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<Long> localProperty = new SimpleListProperty<>();
+            Bindings.longValueAt(localProperty, null);
+        });
     }
 
+
     @Test
     public void testStringValueAt_Constant() {
         final String defaultData = null;
@@ -1133,17 +1214,23 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testStringValueAt_Constant_Null() {
-        Bindings.stringValueAt(null, 0);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.stringValueAt(null, 0);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
+
+    @Test
     public void testStringValueAt_Constant_NegativeIndex() {
-        final ListProperty<String> localProperty = new SimpleListProperty<>();
-        Bindings.stringValueAt(localProperty, -1);
+        assertThrows(IllegalArgumentException.class, () -> {
+            final ListProperty<String> localProperty = new SimpleListProperty<>();
+            Bindings.stringValueAt(localProperty, -1);
+        });
     }
 
+
     @Test
     public void testStringValueAt_Variable() {
         final String defaultData = null;
@@ -1214,16 +1301,19 @@ public class BindingsListTest {
         ErrorLoggingUtiltity.checkFine(IndexOutOfBoundsException.class);
     }
 
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testStringValueAt_Variable_Null() {
-        Bindings.stringValueAt((ObservableList<String>)null, index);
+        assertThrows(NullPointerException.class, () -> {
+            Bindings.stringValueAt((ObservableList<String>)null, index);
+        });
     }
 
-    @Test(expected = NullPointerException.class)
+
+    @Test
     public void testStringValueAt_Variable_NullIndex() {
-        final ListProperty<String> localProperty = new SimpleListProperty<>();
-        Bindings.stringValueAt(localProperty, null);
+        assertThrows(NullPointerException.class, () -> {
+            final ListProperty<String> localProperty = new SimpleListProperty<>();
+            Bindings.stringValueAt(localProperty, null);
+        });
     }
-
-
 }
