@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,7 +24,7 @@
  */
 package test.com.sun.javafx.scene.control.inputmap;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Thoughts / Considerations (search for [1], etc in comments below):
@@ -289,15 +289,15 @@ public class InputMapTest {
 //    }
 //
 //    // TODO [1], [2]
-////    @Test public void testLookup_mouseMapping_mappingThatIsInstalled_usingAnyEventType() {
-////        InputMap<?> map = createDummyInputMap();
-////        InputMap.MouseMapping mapping = new InputMap.MouseMapping(MouseEvent.MOUSE_PRESSED, e -> { });
-////        map.getMappings().add(mapping);
-////
-////        Optional<InputMap.Mapping<?>> returnedMapping = map.lookupMapping(MouseEvent.ANY);
-////        assertNotNull(returnedMapping);
-////        assertTrue(returnedMapping.isPresent());
-////    }
+//--    @Test public void testLookup_mouseMapping_mappingThatIsInstalled_usingAnyEventType() {
+//--        InputMap<?> map = createDummyInputMap();
+//--        InputMap.MouseMapping mapping = new InputMap.MouseMapping(MouseEvent.MOUSE_PRESSED, e -> { });
+//--        map.getMappings().add(mapping);
+//--
+//--        Optional<InputMap.Mapping<?>> returnedMapping = map.lookupMapping(MouseEvent.ANY);
+//--        assertNotNull(returnedMapping);
+//--        assertTrue(returnedMapping.isPresent());
+//--    }
 //
 //    @Test public void testLookup_keyMapping_mappingThatIsInstalledOnChildMap() {
 //        Rectangle dummy = new Rectangle();
