@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,19 +25,23 @@
 
 package test.javafx.scene.control;
 
-import javafx.scene.control.skin.TooltipSkin;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static test.com.sun.javafx.scene.control.infrastructure.ControlSkinFactory.attemptGC;
+import java.lang.ref.WeakReference;
 import javafx.beans.property.DoubleProperty;
 import javafx.beans.property.DoublePropertyBase;
 import javafx.beans.property.SimpleStringProperty;
-
 import javafx.scene.Node;
 import javafx.scene.control.PopupControl;
 import javafx.scene.control.Skin;
 import javafx.scene.control.Tooltip;
-import org.junit.Before;
-import org.junit.Test;
-
-import static org.junit.Assert.*;
+import javafx.scene.control.skin.TooltipSkin;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  *
@@ -52,7 +56,8 @@ public class PopupControlTest {
         @Override public C getSkinnable()   { return null; }
     }
 
-    @Before public void setup() {
+    @BeforeEach
+    public void setup() {
         popup = new PopupControl();
     }
 
@@ -650,4 +655,28 @@ public class PopupControlTest {
 
     //TODO: test computePref____ methods
 
+    /**
+     * Set a skin -> set another instance of the same skin (class).
+     */
+    @Test
+    public void testMemoryLeakSameSkinClass() {
+        popup.setSkin(new PopupControlSkin<>());
+        Skin<?> skin = popup.getSkin();
+        popup.setSkin(new PopupControlSkin<>());
+
+        WeakReference<?> weakRef = new WeakReference<>(skin);
+        skin = null;
+        attemptGC(weakRef);
+        assertNull(weakRef.get(), "Unused Skin must be gc'ed");
+    }
+
+    @Test
+    public void testSetSkinOfSameClass() {
+        popup.setSkin(new PopupControlSkin<>());
+        Skin<?> oldSkin = popup.getSkin();
+        popup.setSkin(new PopupControlSkin<>());
+        Skin<?> newSkin = popup.getSkin();
+
+        assertNotEquals(oldSkin, newSkin, "New skin was not set");
+    }
 }
