@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,16 +25,19 @@
 
 package com.sun.javafx.text;
 
-
-import javafx.scene.shape.LineTo;
-import javafx.scene.shape.MoveTo;
+import java.text.Bidi;
+import java.text.BreakIterator;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Hashtable;
+import java.util.concurrent.atomic.AtomicBoolean;
+import javafx.scene.layout.Region;
 import javafx.scene.shape.PathElement;
 import com.sun.javafx.font.CharToGlyphMapper;
 import com.sun.javafx.font.FontResource;
 import com.sun.javafx.font.FontStrike;
 import com.sun.javafx.font.Metrics;
 import com.sun.javafx.font.PGFont;
-import com.sun.javafx.font.PrismFontFactory;
 import com.sun.javafx.geom.BaseBounds;
 import com.sun.javafx.geom.Path2D;
 import com.sun.javafx.geom.Point2D;
@@ -44,14 +47,14 @@ import com.sun.javafx.geom.Shape;
 import com.sun.javafx.geom.transform.BaseTransform;
 import com.sun.javafx.geom.transform.Translate2D;
 import com.sun.javafx.scene.text.GlyphList;
+import com.sun.javafx.scene.text.TabAdvancePolicy;
 import com.sun.javafx.scene.text.TextLayout;
+import com.sun.javafx.scene.text.TextLine;
 import com.sun.javafx.scene.text.TextSpan;
-import java.text.Bidi;
-import java.text.BreakIterator;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Hashtable;
 
+/**
+ * Prism TextLayout
+ */
 public class PrismTextLayout implements TextLayout {
     private static final BaseTransform IDENTITY = BaseTransform.IDENTITY_TRANSFORM;
     private static final int X_MIN_INDEX = 0;
@@ -63,14 +66,14 @@ public class PrismTextLayout implements TextLayout {
     private static final Object  CACHE_SIZE_LOCK = new Object();
     private static int cacheSize = 0;
     private static final int MAX_STRING_SIZE = 256;
-    private static final int MAX_CACHE_SIZE = PrismFontFactory.cacheLayoutSize;
 
+    private final int maxCacheSize;
     private char[] text;
     private TextSpan[] spans;   /* Rich text  (null for single font text) */
     private PGFont font;        /* Single font text (null for rich text) */
     private FontStrike strike;  /* cached strike of font (identity) */
     private Integer cacheKey;
-    private TextLine[] lines;
+    private PrismTextLine[] lines;
     private TextRun[] runs;
     private int runCount;
     private BaseBounds logicalBounds;
@@ -80,9 +83,10 @@ public class PrismTextLayout implements TextLayout {
     private LayoutCache layoutCache;
     private Shape shape;
     private int flags;
-    private int tabSize = DEFAULT_TAB_SIZE;
+    private TabAdvancePolicy tabAdvancePolicy;
 
-    public PrismTextLayout() {
+    public PrismTextLayout(int maxCacheSize) {
+        this.maxCacheSize = maxCacheSize;
         logicalBounds = new RectBounds();
         flags = ALIGN_LEFT;
     }
@@ -139,7 +143,7 @@ public class PrismTextLayout implements TextLayout {
         this.font = (PGFont)font;
         this.strike = ((PGFont)font).getStrike(IDENTITY);
         this.text = text.toCharArray();
-        if (MAX_CACHE_SIZE > 0) {
+        if (maxCacheSize > 0) {
             int length = text.length();
             if (0 < length && length <= MAX_STRING_SIZE) {
                 cacheKey = text.hashCode() * strike.hashCode();
@@ -232,7 +236,7 @@ public class PrismTextLayout implements TextLayout {
     }
 
     @Override
-    public com.sun.javafx.scene.text.TextLine[] getLines() {
+    public TextLine[] getLines() {
         ensureLayout();
         return lines;
     }
@@ -266,7 +270,7 @@ public class PrismTextLayout implements TextLayout {
         float bottom = Float.NEGATIVE_INFINITY;
         if (filter != null) {
             for (int i = 0; i < lines.length; i++) {
-                TextLine line = lines[i];
+                PrismTextLine line = lines[i];
                 TextRun[] lineRuns = line.getRuns();
                 for (int j = 0; j < lineRuns.length; j++) {
                     TextRun run = lineRuns[j];
@@ -292,7 +296,7 @@ public class PrismTextLayout implements TextLayout {
         } else {
             top = bottom = 0;
             for (int i = 0; i < lines.length; i++) {
-                TextLine line = lines[i];
+                PrismTextLine line = lines[i];
                 RectBounds lineBounds = line.getBounds();
                 float lineLeft = lineBounds.getMinX() + line.getLeftSideBearing();
                 if (lineLeft < left) left = lineLeft;
@@ -311,21 +315,20 @@ public class PrismTextLayout implements TextLayout {
     }
 
     @Override
-    public PathElement[] getCaretShape(int offset, boolean isLeading,
-                                       float x, float y) {
+    public TextLayout.CaretGeometry getCaretGeometry(int offset, boolean isLeading) {
         ensureLayout();
         int lineIndex = 0;
         int lineCount = getLineCount();
         while (lineIndex < lineCount - 1) {
-            TextLine line = lines[lineIndex];
+            PrismTextLine line = lines[lineIndex];
             int lineEnd = line.getStart() + line.getLength();
             if (lineEnd > offset) break;
             lineIndex++;
         }
-        int sliptCaretOffset = -1;
+        int splitCaretOffset = -1;
         int level = 0;
         float lineX = 0, lineY = 0, lineHeight = 0;
-        TextLine line = lines[lineIndex];
+        PrismTextLine line = lines[lineIndex];
         TextRun[] runs = line.getRuns();
         int runCount = runs.length;
         int runIndex = -1;
@@ -351,13 +354,13 @@ public class PrismTextLayout implements TextLayout {
             if (isLeading) {
                 if (runIndex > 0 && offset == runStart) {
                     level = run.getLevel();
-                    sliptCaretOffset = offset - 1;
+                    splitCaretOffset = offset - 1;
                 }
             } else {
                 int runEnd = run.getEnd();
                 if (runIndex + 1 < runs.length && offset + 1 == runEnd) {
                     level = run.getLevel();
-                    sliptCaretOffset = offset + 1;
+                    splitCaretOffset = offset + 1;
                 }
             }
         } else {
@@ -383,14 +386,13 @@ public class PrismTextLayout implements TextLayout {
         if (isMirrored()) {
             lineX = getMirroringWidth() - lineX;
         }
-        lineX += x;
-        lineY += y;
-        if (sliptCaretOffset != -1) {
+
+        if (splitCaretOffset != -1) {
             for (int i = 0; i < runs.length; i++) {
                 TextRun run = runs[i];
                 int runStart = run.getStart();
                 int runEnd = run.getEnd();
-                if (runStart <= sliptCaretOffset && sliptCaretOffset < runEnd) {
+                if (runStart <= splitCaretOffset && splitCaretOffset < runEnd) {
                     if ((run.getLevel() & 1) != (level & 1)) {
                         Point2D location = run.getLocation();
                         float lineX2 = location.x;
@@ -402,21 +404,23 @@ public class PrismTextLayout implements TextLayout {
                         if (isMirrored()) {
                             lineX2 = getMirroringWidth() - lineX2;
                         }
-                        lineX2 += x;
-                        PathElement[] result = new PathElement[4];
-                        result[0] = new MoveTo(lineX, lineY);
-                        result[1] = new LineTo(lineX, lineY + lineHeight / 2);
-                        result[2] = new MoveTo(lineX2, lineY + lineHeight / 2);
-                        result[3] = new LineTo(lineX2, lineY + lineHeight);
-                        return result;
+                        // split caret
+                        return new TextLayout.CaretGeometry.Split(
+                            lineX,
+                            lineY,
+                            lineX2,
+                            lineHeight
+                        );
                     }
                 }
             }
         }
-        PathElement[] result = new PathElement[2];
-        result[0] = new MoveTo(lineX, lineY);
-        result[1] = new LineTo(lineX, lineY + lineHeight);
-        return result;
+        // regular caret
+        return new TextLayout.CaretGeometry.Single(
+            lineX,
+            lineY,
+            lineHeight
+        );
     }
 
     @Override
@@ -431,27 +435,27 @@ public class PrismTextLayout implements TextLayout {
             charIndex = getCharCount();
             insertionIndex = charIndex + 1;
         } else {
-            if (isMirrored()) {
-                x = getMirroringWidth() - x;
-            }
-            TextLine line = lines[lineIndex];
+            PrismTextLine line = lines[lineIndex];
             TextRun[] runs = line.getRuns();
             RectBounds bounds = line.getBounds();
             TextRun run = null;
             x -= bounds.getMinX();
-            //TODO binary search
             for (int i = 0; i < runs.length; i++) {
                 run = runs[i];
-                if (x < run.getWidth()) break;
+                if (x < run.getWidth()) {
+                    break;
+                }
                 if (i + 1 < runs.length) {
-                    if (runs[i + 1].isLinebreak()) break;
+                    if (runs[i + 1].isLinebreak()) {
+                        break;
+                    }
                     x -= run.getWidth();
                 }
             }
             if (run != null) {
-                int[] trailing = new int[1];
+                AtomicBoolean trailing = new AtomicBoolean();
                 charIndex = run.getStart() + run.getOffsetAtX(x, trailing);
-                leading = (trailing[0] == 0);
+                leading = !trailing.get();
 
                 insertionIndex = charIndex;
                 if (getText() != null && insertionIndex < getText().length) {
@@ -479,15 +483,14 @@ public class PrismTextLayout implements TextLayout {
     }
 
     @Override
-    public PathElement[] getRange(int start, int end, int type,
-                                  float x, float y) {
+    public void getRange(int start, int end, int type, GeometryCallback client) {
         ensureLayout();
         int lineCount = getLineCount();
         ArrayList<PathElement> result = new ArrayList<>();
         float lineY = 0;
 
         for  (int lineIndex = 0; lineIndex < lineCount; lineIndex++) {
-            TextLine line = lines[lineIndex];
+            PrismTextLine line = lines[lineIndex];
             RectBounds lineBounds = line.getBounds();
             int lineStart = line.getStart();
             if (lineStart >= end) break;
@@ -576,11 +579,7 @@ public class PrismTextLayout implements TextLayout {
                                 l = width - l;
                                 r = width - r;
                             }
-                            result.add(new MoveTo(x + l,  y + top));
-                            result.add(new LineTo(x + r, y + top));
-                            result.add(new LineTo(x + r, y + bottom));
-                            result.add(new LineTo(x + l,  y + bottom));
-                            result.add(new LineTo(x + l,  y + top));
+                            client.addRectangle(l, top, r, bottom);
                         }
                         left = runLeft;
                         right = runRight;
@@ -593,11 +592,7 @@ public class PrismTextLayout implements TextLayout {
                             l = width - l;
                             r = width - r;
                         }
-                        result.add(new MoveTo(x + l,  y + top));
-                        result.add(new LineTo(x + r, y + top));
-                        result.add(new LineTo(x + r, y + bottom));
-                        result.add(new LineTo(x + l,  y + bottom));
-                        result.add(new LineTo(x + l,  y + top));
+                        client.addRectangle(l, top, r, bottom);
                     }
                 }
                 lineX += runWidth;
@@ -605,7 +600,6 @@ public class PrismTextLayout implements TextLayout {
             }
             lineY += lineBounds.getHeight() + spacing;
         }
-        return result.toArray(new PathElement[result.size()]);
     }
 
     @Override
@@ -628,7 +622,7 @@ public class PrismTextLayout implements TextLayout {
             firstBaseline = -lines[0].getBounds().getMinY();
         }
         for (int i = 0; i < lines.length; i++) {
-            TextLine line = lines[i];
+            PrismTextLine line = lines[i];
             TextRun[] runs = line.getRuns();
             RectBounds bounds = line.getBounds();
             float baseline = -bounds.getMinY();
@@ -684,12 +678,13 @@ public class PrismTextLayout implements TextLayout {
     }
 
     @Override
-    public boolean setTabSize(int spaces) {
-        if (spaces < 1) {
-            spaces = 1;
+    public boolean setTabAdvancePolicy(int tabSize, TabAdvancePolicy policy) {
+        if (policy == null) {
+            float spaceAdvance = getSpaceAdvance();
+            policy = new FixedTabAdvancePolicy(tabSize, spaceAdvance);
         }
-        if (tabSize != spaces) {
-            tabSize = spaces;
+        if (tabAdvancePolicy == null || (!tabAdvancePolicy.equals(policy))) {
+            tabAdvancePolicy = policy;
             relayout();
             return true;
         }
@@ -705,11 +700,16 @@ public class PrismTextLayout implements TextLayout {
     private int getLineIndex(float y) {
         int index = 0;
         float bottom = 0;
+
         int lineCount = getLineCount();
         while (index < lineCount) {
             bottom += lines[index].getBounds().getHeight() + spacing;
-            if (index + 1 == lineCount) bottom -= lines[index].getLeading();
-            if (bottom > y) break;
+            if (index + 1 == lineCount) {
+                bottom -= lines[index].getLeading();
+            }
+            if (bottom > y) {
+                break;
+            }
             index++;
         }
         return index;
@@ -815,7 +815,7 @@ public class PrismTextLayout implements TextLayout {
             int count = Math.max(4, Math.min(chars.length / 16, 16));
             runs = new TextRun[count];
         }
-        GlyphLayout layout = GlyphLayout.getInstance();
+        GlyphLayout layout = glyphLayout();
         flags = layout.breakRuns(this, chars, flags);
         layout.dispose();
         for (int j = runCount; j < runs.length; j++) {
@@ -823,6 +823,10 @@ public class PrismTextLayout implements TextLayout {
         }
     }
 
+    protected GlyphLayout glyphLayout() {
+        return GlyphLayoutManager.getInstance();
+    }
+
     private void shape(TextRun run, char[] chars, GlyphLayout layout) {
         FontStrike strike;
         PGFont font;
@@ -926,8 +930,11 @@ public class PrismTextLayout implements TextLayout {
         }
     }
 
-    private TextLine createLine(int start, int end, int startOffset) {
+    private PrismTextLine createLine(int start, int end, int startOffset, float collapsedSpaceWidth) {
         int count = end - start + 1;
+
+        assert count > 0 : "number of TextRuns in a TextLine cannot be less than one: " + count;
+
         TextRun[] lineRuns = new TextRun[count];
         if (start < runCount) {
             System.arraycopy(runs, start, lineRuns, 0, count);
@@ -944,12 +951,43 @@ public class PrismTextLayout implements TextLayout {
             leading = Math.max(leading, run.getLeading());
             length += run.getLength();
         }
+
+        width -= collapsedSpaceWidth;
+
         if (width > layoutWidth) layoutWidth = width;
-        return new TextLine(startOffset, length, lineRuns,
-                            width, ascent, descent, leading);
+        return new PrismTextLine(startOffset, length, lineRuns, width, ascent, descent, leading);
     }
 
-    private void reorderLine(TextLine line) {
+    /**
+     * Computes the size of the white space trailing a given run.
+     *
+     * @param run the run to compute trailing space width for, cannot be {@code null}
+     * @return the X size of the white space trailing the run
+     */
+    private float computeTrailingSpaceWidth(TextRun run) {
+        float trailingSpaceWidth = 0;
+        char[] chars = getText();
+
+        /*
+         * As the loop below exits when encountering a non-white space character,
+         * testing each trailing glyph in turn for white space is safe, as white
+         * space is always represented with only a single glyph:
+         */
+
+        for (int i = run.getGlyphCount() - 1; i >= 0; i--) {
+            int textOffset = run.getStart() + run.getCharOffset(i);
+
+            if (!Character.isWhitespace(chars[textOffset])) {
+                break;
+            }
+
+            trailingSpaceWidth += run.getAdvance(i);
+        }
+
+        return trailingSpaceWidth;
+    }
+
+    private void reorderLine(PrismTextLine line) {
         TextRun[] runs = line.getRuns();
         int length = runs.length;
         if (length > 0 && runs[length - 1].isLinebreak()) {
@@ -1036,25 +1074,111 @@ public class PrismTextLayout implements TextLayout {
         }
     }
 
-    private float getTabAdvance() {
-        float spaceAdvance = 0;
+    private float getSpaceAdvance() {
         if (spans != null) {
-            /* Rich text case - use the first font (for now) */
+            // TextFlow case - use the first font
             for (int i = 0; i < spans.length; i++) {
                 TextSpan span = spans[i];
                 PGFont font = (PGFont)span.getFont();
                 if (font != null) {
                     FontStrike strike = font.getStrike(IDENTITY);
-                    spaceAdvance = strike.getCharAdvance(' ');
-                    break;
+                    return strike.getCharAdvance(' ');
                 }
             }
+            return 0.0f;
         } else {
-            spaceAdvance = strike.getCharAdvance(' ');
+            return strike.getCharAdvance(' ');
         }
-        return tabSize * spaceAdvance;
     }
 
+    /*
+     * The way JavaFX lays out text:
+     *
+     * JavaFX distinguishes between soft wraps and hard wraps. Soft wraps
+     * occur when a wrap width has been set and the text requires wrapping
+     * to stay within the set wrap width. Hard wraps are explicitly part of
+     * the text in the form of line feeds (LF) and carriage returns (CR).
+     * Hard wrapping considers a singular LF or CR, or the combination of
+     * CR+LF (or LF+CR) as a single wrap location. Hard wrapping also occurs
+     * between TextSpans when multiple TextSpans were supplied (for wrapping
+     * purposes, there is no difference between two TextSpans and a single
+     * TextSpan where the text was concatenated with a line break in between).
+     *
+     * Soft wrapping occurs when a wrap width has been set. This occurs at
+     * the first character that does not fit.
+     *
+     * - If that character is not a white space, the break is set immediately
+     *   after the first white space encountered before that character
+     *   - If there is no white space before the preferred break character, the
+     *     break is done at the first character that does not fit (the wrap
+     *     then occurs in the middle of a (long) word)
+     * - If the preferred break character is white space, and it is followed by
+     *   more white space, the break is moved to the end of the white space (thus
+     *   a break in white space always occurs at first non white space character
+     *   following a white space sequence)
+     *
+     * White space collapsing:
+     *
+     * Only white space that is present at soft wrapped locations is collapsed to
+     * zero. Any other white space is preserved. This includes white space between
+     * words, leading and trailing white space, and white space around hard wrapped
+     * locations.
+     *
+     * Alignment:
+     *
+     * The alignment calculation only looks at the width of all the significant
+     * characters in each line. Significant characters are any non white space
+     * characters and any white space that has been preserved (white space that wasn't
+     * collapsed due to soft wrapping).
+     *
+     * Alignment does not take text effects, such as strike through and underline, into
+     * account. This means that such effects can appear unaligned. Trailing spaces at a
+     * soft wrap location (that are underlined for example), may show the underline go
+     * outside the logical bounds of the text.
+     *
+     * Example, where <SW> indicates a soft wrap location, and <LF> is a line feed:
+     *
+     *     "   The   quick <SW>brown fox jumps <SW> over the <LF> lazy dog   "
+     *
+     * Would be rendered as (left aligned):
+     *
+     *     "   The   quick"
+     *     "brown fox jumps"
+     *     "over the "
+     *     " lazy dog   "
+     *
+     * The alignment calculation uses the above bounds indicated by the double
+     * quotes, and so right aligned text would look like:
+     *
+     *      "   The   quick"
+     *     "brown fox jumps"
+     *           "over the "
+     *        " lazy dog   "
+     *
+     * Note that only the white space at the soft wrap locations is collapsed.
+     * In all other locations the space was preserved (the space between words
+     * where no soft wrap occurred, the leading and trailing space, and the
+     * space around the hard wrapped location).
+     *
+     * Text effects have no effect on the alignment, and so with underlining on
+     * the right aligned text would look like:
+     *
+     *      "___The___quick_"     (one collapsed space becomes visible here)
+     *     "brown_fox_jumps__"    (two collapsed spaces become visible here)
+     *           "over_the_"
+     *        "_lazy_dog___"
+     *
+     * Note that text alignment has not changed at all, but the bounds are exceeded
+     * in some locations to allow for the underline. Controls displaying such texts
+     * will likely clip the underlined parts exceeding the bounds.
+     *
+     * Users wishing to mitigate some of these perhaps surprising results can ensure
+     * they use trimmed texts, and avoid the use of line breaks, or at least ensure
+     * that line breaks are not preceded or succeeded by white space (activating
+     * line wrapping is not equivalent to collapsing any consecutive white space
+     * no matter where it occurs).
+     */
+
     private void layout() {
         /* Try the cache */
         initCache();
@@ -1072,12 +1196,13 @@ public class PrismTextLayout implements TextLayout {
 
         GlyphLayout layout = null;
         if ((flags & (FLAGS_HAS_COMPLEX)) != 0) {
-            layout = GlyphLayout.getInstance();
+            layout = glyphLayout();
         }
 
-        float tabAdvance = 0;
         if ((flags & FLAGS_HAS_TABS) != 0) {
-            tabAdvance = getTabAdvance();
+            if (tabAdvancePolicy == null) {
+                setTabAdvancePolicy(TextLayout.DEFAULT_TAB_SIZE, null);
+            }
         }
 
         BreakIterator boundary = null;
@@ -1107,12 +1232,20 @@ public class PrismTextLayout implements TextLayout {
         float lineWidth = 0;
         int startIndex = 0;
         int startOffset = 0;
-        ArrayList<TextLine> linesList = new ArrayList<>();
+        float layoutShift = Float.NaN;
+        ArrayList<PrismTextLine> linesList = new ArrayList<>();
         for (int i = 0; i < runCount; i++) {
             TextRun run = runs[i];
             shape(run, chars, layout);
+
             if (run.isTab()) {
-                float tabStop = ((int)(lineWidth / tabAdvance) +1) * tabAdvance;
+                if (Float.isNaN(layoutShift)) {
+                    layoutShift = computeLayoutShift(run.getTextSpan());
+                }
+                float tabStop = tabAdvancePolicy.nextTabStop(layoutShift, lineWidth);
+                if (tabStop <= 0.0f) {
+                    tabStop = lineWidth + getSpaceAdvance();
+                }
                 run.setWidth(tabStop - lineWidth);
             }
 
@@ -1122,17 +1255,22 @@ public class PrismTextLayout implements TextLayout {
                 /* Find offset of the first character that does not fit on the line */
                 int hitOffset = run.getStart() + run.getWrapIndex(wrapWidth - lineWidth);
 
-                /* Only keep whitespaces (not tabs) in the current run to avoid
+                /*
+                 * Only keep white spaces (not tabs) in the current run to avoid
                  * dealing with unshaped runs.
+                 *
+                 * If the run is a tab, the run will be always of length 1 (see
+                 * buildRuns()). As there is no "next" character that can be selected
+                 * as the wrap index in this run, the white space skipping logic
+                 * below won't skip tabs.
                  */
+
                 int offset = hitOffset;
                 int runEnd = run.getEnd();
-                while (offset + 1 < runEnd && chars[offset] == ' ') {
+
+                // Don't take white space into account at the preferred wrap index:
+                while (offset + 1 < runEnd && Character.isWhitespace(chars[offset])) {
                     offset++;
-                    /* Preserve behaviour: only keep one white space in the line
-                     * before wrapping. Needed API to allow change.
-                     */
-                    break;
                 }
 
                 /* Find the break opportunity */
@@ -1229,7 +1367,7 @@ public class PrismTextLayout implements TextLayout {
 
             lineWidth += runWidth;
             if (run.isBreak()) {
-                TextLine line = createLine(startIndex, i, startOffset);
+                PrismTextLine line = createLine(startIndex, i, startOffset, computeTrailingSpaceWidth(runs[i]));
                 linesList.add(line);
                 startIndex = i + 1;
                 startOffset += line.getLength();
@@ -1238,11 +1376,11 @@ public class PrismTextLayout implements TextLayout {
         }
         if (layout != null) layout.dispose();
 
-        linesList.add(createLine(startIndex, runCount - 1, startOffset));
-        lines = new TextLine[linesList.size()];
+        linesList.add(createLine(startIndex, runCount - 1, startOffset, 0));
+        lines = new PrismTextLine[linesList.size()];
         linesList.toArray(lines);
 
-        float fullWidth = Math.max(wrapWidth, layoutWidth);
+        float fullWidth = wrapWidth > 0 ? wrapWidth : layoutWidth;  // layoutWidth = widest line, wrapWidth is user set
         float lineY = 0;
         float align;
         if (isMirrored()) {
@@ -1254,12 +1392,13 @@ public class PrismTextLayout implements TextLayout {
         }
         if (textAlignment == ALIGN_CENTER) align = 0.5f;
         for (int i = 0; i < lines.length; i++) {
-            TextLine line = lines[i];
+            PrismTextLine line = lines[i];
             int lineStart = line.getStart();
             RectBounds bounds = line.getBounds();
 
             /* Center and right alignment */
-            float lineX = (fullWidth - bounds.getWidth()) * align;
+            float unusedWidth = fullWidth - bounds.getWidth();
+            float lineX = unusedWidth * align;
             line.setAlignment(lineX);
 
             /* Justify */
@@ -1277,7 +1416,7 @@ public class PrismTextLayout implements TextLayout {
                         if (hitChar && chars[j] == ' ') wsCount++;
                     }
                     if (wsCount != 0) {
-                        float inc = (fullWidth - bounds.getWidth()) / wsCount;
+                        float inc = unusedWidth / wsCount;
                         done:
                         for (int j = 0; j < lineRunCount; j++) {
                             TextRun textRun = lineRuns[j];
@@ -1342,7 +1481,7 @@ public class PrismTextLayout implements TextLayout {
                 layoutCache.analysis = flags & ANALYSIS_MASK;
                 synchronized (CACHE_SIZE_LOCK) {
                     int charCount = chars.length;
-                    if (cacheSize + charCount > MAX_CACHE_SIZE) {
+                    if (cacheSize + charCount > maxCacheSize) {
                         stringCache.clear();
                         cacheSize = 0;
                     }
@@ -1387,7 +1526,7 @@ public class PrismTextLayout implements TextLayout {
         Metrics metrics = strike.getMetrics();
         float size = strike.getSize();
         for (int i = 0; i < lines.length; i++) {
-            TextLine line = lines[i];
+            PrismTextLine line = lines[i];
             TextRun[] runs = line.getRuns();
             for (int j = 0; j < runs.length; j++) {
                 TextRun run = runs[j];
@@ -1441,7 +1580,7 @@ public class PrismTextLayout implements TextLayout {
         return visualBounds;
     }
 
-    private void computeSideBearings(TextLine line) {
+    private void computeSideBearings(PrismTextLine line) {
         TextRun[] runs = line.getRuns();
         if (runs.length == 0) return;
         float bounds[] = new float[4];
@@ -1527,4 +1666,15 @@ public class PrismTextLayout implements TextLayout {
         }
         line.setSideBearings(lsb, rsb);
     }
+
+    private float computeLayoutShift(TextSpan span) {
+        if (span != null) {
+            Region root = span.getLayoutRootRegion();
+            if (root != null) {
+                // TODO ltr
+                return -(float)root.snappedLeftInset();
+            }
+        }
+        return 0.0f;
+    }
 }
