@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -61,10 +61,8 @@ jmethodID jViewNotifyDragOver;
 jmethodID jViewNotifyDragDrop;
 jmethodID jViewNotifyDragLeave;
 jmethodID jViewNotifyScroll;
-jmethodID jViewNotifyInputMethod;
-jmethodID jViewNotifyInputMethodDraw;
-jmethodID jViewNotifyInputMethodCaret;
-jmethodID jViewNotifyPreeditMode;
+jmethodID jViewNotifyInputMethodLinux;
+jmethodID jViewNotifyInputMethodCandidateRelativePosRequest;
 jmethodID jViewNotifyMenu;
 jfieldID  jViewPtr;
 
@@ -83,15 +81,21 @@ jfieldID jWindowPtr;
 jfieldID jCursorPtr;
 
 jmethodID jGtkWindowNotifyStateChanged;
+jmethodID jGtkWindowDragAreaHitTest;
 
 jmethodID jClipboardContentChanged;
 
 jmethodID jSizeInit;
 
+jclass jMapCls;
 jmethodID jMapGet;
+jmethodID jMapPut;
 jmethodID jMapKeySet;
 jmethodID jMapContainsKey;
 
+jclass jHashMapCls;
+jmethodID jHashMapInit;
+
 jclass jHashSetCls;
 jmethodID jHashSetInit;
 
@@ -110,6 +114,20 @@ jfieldID jApplicationVisualID;
 jmethodID jApplicationReportException;
 jmethodID jApplicationGetApplication;
 jmethodID jApplicationGetName;
+jmethodID jApplicationNotifyPreferencesChanged;
+
+jclass jObjectCls;
+jmethodID jObjectEquals;
+
+jclass jBooleanCls;
+jfieldID jBooleanTRUE;
+jfieldID jBooleanFALSE;
+
+jclass jCollectionsCls;
+jmethodID jCollectionsUnmodifiableMap;
+
+jclass jColorCls;
+jmethodID jColorRgb;
 
 static jboolean displayValid = JNI_FALSE;
 
@@ -210,8 +228,6 @@ JNI_OnLoad(JavaVM *jvm, void *reserved)
     if (env->ExceptionCheck()) return JNI_ERR;
     jViewNotifyScroll = env->GetMethodID(clazz, "notifyScroll", "(IIIIDDIIIIIDD)V");
     if (env->ExceptionCheck()) return JNI_ERR;
-    jViewNotifyInputMethod = env->GetMethodID(clazz, "notifyInputMethod", "(Ljava/lang/String;[I[I[BIII)V");
-    if (env->ExceptionCheck()) return JNI_ERR;
     jViewNotifyMenu = env->GetMethodID(clazz, "notifyMenu", "(IIIIZ)V");
     if (env->ExceptionCheck()) return JNI_ERR;
     jViewPtr = env->GetFieldID(clazz, "ptr", "J");
@@ -219,11 +235,10 @@ JNI_OnLoad(JavaVM *jvm, void *reserved)
 
     clazz = env->FindClass("com/sun/glass/ui/gtk/GtkView");
     if (env->ExceptionCheck()) return JNI_ERR;
-    jViewNotifyInputMethodDraw = env->GetMethodID(clazz, "notifyInputMethodDraw", "(Ljava/lang/String;III[B)V");
+    jViewNotifyInputMethodLinux = env->GetMethodID(clazz, "notifyInputMethodLinux", "(Ljava/lang/String;IIB)V");
     if (env->ExceptionCheck()) return JNI_ERR;
-    jViewNotifyInputMethodCaret = env->GetMethodID(clazz, "notifyInputMethodCaret", "(III)V");
-    if (env->ExceptionCheck()) return JNI_ERR;
-    jViewNotifyPreeditMode = env->GetMethodID(clazz, "notifyPreeditMode", "(Z)V");
+    jViewNotifyInputMethodCandidateRelativePosRequest
+        = env->GetMethodID(clazz, "notifyInputMethodCandidateRelativePosRequest", "(I)[D");
     if (env->ExceptionCheck()) return JNI_ERR;
 
     clazz = env->FindClass("com/sun/glass/ui/Window");
@@ -255,8 +270,9 @@ JNI_OnLoad(JavaVM *jvm, void *reserved)
 
     clazz = env->FindClass("com/sun/glass/ui/gtk/GtkWindow");
     if (env->ExceptionCheck()) return JNI_ERR;
-    jGtkWindowNotifyStateChanged =
-            env->GetMethodID(clazz, "notifyStateChanged", "(I)V");
+    jGtkWindowNotifyStateChanged = env->GetMethodID(clazz, "notifyStateChanged", "(I)V");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jGtkWindowDragAreaHitTest = env->GetMethodID(clazz, "dragAreaHitTest", "(II)Z");
     if (env->ExceptionCheck()) return JNI_ERR;
 
     clazz = env->FindClass("com/sun/glass/ui/Clipboard");
@@ -276,13 +292,22 @@ JNI_OnLoad(JavaVM *jvm, void *reserved)
 
     clazz = env->FindClass("java/util/Map");
     if (env->ExceptionCheck()) return JNI_ERR;
+    jMapCls = (jclass)env->NewGlobalRef(clazz);
     jMapGet = env->GetMethodID(clazz, "get", "(Ljava/lang/Object;)Ljava/lang/Object;");
     if (env->ExceptionCheck()) return JNI_ERR;
+    jMapPut = env->GetMethodID(clazz, "put", "(Ljava/lang/Object;Ljava/lang/Object;)Ljava/lang/Object;");
+    if (env->ExceptionCheck()) return JNI_ERR;
     jMapKeySet = env->GetMethodID(clazz, "keySet", "()Ljava/util/Set;");
     if (env->ExceptionCheck()) return JNI_ERR;
     jMapContainsKey = env->GetMethodID(clazz, "containsKey", "(Ljava/lang/Object;)Z");
     if (env->ExceptionCheck()) return JNI_ERR;
 
+    clazz = env->FindClass("java/util/HashMap");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jHashMapCls = (jclass) env->NewGlobalRef(clazz);
+    jHashMapInit = env->GetMethodID(jHashMapCls, "<init>", "()V");
+    if (env->ExceptionCheck()) return JNI_ERR;
+
     clazz = env->FindClass("java/util/HashSet");
     if (env->ExceptionCheck()) return JNI_ERR;
     jHashSetCls = (jclass) env->NewGlobalRef(clazz);
@@ -327,6 +352,34 @@ JNI_OnLoad(JavaVM *jvm, void *reserved)
     if (env->ExceptionCheck()) return JNI_ERR;
     jApplicationGetName = env->GetMethodID(jApplicationCls, "getName", "()Ljava/lang/String;");
     if (env->ExceptionCheck()) return JNI_ERR;
+    jApplicationNotifyPreferencesChanged = env->GetMethodID(jApplicationCls, "notifyPreferencesChanged", "(Ljava/util/Map;)V");
+    if (env->ExceptionCheck()) return JNI_ERR;
+
+    clazz = env->FindClass("java/lang/Object");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jObjectCls = (jclass)env->NewGlobalRef(clazz);
+    jObjectEquals = env->GetMethodID(jObjectCls, "equals", "(Ljava/lang/Object;)Z");
+    if (env->ExceptionCheck()) return JNI_ERR;
+
+    clazz = env->FindClass("java/lang/Boolean");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jBooleanCls = (jclass)env->NewGlobalRef(clazz);
+    jBooleanTRUE = env->GetStaticFieldID(jBooleanCls, "TRUE", "Ljava/lang/Boolean;");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jBooleanFALSE = env->GetStaticFieldID(jBooleanCls, "FALSE", "Ljava/lang/Boolean;");
+    if (env->ExceptionCheck()) return JNI_ERR;
+
+    clazz = env->FindClass("java/util/Collections");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jCollectionsCls = (jclass)env->NewGlobalRef(clazz);
+    jCollectionsUnmodifiableMap = env->GetStaticMethodID(jCollectionsCls, "unmodifiableMap", "(Ljava/util/Map;)Ljava/util/Map;");
+    if (env->ExceptionCheck()) return JNI_ERR;
+
+    clazz = env->FindClass("javafx/scene/paint/Color");
+    if (env->ExceptionCheck()) return JNI_ERR;
+    jColorCls = (jclass)env->NewGlobalRef(clazz);
+    jColorRgb = env->GetStaticMethodID(jColorCls, "rgb", "(IIID)Ljavafx/scene/paint/Color;");
+    if (env->ExceptionCheck()) return JNI_ERR;
 
     return JNI_VERSION_1_6;
 }
@@ -557,7 +610,8 @@ glass_gdk_mouse_devices_grab_with_cursor(GdkWindow *gdkWindow, GdkCursor *cursor
                                                 | GDK_BUTTON2_MOTION_MASK
                                                 | GDK_BUTTON3_MOTION_MASK
                                                 | GDK_BUTTON_PRESS_MASK
-                                                | GDK_BUTTON_RELEASE_MASK),
+                                                | GDK_BUTTON_RELEASE_MASK
+                                                | GDK_TOUCH_MASK),
                                             NULL, cursor, GDK_CURRENT_TIME);
 
     return (status == GDK_GRAB_SUCCESS) ? TRUE : FALSE;
