@@ -59,8 +59,17 @@
 
 #pragma mark --- Delegate
 
+- (void)windowDidChangeScreen:(NSNotification *)notification
+{
+    //NSLog(@"windowDidChangeScreen: %p  screen: %p", self, [self->nsWindow screen]);
+
+    // Fix up window stacking order
+    [self reorderChildWindows];
+}
+
 - (void)windowDidBecomeKey:(NSNotification *)notification
 {
+    //NSLog(@"windowDidBecomeKey: %p", self);
     GET_MAIN_JENV;
     if (!self->isEnabled)
     {
@@ -76,10 +85,14 @@
         [NSApp setMainMenu:self->menubar->menu];
     }
     [[NSApp mainMenu] update];
+
+    // Fix up window stacking order
+    [self reorderChildWindows];
 }
 
 - (void)windowDidResignKey:(NSNotification *)notification
 {
+    //NSLog(@"windowDidResignKey: %p", self);
     [self _ungrabFocus];
 
     GET_MAIN_JENV_NOWARN;
@@ -90,18 +103,25 @@
 
 - (void)windowWillClose:(NSNotification *)notification
 {
-    // Unparent self. Otherwise the code hangs
-    if ([self->nsWindow parentWindow])
-    {
-        [[self->nsWindow parentWindow] removeChildWindow:self->nsWindow];
+    //NSLog(@"windowWillClose");
+    // Remove self from list of owner's child windows
+    if (self->owner != nil) {
+        [self->owner removeChildWindow:self];
     }
 
     // Finally, close owned windows to mimic MS Windows behavior
-    NSArray *children = [self->nsWindow childWindows];
-    for (NSUInteger i=0; i<[children count]; i++)
-    {
-        NSWindow *child = (NSWindow*)[children objectAtIndex:i];
-        [child close];
+    if (self->childWindows != nil) {
+        // Iterate over an immutable copy
+        NSArray *children = [[NSArray alloc] initWithArray:self->childWindows];
+        for (GlassWindow *child in children) {
+            [child->nsWindow close];
+        }
+        [children release];
+    }
+
+    // If we have an owner, reorder its remaining children
+    if (self->owner != nil) {
+        [self->owner reorderChildWindows];
     }
 
     // Call the notification method
@@ -160,14 +180,24 @@
     [self _sendJavaWindowResizeEvent:com_sun_glass_events_WindowEvent_RESIZE forFrame:frame];
 }
 
+- (void)windowWillMiniaturize:(NSNotification *)notification
+{
+    //NSLog(@"windowWillMiniaturize: %p", self);
+}
+
 - (void)windowDidMiniaturize:(NSNotification *)notification
 {
+    //NSLog(@"windowDidMiniaturize: %p", self);
     [self _sendJavaWindowResizeEvent:com_sun_glass_events_WindowEvent_MINIMIZE forFrame:[self _flipFrame]];
+    [self minimizeChildWindows:YES];
 }
 
 - (void)windowDidDeminiaturize:(NSNotification *)notification
 {
+    //NSLog(@"windowDidDeminiaturize: %p", self);
     [self _sendJavaWindowResizeEvent:com_sun_glass_events_WindowEvent_RESTORE forFrame:[self _flipFrame]];
+    [self minimizeChildWindows:NO];
+    [self reorderChildWindows];
 }
 
 - (BOOL)windowShouldZoom:(NSWindow *)window toFrame:(NSRect)newFrame
@@ -202,6 +232,8 @@
     if (nsWindow.toolbar != nil) {
         nsWindow.toolbar.visible = NO;
     }
+    // Allow child windows to move to the same space as this full-screen window
+    [self setMoveToActiveSpaceChildWindows:YES];
 }
 
 - (void)windowDidEnterFullScreen:(NSNotification *)notification
@@ -209,6 +241,10 @@
     //NSLog(@"windowDidEnterFullScreen");
     [(GlassViewDelegate*)[self->view delegate] sendJavaFullScreenEvent:YES withNativeWidget:YES];
     [GlassApplication leaveFullScreenExitingLoopIfNeeded];
+
+    // Fix up window stacking order then disable moving child windows to active space
+    [self reorderChildWindows];
+    [self setMoveToActiveSpaceChildWindows:NO];
 }
 
 - (void)windowWillExitFullScreen:(NSNotification *)notification
@@ -236,6 +272,9 @@
 
     [delegate sendJavaFullScreenEvent:NO withNativeWidget:YES];
     [GlassApplication leaveFullScreenExitingLoopIfNeeded];
+
+    // Fix up window stacking order
+    [self reorderChildWindows];
 }
 
 - (BOOL)windowShouldClose:(NSNotification *)notification
