@@ -28,6 +28,7 @@
 
 #import "GlassMenu.h"
 #import "GlassView.h"
+#import "GlassView3D.h"
 
 // normal Glass window delegate
 @interface GlassWindow : NSObject <NSWindowDelegate>
@@ -38,8 +39,12 @@
     // A reference to an NSWindow or NSPanel descendant - the native window
     NSWindow            *nsWindow;
 
-    NSWindow            *owner;
-    NSView<GlassView>   *view;
+    // Owner glass window and list of owned "child" glass windows
+    // (we don't create NSWindow children)
+    GlassWindow         *owner;
+    NSMutableArray<GlassWindow*> *childWindows;
+
+    GlassView3D<GlassView>   *view;
     NSScreen            *currentScreen;
     GlassMenubar        *menubar;
     NSRect              preZoomedRect;
@@ -58,6 +63,8 @@
 
     BOOL                isClosed;
 
+    NSWindowLevel       prefLevel; // Preferred level for this window
+
     // We track whether an explicit size/location have been assigned to the window
     // in order to differentiate between an explicitly assigned zero bounds, and the
     // deafult bounds (which are also zeros - see a comment in _createWindowCommon().)
@@ -68,6 +75,13 @@
     BOOL                isWindowResizable;
 }
 
+// Helper methods for owned windows
+- (void) addChildWindow:(GlassWindow*)childWindow;
+- (void) removeChildWindow:(GlassWindow*)childWindow;
+- (void) reorderChildWindows;
+- (void) minimizeChildWindows:(BOOL)minimize;
+- (void) setMoveToActiveSpaceChildWindows:(BOOL)moveToActiveSpace;
+
 // NSWindow overrides delegate methods
 - (void)close;
 - (void)sendEvent:(NSEvent *)event;
