@@ -37,7 +37,6 @@
 #import "GlassView.h"
 #import "GlassScreen.h"
 #import "GlassApplication.h"
-#import "GlassLayer3D.h"
 #import "GlassHelper.h"
 
 #pragma clang diagnostic ignored "-Wdeprecated-declarations"
@@ -93,13 +92,13 @@ static inline GlassWindow *getGlassWindow(JNIEnv *env, jlong jPtr)
     return (GlassWindow*)[nsWindow delegate];
 }
 
-static inline NSView<GlassView> *getMacView(JNIEnv *env, jobject jview)
+static inline GlassView3D<GlassView> *getMacView(JNIEnv *env, jobject jview)
 {
     if (jview != NULL)
     {
         jfieldID jfID = (*env)->GetFieldID(env, jViewClass, "ptr", "J");
         GLASS_CHECK_EXCEPTION(env);
-        return (NSView<GlassView>*)jlong_to_ptr((*env)->GetLongField(env, jview, jfID));
+        return (GlassView3D<GlassView>*)jlong_to_ptr((*env)->GetLongField(env, jview, jfID));
     }
     else
     {
@@ -310,6 +309,7 @@ GLASS_NS_WINDOW_IMPLEMENTATION
         }
 
         [self _checkUngrab];
+        [self reorderChildWindows];
     }
 }
 
@@ -346,6 +346,90 @@ GLASS_NS_WINDOW_IMPLEMENTATION
     return self->isFocusable;
 }
 
+- (void) addChildWindow:(GlassWindow*)childWindow
+{
+    LOG("addChildWindow: %p  child: %p", self, childWindow);
+    if (self->childWindows == nil) {
+        self->childWindows = [[NSMutableArray alloc] init];
+    }
+    [self->childWindows addObject:childWindow];
+}
+
+- (void) removeChildWindow:(GlassWindow*)childWindow
+{
+    LOG("removeChildWindow: %p  child: %p", self, childWindow);
+    if (self->childWindows != nil) {
+        [self->childWindows removeObject:childWindow];
+    }
+}
+
+//
+// Recursively orders all child windows so that they are above their owner.
+//
+- (void) reorderChildWindows
+{
+    LOG("reorderChildWindows: %p", self);
+    if ((self->childWindows != nil) && (!nsWindow.isMiniaturized)) {
+        for (GlassWindow *child in self->childWindows)
+        {
+            // Owned windows must set their level to at least the level of their owner
+            NSWindowLevel level = MAX(child->prefLevel, [self->nsWindow level]);
+            [child->nsWindow setLevel:level];
+            // Order child above the owner window
+            if (child->nsWindow.isVisible) {
+                [child->nsWindow orderWindow:NSWindowAbove relativeTo:[self->nsWindow windowNumber]];
+            }
+            [child reorderChildWindows];
+        }
+    }
+}
+
+//
+// Recursively minimize or unminimize all child windows.
+//
+- (void) minimizeChildWindows:(BOOL)minimize
+{
+    LOG("minimizeChildWindows: %p  minimize:%d", self, minimize);
+    if (self->childWindows != nil) {
+        for (GlassWindow *child in self->childWindows)
+        {
+            if (minimize) {
+                [child->nsWindow orderOut:child];
+            } else {
+                [child->nsWindow orderFront:child];
+            }
+
+            [child minimizeChildWindows:minimize];
+        }
+    }
+}
+
+//
+// Recursively set the collection behavior for the child windows to enable or
+// disable the "move to active space" behavior. This is used when the owner
+// enters full-screen, so that the children will follow the owner to the
+// full-screen space. It is called with "true" when first entering full screen
+// and "false" once the transition to full-screen is complete.
+//
+- (void) setMoveToActiveSpaceChildWindows:(BOOL)moveToActiveSpace
+{
+    LOG("setMoveToActiveSpaceChildWindows: %p  moveToActiveSpace:%d", self, moveToActiveSpace);
+    if (self->childWindows != nil) {
+        for (GlassWindow *child in self->childWindows)
+        {
+            NSWindowCollectionBehavior behavior = [child->nsWindow collectionBehavior];
+            if (moveToActiveSpace) {
+                behavior |= NSWindowCollectionBehaviorMoveToActiveSpace;
+            } else {
+                behavior &= ~NSWindowCollectionBehaviorMoveToActiveSpace;
+            }
+            [child->nsWindow setCollectionBehavior: behavior];
+
+            [child setMoveToActiveSpaceChildWindows:moveToActiveSpace];
+        }
+    }
+}
+
 - (NSColor*)setBackgroundColor:(NSColor *)color
 {
     if (self->isTransparent == NO)
@@ -462,14 +546,19 @@ static jlong _createWindowCommonDo(JNIEnv *env, jobject jWindow, jlong jOwnerPtr
             [[window->nsWindow standardWindowButton:NSWindowMiniaturizeButton] setFrame:CGRectMake(0, 0, 0, 0)];
             [[window->nsWindow standardWindowButton:NSWindowZoomButton] setFrame:CGRectMake(0, 0, 0, 0)];
 
-            if (!jOwnerPtr) {
-                [window->nsWindow setLevel:NSNormalWindowLevel];
-            }
+            [window->nsWindow setLevel:NSNormalWindowLevel];
         }
 
+        window->prefLevel = [window->nsWindow level];
         if (jOwnerPtr != 0L)
         {
-            window->owner = getGlassWindow(env, jOwnerPtr)->nsWindow; // not retained (use weak reference?)
+            // Get owner glass window and add this window as a child window
+            window->owner = getGlassWindow(env, jOwnerPtr);
+            [window->owner addChildWindow:window];
+
+            // Owned windows must set their level to at least the level of their owner
+            NSWindowLevel level = MAX(window->prefLevel, [window->owner->nsWindow level]);
+            [window->nsWindow setLevel:level];
         }
 
         /* 10.7 full screen window support */
@@ -677,7 +766,13 @@ JNIEXPORT void JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setLevel
                 level = NSScreenSaverWindowLevel;
                 break;
         }
+        window->prefLevel = level; // Save preferred level
+        if (window->owner != nil) {
+            // Owned windows must set their level to at least the level of their owner
+            level = MAX(level, [window->owner->nsWindow level]);
+        }
         [window->nsWindow setLevel:level];
+        [window reorderChildWindows];
     }
     GLASS_POOL_EXIT;
     GLASS_CHECK_EXCEPTION(env);
@@ -836,8 +931,10 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setView
 
         if (window->view != nil)
         {
-            CALayer *layer = [window->view layer];
-            if (([layer isKindOfClass:[CAOpenGLLayer class]] == YES) &&
+            CALayer *layer = [window->view getLayer];
+            LOG("   layer: %p", layer);
+            // TODO : Move below logic to CGL specific View/Layer class
+            if (([layer.sublayers[0] isKindOfClass:[CAOpenGLLayer class]] == YES) &&
                 (([window->nsWindow styleMask] & NSWindowStyleMaskTexturedBackground) == NO))
             {
                 [((CAOpenGLLayer*)layer) setOpaque:[window->nsWindow isOpaque]];
@@ -1201,11 +1298,6 @@ JNIEXPORT jboolean JNICALL Java_com_sun_glass_ui_mac_MacWindow__1setVisible
         else
         {
             [window _ungrabFocus];
-            if (window->owner != nil)
-            {
-                LOG("   removeChildWindow: %p", window);
-                [window->owner removeChildWindow:window->nsWindow];
-            }
             [window->nsWindow orderOut:window->nsWindow];
         }
         now = [window->nsWindow isVisible] ? JNI_TRUE : JNI_FALSE;
