@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,12 +33,15 @@ import javafx.scene.layout.BackgroundFill;
 import javafx.scene.layout.BackgroundImage;
 import javafx.scene.layout.BackgroundPosition;
 import javafx.scene.layout.BackgroundShim;
+import javafx.scene.layout.BackgroundSize;
 import javafx.scene.layout.CornerRadii;
 import javafx.scene.paint.Color;
-import org.junit.Test;
+import org.junit.jupiter.api.Nested;
+import org.junit.jupiter.api.Test;
+import java.util.List;
 
 import static javafx.scene.layout.BackgroundRepeat.*;
-import static org.junit.Assert.*;
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  */
@@ -66,7 +69,8 @@ public class BackgroundTest {
             new BackgroundImage(IMAGE_4, NO_REPEAT, NO_REPEAT, null, null)
     };
 
-    @Test public void instanceCreation() {
+    @Test
+    public void instanceCreation() {
         Background b = new Background(FILLS_1, IMAGES_1);
         assertEquals(FILLS_1.length, b.getFills().size(), 0);
         assertEquals(FILLS_1[0], b.getFills().get(0));
@@ -74,7 +78,8 @@ public class BackgroundTest {
         assertEquals(IMAGES_1[0], b.getImages().get(0));
     }
 
-    @Test public void instanceCreation2() {
+    @Test
+    public void instanceCreation2() {
         Background b = new Background(FILLS_2, IMAGES_2);
         assertEquals(FILLS_2.length, b.getFills().size(), 0);
         assertEquals(FILLS_2[0], b.getFills().get(0));
@@ -85,35 +90,40 @@ public class BackgroundTest {
         assertEquals(IMAGES_2[2], b.getImages().get(2));
     }
 
-    @Test public void instanceCreationNullFills() {
+    @Test
+    public void instanceCreationNullFills() {
         Background b = new Background(null, IMAGES_1);
         assertEquals(0, b.getFills().size(), 0);
         assertEquals(IMAGES_1.length, b.getImages().size(), 0);
         assertEquals(IMAGES_1[0], b.getImages().get(0));
     }
 
-    @Test public void instanceCreationEmptyFills() {
+    @Test
+    public void instanceCreationEmptyFills() {
         Background b = new Background(new BackgroundFill[0], IMAGES_1);
         assertEquals(0, b.getFills().size(), 0);
         assertEquals(IMAGES_1.length, b.getImages().size(), 0);
         assertEquals(IMAGES_1[0], b.getImages().get(0));
     }
 
-    @Test public void instanceCreationNullImages() {
+    @Test
+    public void instanceCreationNullImages() {
         Background b = new Background(FILLS_1, null);
         assertEquals(FILLS_1.length, b.getFills().size(), 0);
         assertEquals(FILLS_1[0], b.getFills().get(0));
         assertEquals(0, b.getImages().size(), 0);
     }
 
-    @Test public void instanceCreationEmptyImages() {
+    @Test
+    public void instanceCreationEmptyImages() {
         Background b = new Background(FILLS_1, new BackgroundImage[0]);
         assertEquals(FILLS_1.length, b.getFills().size(), 0);
         assertEquals(FILLS_1[0], b.getFills().get(0));
         assertEquals(0, b.getImages().size(), 0);
     }
 
-    @Test public void instanceCreationWithNullsInTheFillArray() {
+    @Test
+    public void instanceCreationWithNullsInTheFillArray() {
         final BackgroundFill[] fills = new BackgroundFill[] {
                 null,
                 new BackgroundFill(Color.GREEN, new CornerRadii(3), new Insets(4)),
@@ -125,7 +135,8 @@ public class BackgroundTest {
         assertEquals(FILLS_2[1], b.getFills().get(1));
     }
 
-    @Test public void instanceCreationWithNullsInTheFillArray2() {
+    @Test
+    public void instanceCreationWithNullsInTheFillArray2() {
         final BackgroundFill[] fills = new BackgroundFill[] {
                 new BackgroundFill(Color.GREEN, new CornerRadii(3), new Insets(4)),
                 null,
@@ -137,7 +148,8 @@ public class BackgroundTest {
         assertEquals(FILLS_2[1], b.getFills().get(1));
     }
 
-    @Test public void instanceCreationWithNullsInTheFillArray3() {
+    @Test
+    public void instanceCreationWithNullsInTheFillArray3() {
         final BackgroundFill[] fills = new BackgroundFill[] {
                 new BackgroundFill(Color.GREEN, new CornerRadii(3), new Insets(4)),
                 new BackgroundFill(Color.BLUE, new CornerRadii(6), new Insets(8)),
@@ -149,7 +161,8 @@ public class BackgroundTest {
         assertEquals(FILLS_2[1], b.getFills().get(1));
     }
 
-    @Test public void instanceCreationWithNullsInTheFillArray4() {
+    @Test
+    public void instanceCreationWithNullsInTheFillArray4() {
         final BackgroundFill[] fills = new BackgroundFill[] {
                 null
         };
@@ -157,7 +170,8 @@ public class BackgroundTest {
         assertEquals(0, b.getFills().size(), 0);
     }
 
-    @Test public void instanceCreationWithNullsInTheImageArray() {
+    @Test
+    public void instanceCreationWithNullsInTheImageArray() {
         final BackgroundImage[] images = new BackgroundImage[] {
                 null,
                 new BackgroundImage(IMAGE_2, SPACE, SPACE, null, null),
@@ -171,7 +185,8 @@ public class BackgroundTest {
         assertEquals(IMAGES_2[2], b.getImages().get(2));
     }
 
-    @Test public void instanceCreationWithNullsInTheImageArray2() {
+    @Test
+    public void instanceCreationWithNullsInTheImageArray2() {
         final BackgroundImage[] images = new BackgroundImage[] {
                 new BackgroundImage(IMAGE_2, SPACE, SPACE, null, null),
                 null,
@@ -185,7 +200,8 @@ public class BackgroundTest {
         assertEquals(IMAGES_2[2], b.getImages().get(2));
     }
 
-    @Test public void instanceCreationWithNullsInTheImageArray3() {
+    @Test
+    public void instanceCreationWithNullsInTheImageArray3() {
         final BackgroundImage[] images = new BackgroundImage[] {
                 new BackgroundImage(IMAGE_2, SPACE, SPACE, null, null),
                 new BackgroundImage(IMAGE_3, ROUND, ROUND, null, null),
@@ -199,7 +215,8 @@ public class BackgroundTest {
         assertEquals(IMAGES_2[2], b.getImages().get(2));
     }
 
-    @Test public void instanceCreationWithNullsInTheImageArray4() {
+    @Test
+    public void instanceCreationWithNullsInTheImageArray4() {
         final BackgroundImage[] images = new BackgroundImage[] {
                 null
         };
@@ -207,7 +224,8 @@ public class BackgroundTest {
         assertEquals(0, b.getImages().size(), 0);
     }
 
-    @Test public void suppliedBackgroundFillsMutatedLaterDoNotChangeFills() {
+    @Test
+    public void suppliedBackgroundFillsMutatedLaterDoNotChangeFills() {
         final BackgroundFill fill = new BackgroundFill(Color.GREEN, new CornerRadii(3), new Insets(4));
         final BackgroundFill[] fills = new BackgroundFill[] { fill };
         Background b = new Background(fills, null);
@@ -219,7 +237,8 @@ public class BackgroundTest {
         assertSame(fill, b2.getFills().get(0));
     }
 
-    @Test public void suppliedBackgroundImagesMutatedLaterDoNotChangeImages() {
+    @Test
+    public void suppliedBackgroundImagesMutatedLaterDoNotChangeImages() {
         final BackgroundImage image = new BackgroundImage(IMAGE_2, SPACE, SPACE, null, null);
         final BackgroundImage[] images = new BackgroundImage[] { image };
         Background b = new Background(null, images);
@@ -231,23 +250,28 @@ public class BackgroundTest {
         assertSame(image, b2.getImages().get(0));
     }
 
-    @Test(expected = UnsupportedOperationException.class)
+    @Test
     public void fillsIsUnmodifiable() {
-        final BackgroundFill fill = new BackgroundFill(Color.GREEN, new CornerRadii(3), new Insets(4));
-        final BackgroundFill[] fills = new BackgroundFill[] { fill };
-        Background b = new Background(fills);
-        b.getFills().add(new BackgroundFill(Color.BLUE, new CornerRadii(6), new Insets(8)));
+        assertThrows(UnsupportedOperationException.class, () -> {
+            final BackgroundFill fill = new BackgroundFill(Color.GREEN, new CornerRadii(3), new Insets(4));
+            final BackgroundFill[] fills = new BackgroundFill[] { fill };
+            Background b = new Background(fills);
+            b.getFills().add(new BackgroundFill(Color.BLUE, new CornerRadii(6), new Insets(8)));
+        });
     }
 
-    @Test(expected = UnsupportedOperationException.class)
+    @Test
     public void imagesIsUnmodifiable() {
-        final BackgroundImage image = new BackgroundImage(IMAGE_2, SPACE, SPACE, null, null);
-        final BackgroundImage[] images = new BackgroundImage[] { image };
-        Background b = new Background(images);
-        b.getImages().add(new BackgroundImage(IMAGE_3, ROUND, ROUND, null, null));
+        assertThrows(UnsupportedOperationException.class, () -> {
+            final BackgroundImage image = new BackgroundImage(IMAGE_2, SPACE, SPACE, null, null);
+            final BackgroundImage[] images = new BackgroundImage[] { image };
+            Background b = new Background(images);
+            b.getImages().add(new BackgroundImage(IMAGE_3, ROUND, ROUND, null, null));
+        });
     }
 
-    @Test public void backgroundOutsetsAreDefinedByFills() {
+    @Test
+    public void backgroundOutsetsAreDefinedByFills() {
         final BackgroundFill[] fills = new BackgroundFill[] {
                 new BackgroundFill(Color.RED, new CornerRadii(3), new Insets(-1, 5, 5, 5)),
                 new BackgroundFill(Color.GREEN, new CornerRadii(6), new Insets(8)),
@@ -262,7 +286,8 @@ public class BackgroundTest {
         assertEquals(new Insets(7, 2, 8, 8), b.getOutsets());
     }
 
-    @Test public void backgroundImagesDoNotContributeToOutsets() {
+    @Test
+    public void backgroundImagesDoNotContributeToOutsets() {
         final BackgroundImage[] images = new BackgroundImage[] {
                 new BackgroundImage(IMAGE_1, null, null,
                         new BackgroundPosition(Side.LEFT, -10, false, Side.TOP, -10, false),
@@ -273,73 +298,85 @@ public class BackgroundTest {
         assertEquals(Insets.EMPTY, b.getOutsets());
     }
 
-    @Test public void equivalent() {
+    @Test
+    public void equivalent() {
         Background a = new Background((BackgroundFill[])null, null);
         Background b = new Background((BackgroundFill[])null, null);
         assertEquals(a, b);
     }
 
-    @Test public void equivalent2() {
+    @Test
+    public void equivalent2() {
         Background a = new Background(FILLS_2, null);
         Background b = new Background(FILLS_2, null);
         assertEquals(a, b);
     }
 
-    @Test public void equivalent3() {
+    @Test
+    public void equivalent3() {
         Background a = new Background(null, IMAGES_2);
         Background b = new Background(null, IMAGES_2);
         assertEquals(a, b);
     }
 
-    @Test public void equivalentHasSameHashCode() {
+    @Test
+    public void equivalentHasSameHashCode() {
         Background a = new Background((BackgroundFill[])null, null);
         Background b = new Background((BackgroundFill[])null, null);
         assertEquals(a.hashCode(), b.hashCode());
     }
 
-    @Test public void equivalentHasSameHashCode2() {
+    @Test
+    public void equivalentHasSameHashCode2() {
         Background a = new Background(FILLS_2, null);
         Background b = new Background(FILLS_2, null);
         assertEquals(a.hashCode(), b.hashCode());
     }
 
-    @Test public void equivalentHasSameHashCode3() {
+    @Test
+    public void equivalentHasSameHashCode3() {
         Background a = new Background(null, IMAGES_2);
         Background b = new Background(null, IMAGES_2);
         assertEquals(a.hashCode(), b.hashCode());
     }
 
-    @Test public void notEqual() {
+    @Test
+    public void notEqual() {
         Background a = new Background(FILLS_1, null);
         Background b = new Background((BackgroundFill[])null, null);
         assertFalse(a.equals(b));
     }
 
-    @Test public void notEqual2() {
+    @Test
+    public void notEqual2() {
         Background a = new Background((BackgroundFill[])null, null);
         Background b = new Background(FILLS_2, null);
         assertFalse(a.equals(b));
     }
 
-    @Test public void notEqual3() {
+    @Test
+    public void notEqual3() {
         Background a = new Background(null, IMAGES_1);
         Background b = new Background((BackgroundFill[])null, null);
         assertFalse(a.equals(b));
     }
 
-    @Test public void notEqual4() {
+    @Test
+    public void notEqual4() {
         Background a = new Background((BackgroundFill[])null, null);
         Background b = new Background(null, IMAGES_2);
         assertFalse(a.equals(b));
     }
 
-    @Test public void notEqualWithNull() {
+    @Test
+    public void notEqualWithNull() {
         Background a = new Background((BackgroundFill[])null, null);
         assertFalse(a.equals(null));
     }
 
     @SuppressWarnings("unlikely-arg-type")
-    @Test public void notEqualWithRandom() {
+    @Test
+    public void notEqualWithRandom() {
         Background a = new Background((BackgroundFill[])null, null);
         assertFalse(a.equals("Some random String"));
     }
@@ -351,7 +388,8 @@ public class BackgroundTest {
      *                                                                        *
      *************************************************************************/
 
-    @Test public void opaqueInsets_nullFillsResultsInNaN() {
+    @Test
+    public void opaqueInsets_nullFillsResultsInNaN() {
         Background b = new Background((BackgroundFill[])null, null);
         final double[] trbl = new double[4];
         BackgroundShim.computeOpaqueInsets(b, 100, 50, trbl);
@@ -361,7 +399,8 @@ public class BackgroundTest {
         assertTrue(Double.isNaN(trbl[3]));
     }
 
-    @Test public void opaqueInsets_transparentFillsResultsInNaN() {
+    @Test
+    public void opaqueInsets_transparentFillsResultsInNaN() {
         BackgroundFill f = new BackgroundFill(Color.TRANSPARENT, null, null);
         Background b = new Background(new BackgroundFill[] { f }, null);
         final double[] trbl = new double[4];
@@ -372,7 +411,8 @@ public class BackgroundTest {
         assertTrue(Double.isNaN(trbl[3]));
     }
 
-    @Test public void opaqueInsets_transparentFillsResultsInNaN2() {
+    @Test
+    public void opaqueInsets_transparentFillsResultsInNaN2() {
         BackgroundFill f = new BackgroundFill(Color.rgb(255, 0, 0, 0), null, null);
         Background b = new Background(new BackgroundFill[] { f }, null);
         final double[] trbl = new double[4];
@@ -383,7 +423,8 @@ public class BackgroundTest {
         assertTrue(Double.isNaN(trbl[3]));
     }
 
-    @Test public void opaqueInsets_transparentFillsResultsInNaN3() {
+    @Test
+    public void opaqueInsets_transparentFillsResultsInNaN3() {
         BackgroundFill f = new BackgroundFill(Color.TRANSPARENT, null, null);
         BackgroundFill f2 = new BackgroundFill(Color.rgb(255, 0, 0, 0), null, null);
         Background b = new Background(new BackgroundFill[] { f, f2 }, null);
@@ -395,7 +436,8 @@ public class BackgroundTest {
         assertTrue(Double.isNaN(trbl[3]));
     }
 
-    @Test public void opaqueInsets_transparentFillsMixedWithNonTransparentFills() {
+    @Test
+    public void opaqueInsets_transparentFillsMixedWithNonTransparentFills() {
         BackgroundFill f = new BackgroundFill(Color.TRANSPARENT, null, null);
         BackgroundFill f2 = new BackgroundFill(Color.RED, null, new Insets(1));
         Background b = new Background(new BackgroundFill[] { f, f2 }, null);
@@ -407,7 +449,8 @@ public class BackgroundTest {
         assertEquals(1, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_transparentFillsMixedWithNonTransparentFills2() {
+    @Test
+    public void opaqueInsets_transparentFillsMixedWithNonTransparentFills2() {
         BackgroundFill f = new BackgroundFill(Color.TRANSPARENT, null, null);
         BackgroundFill f2 = new BackgroundFill(Color.RED, null, new Insets(-1));
         Background b = new Background(new BackgroundFill[] { f, f2 }, null);
@@ -419,7 +462,8 @@ public class BackgroundTest {
         assertEquals(-1, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed() {
+    @Test
+    public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(1));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(2));
@@ -432,7 +476,8 @@ public class BackgroundTest {
         assertEquals(0, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed2() {
+    @Test
+    public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed2() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(-1));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(1));
@@ -445,7 +490,8 @@ public class BackgroundTest {
         assertEquals(-1, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed3() {
+    @Test
+    public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed3() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(10));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(1));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(2));
@@ -458,7 +504,8 @@ public class BackgroundTest {
         assertEquals(1, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed4() {
+    @Test
+    public void opaqueInsets_nestedOpaqueRectangles_LargestRectangleUsed4() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(1));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(-2));
@@ -471,7 +518,8 @@ public class BackgroundTest {
         assertEquals(-2, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_offsetOpaqueRectangles_completelyContained_LargestRectangleUsed() {
+    @Test
+    public void opaqueInsets_offsetOpaqueRectangles_completelyContained_LargestRectangleUsed() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(1, 0, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(0, 1, 0, 0));
@@ -487,7 +535,8 @@ public class BackgroundTest {
     }
 
     // Even when the big rectangle is not the first, does it still work?
-    @Test public void opaqueInsets_offsetOpaqueRectangles_completelyContained_LargestRectangleUsed2() {
+    @Test
+    public void opaqueInsets_offsetOpaqueRectangles_completelyContained_LargestRectangleUsed2() {
         BackgroundFill f = new BackgroundFill(Color.YELLOW, null, new Insets(0, 0, 1, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(1, 0, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(0, 1, 0, 0));
@@ -502,7 +551,8 @@ public class BackgroundTest {
         assertEquals(0, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_offsetOpaqueRectangles_UnionUsed() {
+    @Test
+    public void opaqueInsets_offsetOpaqueRectangles_UnionUsed() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(0, 0, 10, 0));
@@ -516,7 +566,8 @@ public class BackgroundTest {
         assertEquals(0, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_offsetOpaqueRectangles_UnionUsed2() {
+    @Test
+    public void opaqueInsets_offsetOpaqueRectangles_UnionUsed2() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(10, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(10, 10, 10, 0));
@@ -534,7 +585,8 @@ public class BackgroundTest {
     // the one currently being used. We could use the bounds of f, the bounds of f2, or the
     // intersection of the bounds of f and f2. It turns out in this case, the intersection
     // would be smaller, but the bounds of f and f2 are equal in size.
-    @Test public void opaqueInsets_offsetOpaqueRectangles_LargestUsed() {
+    @Test
+    public void opaqueInsets_offsetOpaqueRectangles_LargestUsed() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(10));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(20, 0, 0, 20));
         Background b = new Background(new BackgroundFill[] { f, f2 }, null);
@@ -550,7 +602,8 @@ public class BackgroundTest {
     // of a single fill is correct for any given set of corner radii, because after
     // the opaque region for a single fill is computed, thereafter the rest of the
     // implementation is all the same
-    @Test public void opaqueInsets_uniformCornerRadii() {
+    @Test
+    public void opaqueInsets_uniformCornerRadii() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(3), null);
         Background b = new Background(new BackgroundFill[] { f }, null);
         final double[] trbl = new double[4];
@@ -561,7 +614,8 @@ public class BackgroundTest {
         assertEquals(1.5, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_nonUniformCornerRadii() {
+    @Test
+    public void opaqueInsets_nonUniformCornerRadii() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(1, 2, 3, 4, false), null);
         Background b = new Background(new BackgroundFill[] { f }, null);
         final double[] trbl = new double[4];
@@ -572,7 +626,8 @@ public class BackgroundTest {
         assertEquals(2, trbl[3], 0);
     }
 
-    @Test public void opaqueInsets_nonUniformCornerRadii2() {
+    @Test
+    public void opaqueInsets_nonUniformCornerRadii2() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(1, 2, 3, 4, 5, 6, 7, 8,
                                                                          false, false, false, false,
                                                                          false, false, false, false), null);
@@ -585,7 +640,8 @@ public class BackgroundTest {
         assertEquals(4, trbl[3], 0);
     }
 
-    @Test public void opaqueInsetsPercent_uniformCornerRadii() {
+    @Test
+    public void opaqueInsetsPercent_uniformCornerRadii() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(.1, true), null);
         Background b = new Background(new BackgroundFill[] { f }, null);
         final double[] trbl = new double[4];
@@ -596,7 +652,8 @@ public class BackgroundTest {
         assertEquals(5, trbl[3], 0);
     }
 
-    @Test public void opaqueInsetsPercent_nonUniformCornerRadii() {
+    @Test
+    public void opaqueInsetsPercent_nonUniformCornerRadii() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(.1, .2, .3, .4, true), null);
         Background b = new Background(new BackgroundFill[] { f }, null);
         final double[] trbl = new double[4];
@@ -607,7 +664,8 @@ public class BackgroundTest {
         assertEquals(20, trbl[3], 0); // bottom-left-horizontal dominates at 20
     }
 
-    @Test public void opaqueInsetsPercent_nonUniformCornerRadii2() {
+    @Test
+    public void opaqueInsetsPercent_nonUniformCornerRadii2() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(.1, .15, .2, .25, .3, .35, .4, .45,
                                                                          true, true, true, true,
                                                                          true, true, true, true), null);
@@ -620,7 +678,8 @@ public class BackgroundTest {
         assertEquals(22.5, trbl[3], 0); // bottom-left-horizontal dominates at 22.5
     }
 
-    @Test public void opaqueInsetsPercent_nonUniformCornerRadii3() {
+    @Test
+    public void opaqueInsetsPercent_nonUniformCornerRadii3() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(.1, 15, .2, 25, .3, 35, .4, 45,
                                                                          true, false, true, false,
                                                                          true, false, true, false), null);
@@ -633,7 +692,8 @@ public class BackgroundTest {
         assertEquals(22.5, trbl[3], 0); // bottom-left-horizontal dominates at 22.5
     }
 
-    @Test public void opaqueInsetsPercent_nonUniformCornerRadii4() {
+    @Test
+    public void opaqueInsetsPercent_nonUniformCornerRadii4() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(10, .15, 20, .25, 30, .35, 40, .45,
                                                                          false, true, false, true,
                                                                          false, true, false, true), null);
@@ -646,7 +706,8 @@ public class BackgroundTest {
         assertEquals(22.5, trbl[3], 0); // bottom-left-horizontal dominates at 22.5
     }
 
-    @Test public void backgroundFillsArePercentageBased_AllPercentageBased() {
+    @Test
+    public void backgroundFillsArePercentageBased_AllPercentageBased() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(.5, true), new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, new CornerRadii(.4, true), new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, new CornerRadii(.3, true), new Insets(0, 0, 10, 0));
@@ -655,7 +716,8 @@ public class BackgroundTest {
         assertTrue(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsArePercentageBased_OnePercentageBased() {
+    @Test
+    public void backgroundFillsArePercentageBased_OnePercentageBased() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(5), new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, new CornerRadii(4), new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, new CornerRadii(.3, true), new Insets(0, 0, 10, 0));
@@ -664,7 +726,8 @@ public class BackgroundTest {
         assertTrue(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsArePercentageBased_OneCornerOfOne() {
+    @Test
+    public void backgroundFillsArePercentageBased_OneCornerOfOne() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(5, 5, .5, 5, 5, 5, 5, 5,
                 false, false, true, false, false, false, false, false), new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, new CornerRadii(4), new Insets(0, 10, 0, 0));
@@ -674,7 +737,8 @@ public class BackgroundTest {
         assertTrue(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsAreNotPercentageBased() {
+    @Test
+    public void backgroundFillsAreNotPercentageBased() {
         BackgroundFill f = new BackgroundFill(Color.RED, new CornerRadii(5), new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, new CornerRadii(4), new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, new CornerRadii(3), new Insets(0, 0, 10, 0));
@@ -683,12 +747,14 @@ public class BackgroundTest {
         assertFalse(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsAreNotPercentageBased_NoFills() {
+    @Test
+    public void backgroundFillsAreNotPercentageBased_NoFills() {
         Background b = new Background(new BackgroundFill[0]);
         assertFalse(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsAreNotPercentageBased_NullRadii() {
+    @Test
+    public void backgroundFillsAreNotPercentageBased_NullRadii() {
         BackgroundFill f = new BackgroundFill(Color.RED, null, new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, null, new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, null, new Insets(0, 0, 10, 0));
@@ -697,7 +763,8 @@ public class BackgroundTest {
         assertFalse(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsAreNotPercentageBased_OneEmpty() {
+    @Test
+    public void backgroundFillsAreNotPercentageBased_OneEmpty() {
         BackgroundFill f = new BackgroundFill(Color.RED, CornerRadii.EMPTY, new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, new CornerRadii(4), new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, new CornerRadii(3), new Insets(0, 0, 10, 0));
@@ -706,7 +773,8 @@ public class BackgroundTest {
         assertFalse(b.isFillPercentageBased());
     }
 
-    @Test public void backgroundFillsAreNotPercentageBased_AllEmpty() {
+    @Test
+    public void backgroundFillsAreNotPercentageBased_AllEmpty() {
         BackgroundFill f = new BackgroundFill(Color.RED, CornerRadii.EMPTY, new Insets(10, 0, 0, 0));
         BackgroundFill f2 = new BackgroundFill(Color.GREEN, CornerRadii.EMPTY, new Insets(0, 10, 0, 0));
         BackgroundFill f3 = new BackgroundFill(Color.BLUE, CornerRadii.EMPTY, new Insets(0, 0, 10, 0));
@@ -719,14 +787,100 @@ public class BackgroundTest {
     public void testSingleFill() {
         var background1 = Background.fill(Color.BEIGE);
         var background2 = new Background(new BackgroundFill(Color.BEIGE, null, null));
-        assertEquals("The factory method should give the same result as the constructor", background1, background2);
+        assertEquals(background1, background2, "The factory method should give the same result as the constructor");
     }
 
     @Test
     public void testSingleFillWithNullPaint() {
         var background1 = Background.fill(null);
         var background2 = new Background(new BackgroundFill(null, null, null));
-        assertEquals("The factory method should give the same result as the constructor", background1, background2);
+        assertEquals(background1, background2, "The factory method should give the same result as the constructor");
+    }
+
+    @Nested
+    class InterpolationTest {
+        @Test
+        public void interpolateBetweenDifferentValuesReturnsNewInstance() {
+            var startValue = new Background(
+                List.of(new BackgroundFill(Color.RED, new CornerRadii(10), new Insets(10)),
+                        new BackgroundFill(Color.BLUE, new CornerRadii(2), new Insets(2))),
+                List.of(new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 10, false, Side.TOP, 5, false),
+                                            new BackgroundSize(10, 10, false, false, false, false))));
+
+            var endValue = new Background(
+                List.of(new BackgroundFill(Color.GREEN, new CornerRadii(20), new Insets(20)),
+                        new BackgroundFill(Color.YELLOW, new CornerRadii(6), new Insets(6))),
+                List.of(new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 20, false, Side.TOP, 15, false),
+                                            new BackgroundSize(20, 30, false, false, false, false))));
+
+            var expect = new Background(
+                List.of(new BackgroundFill(Color.RED.interpolate(Color.GREEN, 0.5), new CornerRadii(15), new Insets(15)),
+                        new BackgroundFill(Color.BLUE.interpolate(Color.YELLOW, 0.5), new CornerRadii(4), new Insets(4))),
+                List.of(new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 15, false, Side.TOP, 10, false),
+                                            new BackgroundSize(15, 20, false, false, false, false))));
+
+            var actual = startValue.interpolate(endValue, 0.5);
+
+            assertEquals(expect, actual);
+            assertNotSame(expect, actual);
+        }
+
+        @Test
+        public void interpolateBetweenDifferentNumberOfFillsAndImages() {
+            var startValue = new Background(
+                List.of(new BackgroundFill(Color.RED, new CornerRadii(10), new Insets(10))),
+                List.of(new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 10, false, Side.TOP, 5, false),
+                                            new BackgroundSize(10, 10, false, false, false, false))));
+
+            var endValue = new Background(
+                List.of(new BackgroundFill(Color.GREEN, new CornerRadii(20), new Insets(20)),
+                        new BackgroundFill(Color.BLUE, new CornerRadii(2), new Insets(2))),
+                List.of(new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 20, false, Side.TOP, 15, false),
+                                            new BackgroundSize(20, 30, false, false, false, false)),
+                        new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 30, false, Side.TOP, 40, false),
+                                            new BackgroundSize(50, 60, false, false, false, false))));
+
+            var expect = new Background(
+                List.of(new BackgroundFill(Color.RED.interpolate(Color.GREEN, 0.5), new CornerRadii(15), new Insets(15)),
+                        new BackgroundFill(Color.BLUE, new CornerRadii(2), new Insets(2))),
+                List.of(new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 15, false, Side.TOP, 10, false),
+                                            new BackgroundSize(15, 20, false, false, false, false)),
+                        new BackgroundImage(IMAGE_1, REPEAT, REPEAT,
+                                            new BackgroundPosition(Side.LEFT, 30, false, Side.TOP, 40, false),
+                                            new BackgroundSize(50, 60, false, false, false, false))));
+
+            assertEquals(expect, startValue.interpolate(endValue, 0.5));
+        }
+
+        @Test
+        public void interpolateBetweenEqualValuesReturnsStartInstance() {
+            var startValue = new Background(new BackgroundFill(Color.RED, new CornerRadii(10), new Insets(10)));
+            var endValue = new Background(new BackgroundFill(Color.RED, new CornerRadii(10), new Insets(10)));
+            assertSame(startValue, startValue.interpolate(endValue, 0.5));
+        }
+
+        @Test
+        public void interpolationFactorSmallerThanOrEqualToZeroReturnsStartInstance() {
+            var startValue = new Background(new BackgroundFill(Color.RED, new CornerRadii(10), new Insets(10)));
+            var endValue = new Background(new BackgroundFill(Color.GREEN, new CornerRadii(15), new Insets(20)));
+            assertSame(startValue, startValue.interpolate(endValue, 0));
+            assertSame(startValue, startValue.interpolate(endValue, -0.5));
+        }
+
+        @Test
+        public void interpolationFactorGreaterThanOrEqualToOneReturnsEndInstance() {
+            var startValue = new Background(new BackgroundFill(Color.RED, new CornerRadii(10), new Insets(10)));
+            var endValue = new Background(new BackgroundFill(Color.GREEN, new CornerRadii(15), new Insets(20)));
+            assertSame(endValue, startValue.interpolate(endValue, 1));
+            assertSame(endValue, startValue.interpolate(endValue, 1.5));
+        }
     }
 
     // TODO: What happens if the corner radii become so big that we would end up with a negative opaque
