@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,13 +34,10 @@ import javafx.scene.paint.CycleMethod;
 import javafx.scene.paint.LinearGradient;
 import javafx.scene.paint.Stop;
 import javafx.scene.Scene;
-import org.junit.Test;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.jupiter.api.Nested;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.*;
 
 public class LinearGradientTest {
 
@@ -81,13 +78,15 @@ public class LinearGradientTest {
         assertEquals(normalizedTwoStops, gradient.getStops());
     }
 
-    @Test(expected=UnsupportedOperationException.class)
+    @Test
     public void testGetStopsCannotChangeGradient() {
-        LinearGradient gradient = new LinearGradient(0, 0, 1, 1, true,
-                CycleMethod.NO_CYCLE, twoStopsWithNulls);
+        assertThrows(UnsupportedOperationException.class, () -> {
+            LinearGradient gradient = new LinearGradient(0, 0, 1, 1, true,
+                    CycleMethod.NO_CYCLE, twoStopsWithNulls);
 
-        List<Stop> returned = gradient.getStops();
-        returned.set(0, stop2);
+            List<Stop> returned = gradient.getStops();
+            returned.set(0, stop2);
+        });
     }
 
     @SuppressWarnings("unlikely-arg-type")
@@ -187,14 +186,18 @@ public class LinearGradientTest {
         assertSame(paint, Toolkit.getPaintAccessor().getPlatformPaint(gradient));
     }
 
-    @Test(expected=NullPointerException.class)
+    @Test
     public void testValueOfNullValue() {
-        LinearGradient.valueOf(null);
+        assertThrows(NullPointerException.class, () -> {
+            LinearGradient.valueOf(null);
+        });
     }
 
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void testValueOfEmpty() {
-        LinearGradient.valueOf("");
+        assertThrows(IllegalArgumentException.class, () -> {
+            LinearGradient.valueOf("");
+        });
     }
 
     @Test
@@ -460,4 +463,91 @@ public class LinearGradientTest {
         lGradient = (LinearGradient) region.backgroundProperty().get().getFills().get(0).getFill();
         assertEquals(CycleMethod.REPEAT, lGradient.getCycleMethod());
     }
+
+    @Nested
+    class InterpolationTest {
+        @Test
+        public void interpolateBetweenDifferentValuesReturnsNewInstance() {
+            var startValue = new LinearGradient(
+                10, 20, 30, 40,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLACK), new Stop(1, Color.WHITE)));
+
+            var endValue = new LinearGradient(
+                20, 40, 60, 80,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.WHITE), new Stop(1, Color.BLACK)));
+
+            var expected = new LinearGradient(
+                15, 30, 45, 60,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.gray(0.5)), new Stop(1, Color.gray(0.5))));
+
+            assertEquals(expected, startValue.interpolate(endValue, 0.5));
+        }
+
+        @Test
+        public void interpolateBetweenProportionalAndNonProportionalReturnsStartValuesOrEndValues() {
+            var startValue = new LinearGradient(
+                10, 20, 30, 40,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLUE)));
+
+            var endValue = new LinearGradient(
+                10, 20, 30, 40,
+                false, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLUE)));
+
+            assertSame(startValue, startValue.interpolate(endValue, 0.25));
+            assertSame(endValue, startValue.interpolate(endValue, 0.5));
+            assertSame(endValue, startValue.interpolate(endValue, 0.75));
+        }
+
+        @Test
+        public void interpolateBetweenTwoEqualValuesReturnsStartInstance() {
+            var startValue = new LinearGradient(
+                10, 20, 30, 40,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLUE)));
+
+            var endValue = new LinearGradient(
+                10, 20, 30, 40,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLUE)));
+
+            assertSame(startValue, startValue.interpolate(endValue, 0.5));
+        }
+
+        @Test
+        public void interpolationFactorSmallerThanOrEqualToZeroReturnsStartInstance() {
+            var startValue = new LinearGradient(
+                10, 20, 30, 40,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLUE)));
+
+            var endValue = new LinearGradient(
+                20, 40, 60, 80,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.RED)));
+
+            assertSame(startValue, startValue.interpolate(endValue, 0));
+            assertSame(startValue, startValue.interpolate(endValue, -1));
+        }
+
+        @Test
+        public void interpolationFactorGreaterThanOrEqualToOneReturnsEndInstance() {
+            var startValue = new LinearGradient(
+                10, 20, 30, 40,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.BLUE)));
+
+            var endValue = new LinearGradient(
+                20, 40, 60, 80,
+                true, CycleMethod.NO_CYCLE,
+                List.of(new Stop(0, Color.RED)));
+
+            assertSame(endValue, startValue.interpolate(endValue, 1));
+            assertSame(endValue, startValue.interpolate(endValue, 1.5));
+        }
+    }
 }
