@@ -190,6 +190,8 @@
 #define g_macro__has_attribute_fallthrough G_GNUC_CHECK_VERSION (6, 0)
 #define g_macro__has_attribute_may_alias G_GNUC_CHECK_VERSION (3, 3)
 #define g_macro__has_attribute_warn_unused_result G_GNUC_CHECK_VERSION (3, 4)
+#define g_macro__has_attribute_no_sanitize_address 0
+#define g_macro__has_attribute_ifunc 0
 
 #endif
 
@@ -1237,11 +1239,9 @@
 #if G_GNUC_CHECK_VERSION(2, 0) && defined(__OPTIMIZE__)
 #define _G_BOOLEAN_EXPR_IMPL(uniq, expr)        \
  G_GNUC_EXTENSION ({                            \
-   int G_PASTE (_g_boolean_var_, uniq);         \
+   int G_PASTE (_g_boolean_var_, uniq) = 0;     \
    if (expr)                                    \
       G_PASTE (_g_boolean_var_, uniq) = 1;      \
-   else                                         \
-      G_PASTE (_g_boolean_var_, uniq) = 0;      \
    G_PASTE (_g_boolean_var_, uniq);             \
 })
 #define _G_BOOLEAN_EXPR(expr) _G_BOOLEAN_EXPR_IMPL (__COUNTER__, expr)
