@@ -253,8 +253,8 @@ protect_argv_string (const gchar *string)
 {
   const gchar *p = string;
   gchar *retval, *q;
-  gint len = 0;
-  gint pre_bslash = 0;
+  size_t len = 0;
+  size_t pre_bslash = 0;
   gboolean need_dblquotes = FALSE;
   while (*p)
     {
