@@ -983,4 +983,38 @@
 #define GOBJECT_AVAILABLE_MACRO_IN_2_80
 #define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_80
 #define GOBJECT_AVAILABLE_TYPE_IN_2_80
-#endif
\ No newline at end of file
+#endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_84
+#define GOBJECT_DEPRECATED_IN_2_84 GOBJECT_DEPRECATED
+#define GOBJECT_DEPRECATED_IN_2_84_FOR(f) GOBJECT_DEPRECATED_FOR (f)
+#define GOBJECT_DEPRECATED_MACRO_IN_2_84 GLIB_DEPRECATED_MACRO
+#define GOBJECT_DEPRECATED_MACRO_IN_2_84_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_84 GLIB_DEPRECATED_ENUMERATOR
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_84_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_84 GLIB_DEPRECATED_TYPE
+#define GOBJECT_DEPRECATED_TYPE_IN_2_84_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GOBJECT_DEPRECATED_IN_2_84 _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_IN_2_84_FOR(f) _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_MACRO_IN_2_84
+#define GOBJECT_DEPRECATED_MACRO_IN_2_84_FOR(f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_84
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_84_FOR(f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_84
+#define GOBJECT_DEPRECATED_TYPE_IN_2_84_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_84
+#define GOBJECT_AVAILABLE_IN_2_84 GOBJECT_UNAVAILABLE (2, 84)
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_84 GLIB_UNAVAILABLE_STATIC_INLINE (2, 84)
+#define GOBJECT_AVAILABLE_MACRO_IN_2_84 GLIB_UNAVAILABLE_MACRO (2, 84)
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_84 GLIB_UNAVAILABLE_ENUMERATOR (2, 84)
+#define GOBJECT_AVAILABLE_TYPE_IN_2_84 GLIB_UNAVAILABLE_TYPE (2, 84)
+#else
+#define GOBJECT_AVAILABLE_IN_2_84 _GOBJECT_EXTERN
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_84
+#define GOBJECT_AVAILABLE_MACRO_IN_2_84
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_84
+#define GOBJECT_AVAILABLE_TYPE_IN_2_84
+#endif
