@@ -1,5 +1,5 @@
 /* -----------------------------------------------------------------------
-   types.c - Copyright (c) 1996, 1998, 2024  Red Hat, Inc.
+   types.c - Copyright (c) 1996, 1998, 2024, 2025  Red Hat, Inc.
 
    Predefined ffi_types needed by libffi.
 
@@ -31,6 +31,28 @@
 #include <ffi.h>
 #include <ffi_common.h>
 
+/* Return a version string. */
+const char *ffi_get_version (void)
+{
+  return FFI_VERSION_STRING;
+}
+
+/* Return the version as an unsigned long value: (x * 10000 + y * 100 + z) */
+unsigned long ffi_get_version_number (void)
+{
+  return FFI_VERSION_NUMBER;
+}
+
+unsigned int ffi_get_default_abi (void)
+{
+  return FFI_DEFAULT_ABI;
+}
+
+size_t ffi_get_closure_size (void)
+{
+  return sizeof(ffi_closure);
+}
+
 /* Type definitions */
 
 #define FFI_TYPEDEF(name, type, id, maybe_const)\
