@@ -1572,8 +1572,9 @@ gst_aiff_parse_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
 
       if (aiff->state != AIFF_PARSE_HEADER)
         break;
-
-      /* otherwise fall-through */
+#ifndef GSTREAMER_LITE
+      G_GNUC_FALLTHROUGH;
+#endif // GSTREAMER_LITE
     case AIFF_PARSE_HEADER:
       GST_INFO_OBJECT (aiff, "AIFF_PARSE_HEADER");
       if ((ret = gst_aiff_parse_stream_headers (aiff)) != GST_FLOW_OK)
@@ -1585,7 +1586,7 @@ gst_aiff_parse_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
       aiff->state = AIFF_PARSE_DATA;
       GST_INFO_OBJECT (aiff, "AIFF_PARSE_DATA");
 
-      /* fall-through */
+      /* FALLTHROUGH */
     case AIFF_PARSE_DATA:
       if ((ret = gst_aiff_parse_stream_data (aiff)) != GST_FLOW_OK)
         goto done;
