@@ -57,6 +57,10 @@
 #endif // GSTREAMER_LITE
 #include <glib/gi18n-lib.h>
 
+#ifdef HAVE_VALGRIND
+# include <valgrind/valgrind.h>
+#endif
+
 #ifndef ESTRPIPE
 #define ESTRPIPE EPIPE
 #endif
@@ -144,6 +148,12 @@ gst_alsasink_finalise (GObject * object)
   }
   g_mutex_unlock (&output_mutex);
 
+#ifdef HAVE_VALGRIND
+  if (RUNNING_ON_VALGRIND) {
+    snd_config_update_free_global ();
+  }
+#endif
+
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
