@@ -1213,8 +1213,8 @@ static guint64
 gst_audio_base_sink_get_offset (GstAudioBaseSink * sink)
 {
   guint64 sample, sps;
-  gint writeseg, segdone;
-  gint diff;
+  guint64 writeseg, segdone;
+  gint64 diff;
 
   /* assume we can append to the previous sample */
   sample = sink->next_sample;
@@ -1229,8 +1229,8 @@ gst_audio_base_sink_get_offset (GstAudioBaseSink * sink)
   writeseg = sample / sps;
 
   /* get the currently processed segment */
-  segdone = g_atomic_int_get (&sink->ringbuffer->segdone)
-      - sink->ringbuffer->segbase;
+  segdone = gst_audio_ring_buffer_get_segdone (sink->ringbuffer)
+      - gst_audio_ring_buffer_get_segbase (sink->ringbuffer);
 
   /* see how far away it is from the write segment */
   diff = writeseg - segdone;
@@ -1276,7 +1276,7 @@ gst_audio_base_sink_custom_slaving (GstAudioBaseSink * sink,
 {
   GstClockTime cinternal, cexternal, crate_num, crate_denom;
   GstClockTime etime, itime;
-  GstClockTimeDiff requested_skew;
+  GstClockTimeDiff requested_skew, drift;
   gint driftsamples;
   gint64 last_align;
 
@@ -1314,10 +1314,18 @@ gst_audio_base_sink_custom_slaving (GstAudioBaseSink * sink,
   }
 
   if (requested_skew > 0) {
-    cexternal = (cexternal > requested_skew) ? (cexternal - requested_skew) : 0;
+    /* Move the external time backward by the requested skew, but don't ever
+     * go negative. Moving the requested skew by the same distance defines
+     * the new clock skew window center point. This allows the clock to
+     * drift equally into either direction after the correction. */
+    if (G_LIKELY (cexternal > requested_skew))
+      drift = requested_skew;
+    else
+      drift = cexternal;
 
-    driftsamples =
-        (sink->ringbuffer->spec.info.rate * requested_skew) / GST_SECOND;
+    cexternal -= drift;
+
+    driftsamples = (sink->ringbuffer->spec.info.rate * drift) / GST_SECOND;
     last_align = sink->priv->last_align;
 
     /* if we were aligning in the wrong direction or we aligned more than what we
@@ -1332,10 +1340,10 @@ gst_audio_base_sink_custom_slaving (GstAudioBaseSink * sink,
     gst_clock_set_calibration (sink->provided_clock, cinternal, cexternal,
         crate_num, crate_denom);
   } else if (requested_skew < 0) {
-    cexternal += ABS (requested_skew);
+    drift = -requested_skew;
+    cexternal += drift;
 
-    driftsamples =
-        (sink->ringbuffer->spec.info.rate * ABS (requested_skew)) / GST_SECOND;
+    driftsamples = (sink->ringbuffer->spec.info.rate * drift) / GST_SECOND;
     last_align = sink->priv->last_align;
 
     /* if we were aligning in the wrong direction or we aligned more than what we
@@ -1742,7 +1750,8 @@ gst_audio_base_sink_get_alignment (GstAudioBaseSink * sink,
   gint64 align;
   gint64 sample_diff;
   gint64 max_sample_diff;
-  gint segdone = g_atomic_int_get (&ringbuf->segdone) - ringbuf->segbase;
+  guint64 segdone = gst_audio_ring_buffer_get_segdone (sink->ringbuffer)
+      - gst_audio_ring_buffer_get_segbase (sink->ringbuffer);
   gint64 samples_done = segdone * (gint64) ringbuf->samples_per_seg;
   gint64 headroom = sample_offset - samples_done;
   gboolean allow_align = TRUE;
