@@ -48,6 +48,124 @@
 GST_DEBUG_CATEGORY_STATIC (gst_audio_ring_buffer_debug);
 #define GST_CAT_DEFAULT gst_audio_ring_buffer_debug
 
+/* TODO: use GLib's once https://gitlab.gnome.org/GNOME/glib/issues/1076 lands, or
+ * use C11 atomics once MS arrives in this century.
+ *
+ * We also assume that signed overflow just wraps around because unfortunately
+ * there are no unsigned versions in MSVC. */
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L && !defined(__STDC_NO_ATOMICS__)
+#include <stdatomic.h>
+
+static inline guint64
+gst_atomic_uint64_add (guint64 * atomic, guint64 n)
+{
+  return atomic_fetch_add ((_Atomic guint64 *) atomic, n);
+}
+
+static inline void
+gst_atomic_uint64_set (guint64 * atomic, guint64 n)
+{
+  atomic_store ((_Atomic guint64 *) atomic, n);
+}
+
+static inline guint64
+gst_atomic_uint64_get (guint64 * atomic)
+{
+  gint64 ret = atomic_load ((_Atomic guint64 *) atomic);
+  return ret;
+}
+#elif defined(__GCC_HAVE_SYNC_COMPARE_AND_SWAP_8)
+static inline guint64
+gst_atomic_uint64_add (guint64 * atomic, guint64 n)
+{
+  return __sync_fetch_and_add (atomic, n);
+}
+
+static inline void
+gst_atomic_uint64_set (guint64 * atomic, guint64 n)
+{
+  __sync_synchronize ();
+  __asm__ __volatile__ ("":::"memory");
+  *atomic = n;
+}
+
+static inline guint64
+gst_atomic_uint64_get (guint64 * atomic)
+{
+  gint64 ret = *atomic;
+  __sync_synchronize ();
+  __asm__ __volatile__ ("":::"memory");
+  return ret;
+}
+#elif defined (G_PLATFORM_WIN32)
+#include <windows.h>
+static inline guint64
+gst_atomic_uint64_add (guint64 * atomic, guint64 n)
+{
+  return InterlockedExchangeAdd64 ((gint64 *) atomic, (gint64) n);
+}
+
+static inline void
+gst_atomic_uint64_set (guint64 * atomic, guint64 n)
+{
+  *atomic = n;
+  MemoryBarrier ();
+}
+
+static inline guint64
+gst_atomic_uint64_get (guint64 * atomic)
+{
+  MemoryBarrier ();
+  return *atomic;
+}
+#else
+#define STR_TOKEN(s) #s
+#define STR(s) STR_TOKEN(s)
+#pragma message "No 64-bit atomic int defined for this " STR(TARGET_CPU) " platform/toolchain!"
+
+#define NO_64BIT_ATOMIC_INT_FOR_PLATFORM
+G_LOCK_DEFINE_STATIC (atomic_lock);
+static inline guint64
+gst_atomic_uint64_add (guint64 * atomic, guint64 n)
+{
+  guint64 ret;
+
+  G_LOCK (atomic_lock);
+  *atomic += n;
+  ret = *atomic;
+  G_UNLOCK (atomic_lock);
+
+  return ret;
+}
+
+static inline void
+gst_atomic_uint64_set (guint64 * atomic, guint64 n)
+{
+  G_LOCK (atomic_lock);
+  *atomic = n;
+  G_UNLOCK (atomic_lock);
+}
+
+static inline guint64
+gst_atomic_uint64_get (gint64 * atomic)
+{
+  guint64 ret;
+
+  G_LOCK (atomic_lock);
+  ret = *atomic;
+  G_UNLOCK (atomic_lock);
+
+  return ret;
+}
+#endif
+
+struct _GstAudioRingBufferPrivate
+{
+  /* ATOMIC */
+  guint64 segdone;
+  guint64 segbase;
+};
+
 static void gst_audio_ring_buffer_dispose (GObject * object);
 static void gst_audio_ring_buffer_finalize (GObject * object);
 
@@ -57,7 +175,7 @@ static guint default_commit (GstAudioRingBuffer * buf, guint64 * sample,
     guint8 * data, gint in_samples, gint out_samples, gint * accum);
 
 /* ringbuffer abstract base class */
-G_DEFINE_ABSTRACT_TYPE (GstAudioRingBuffer, gst_audio_ring_buffer,
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GstAudioRingBuffer, gst_audio_ring_buffer,
     GST_TYPE_OBJECT);
 
 static void
@@ -82,6 +200,7 @@ gst_audio_ring_buffer_class_init (GstAudioRingBufferClass * klass)
 static void
 gst_audio_ring_buffer_init (GstAudioRingBuffer * ringbuffer)
 {
+  ringbuffer->priv = gst_audio_ring_buffer_get_instance_private (ringbuffer);
   ringbuffer->open = FALSE;
   ringbuffer->acquired = FALSE;
   g_atomic_int_set (&ringbuffer->state, GST_AUDIO_RING_BUFFER_STATE_STOPPED);
@@ -91,6 +210,8 @@ gst_audio_ring_buffer_init (GstAudioRingBuffer * ringbuffer)
   ringbuffer->flushing = TRUE;
   ringbuffer->segbase = 0;
   ringbuffer->segdone = 0;
+  ringbuffer->priv->segbase = 0;
+  ringbuffer->priv->segdone = 0;
 }
 
 static void
@@ -811,13 +932,17 @@ gst_audio_ring_buffer_release (GstAudioRingBuffer * buf)
     res = rclass->release (buf);
 
   /* signal any waiters */
-  GST_DEBUG_OBJECT (buf, "signal waiter");
-  GST_AUDIO_RING_BUFFER_SIGNAL (buf);
+  if (g_atomic_int_compare_and_exchange (&buf->waiting, 1, 0)) {
+    GST_DEBUG_OBJECT (buf, "signal waiter");
+    GST_AUDIO_RING_BUFFER_SIGNAL (buf);
+  }
 
   if (G_UNLIKELY (!res))
     goto release_failed;
 
+  gst_atomic_uint64_set (&buf->priv->segdone, 0);
   g_atomic_int_set (&buf->segdone, 0);
+  buf->priv->segbase = 0;
   buf->segbase = 0;
   g_free (buf->empty_seg);
   buf->empty_seg = NULL;
@@ -1151,8 +1276,10 @@ gst_audio_ring_buffer_pause_unlocked (GstAudioRingBuffer * buf)
     goto not_started;
 
   /* signal any waiters */
-  GST_DEBUG_OBJECT (buf, "signal waiter");
-  GST_AUDIO_RING_BUFFER_SIGNAL (buf);
+  if (g_atomic_int_compare_and_exchange (&buf->waiting, 1, 0)) {
+    GST_DEBUG_OBJECT (buf, "signal waiter");
+    GST_AUDIO_RING_BUFFER_SIGNAL (buf);
+  }
 
   rclass = GST_AUDIO_RING_BUFFER_GET_CLASS (buf);
   if (G_LIKELY (rclass->pause))
@@ -1268,8 +1395,10 @@ gst_audio_ring_buffer_stop (GstAudioRingBuffer * buf)
   }
 
   /* signal any waiters */
-  GST_DEBUG_OBJECT (buf, "signal waiter");
-  GST_AUDIO_RING_BUFFER_SIGNAL (buf);
+  if (g_atomic_int_compare_and_exchange (&buf->waiting, 1, 0)) {
+    GST_DEBUG_OBJECT (buf, "signal waiter");
+    GST_AUDIO_RING_BUFFER_SIGNAL (buf);
+  }
 
   rclass = GST_AUDIO_RING_BUFFER_GET_CLASS (buf);
   if (G_LIKELY (rclass->stop))
@@ -1348,16 +1477,16 @@ not_acquired:
 guint64
 gst_audio_ring_buffer_samples_done (GstAudioRingBuffer * buf)
 {
-  gint segdone;
+  guint64 segdone;
   guint64 samples;
 
   g_return_val_if_fail (GST_IS_AUDIO_RING_BUFFER (buf), 0);
 
   /* get the amount of segments we processed */
-  segdone = g_atomic_int_get (&buf->segdone);
+  segdone = gst_atomic_uint64_get (&buf->priv->segdone);
 
   /* convert to samples */
-  samples = ((guint64) segdone) * buf->samples_per_seg;
+  samples = segdone * buf->samples_per_seg;
 
   return samples;
 }
@@ -1379,6 +1508,8 @@ gst_audio_ring_buffer_samples_done (GstAudioRingBuffer * buf)
 void
 gst_audio_ring_buffer_set_sample (GstAudioRingBuffer * buf, guint64 sample)
 {
+  guint64 segdone;
+
   g_return_if_fail (GST_IS_AUDIO_RING_BUFFER (buf));
 
   if (sample == -1)
@@ -1390,12 +1521,69 @@ gst_audio_ring_buffer_set_sample (GstAudioRingBuffer * buf, guint64 sample)
   /* FIXME, we assume the ringbuffer can restart at a random
    * position, round down to the beginning and keep track of
    * offset when calculating the processed samples. */
-  buf->segbase = buf->segdone - sample / buf->samples_per_seg;
+  segdone = gst_atomic_uint64_get (&buf->priv->segdone);
+  buf->priv->segbase = segdone - sample / buf->samples_per_seg;
+  buf->segbase = buf->priv->segbase;
 
   gst_audio_ring_buffer_clear_all (buf);
 
-  GST_DEBUG_OBJECT (buf, "set sample to %" G_GUINT64_FORMAT ", segbase %d",
-      sample, buf->segbase);
+  GST_DEBUG_OBJECT (buf,
+      "set sample to %" G_GUINT64_FORMAT ", segbase %" G_GUINT64_FORMAT, sample,
+      buf->priv->segbase);
+}
+
+/**
+ * gst_audio_ring_buffer_set_segdone:
+ * @buf: the #GstAudioRingBuffer to use
+ * @segdone: the segment number to set
+ *
+ * Sets the current segment number of the ringbuffer.
+ *
+ * MT safe.
+ *
+ * Since: 1.26
+ */
+void
+gst_audio_ring_buffer_set_segdone (GstAudioRingBuffer * buf, guint64 segdone)
+{
+  gst_atomic_uint64_set (&buf->priv->segdone, segdone);
+  g_atomic_int_set (&buf->segdone, segdone);
+}
+
+/**
+ * gst_audio_ring_buffer_get_segdone:
+ * @buf: the #GstAudioRingBuffer to use
+ *
+ * Gets the current segment number of the ringbuffer.
+ *
+ * MT safe.
+ *
+ * Returns: Current segment number of the ringbuffer.
+ *
+ * Since: 1.26
+ */
+guint64
+gst_audio_ring_buffer_get_segdone (GstAudioRingBuffer * buf)
+{
+  return gst_atomic_uint64_get (&buf->priv->segdone);
+}
+
+/**
+ * gst_audio_ring_buffer_get_segbase:
+ * @buf: the #GstAudioRingBuffer to use
+ *
+ * Gets the current segment base number of the ringbuffer.
+ *
+ * MT safe.
+ *
+ * Returns: Current segment base number of the ringbuffer.
+ *
+ * Since: 1.26
+ */
+guint64
+gst_audio_ring_buffer_get_segbase (GstAudioRingBuffer * buf)
+{
+  return gst_atomic_uint64_get (&buf->priv->segbase);
 }
 
 /**
@@ -1445,7 +1633,7 @@ gst_audio_ring_buffer_clear_all (GstAudioRingBuffer * buf)
 static gboolean
 wait_segment (GstAudioRingBuffer * buf)
 {
-  gint segments;
+  guint64 segments;
   gboolean wait = TRUE;
 
   /* buffer must be started now or we deadlock since nobody is reading */
@@ -1456,12 +1644,12 @@ wait_segment (GstAudioRingBuffer * buf)
       goto no_start;
 
     GST_DEBUG_OBJECT (buf, "start!");
-    segments = g_atomic_int_get (&buf->segdone);
+    segments = gst_atomic_uint64_get (&buf->priv->segdone);
     gst_audio_ring_buffer_start (buf);
 
     /* After starting, the writer may have wrote segments already and then we
      * don't need to wait anymore */
-    if (G_LIKELY (g_atomic_int_get (&buf->segdone) != segments))
+    if (G_LIKELY (gst_atomic_uint64_get (&buf->priv->segdone) != segments))
       wait = FALSE;
   }
 
@@ -1625,10 +1813,10 @@ static guint
 default_commit (GstAudioRingBuffer * buf, guint64 * sample,
     guint8 * data, gint in_samples, gint out_samples, gint * accum)
 {
-  gint segdone;
+  guint64 segdone;
   gint segsize, segtotal, channels, bps, bpf, sps;
   guint8 *dest, *data_end;
-  gint writeseg, sampleoff;
+  guint64 writeseg, sampleoff;
   gint *toprocess;
   gint inr, outr;
   gboolean reverse;
@@ -1677,17 +1865,20 @@ default_commit (GstAudioRingBuffer * buf, guint64 * sample,
     gboolean skip;
 
     while (TRUE) {
-      gint diff;
+      gint64 diff;
 
       /* get the currently processed segment */
-      segdone = g_atomic_int_get (&buf->segdone) - buf->segbase;
+      segdone =
+          gst_atomic_uint64_get (&buf->priv->segdone) - buf->priv->segbase;
 
       /* see how far away it is from the write segment */
       diff = writeseg - segdone;
 
       GST_DEBUG_OBJECT (buf,
-          "pointer at %d, write to %d-%d, diff %d, segtotal %d, segsize %d, base %d",
-          segdone, writeseg, sampleoff, diff, segtotal, segsize, buf->segbase);
+          "pointer at %" G_GUINT64_FORMAT ", write to %" G_GUINT64_FORMAT "-%"
+          G_GUINT64_FORMAT ", diff %" G_GINT64_FORMAT
+          ", segtotal %d, segsize %d, base %" G_GUINT64_FORMAT, segdone,
+          writeseg, sampleoff, diff, segtotal, segsize, buf->priv->segbase);
 
       /* segment too far ahead, writer too slow, we need to drop, hopefully UNLIKELY */
       if (G_UNLIKELY (diff < 0)) {
@@ -1716,7 +1907,8 @@ default_commit (GstAudioRingBuffer * buf, guint64 * sample,
     d_end = d + avail;
     *sample += avail / bpf;
 
-    GST_DEBUG_OBJECT (buf, "write @%p seg %d, sps %d, off %d, avail %d",
+    GST_DEBUG_OBJECT (buf,
+        "write @%p seg %d, sps %d, off %" G_GUINT64_FORMAT ", avail %d",
         dest + ws * segsize, ws, sps, sampleoff, avail);
 
     if (need_reorder) {
@@ -1859,8 +2051,8 @@ guint
 gst_audio_ring_buffer_read (GstAudioRingBuffer * buf, guint64 sample,
     guint8 * data, guint len, GstClockTime * timestamp)
 {
-  gint segdone;
-  gint segsize, segtotal, channels, bps, bpf, sps, readseg = 0;
+  guint64 segdone, readseg = 0;
+  gint segsize, segtotal, channels, bps, bpf, sps;
   guint8 *dest;
   guint to_read;
   gboolean need_reorder;
@@ -1890,10 +2082,11 @@ gst_audio_ring_buffer_read (GstAudioRingBuffer * buf, guint64 sample,
     sampleoff = (sample % sps);
 
     while (TRUE) {
-      gint diff;
+      gint64 diff;
 
       /* get the currently processed segment */
-      segdone = g_atomic_int_get (&buf->segdone) - buf->segbase;
+      segdone =
+          gst_atomic_uint64_get (&buf->priv->segdone) - buf->priv->segbase;
 
       /* see how far away it is from the read segment, normally segdone (where
        * the hardware is writing) is bigger than readseg (where software is
@@ -1901,10 +2094,10 @@ gst_audio_ring_buffer_read (GstAudioRingBuffer * buf, guint64 sample,
       diff = segdone - readseg;
 
       GST_DEBUG_OBJECT
-          (buf, "pointer at %d, sample %" G_GUINT64_FORMAT
-          ", read from %d-%d, to_read %d, diff %d, segtotal %d, segsize %d",
-          segdone, sample, readseg, sampleoff, to_read, diff, segtotal,
-          segsize);
+          (buf, "pointer at %" G_GUINT64_FORMAT ", sample %" G_GUINT64_FORMAT
+          ", read from %" G_GUINT64_FORMAT "-%d, to_read %d, diff %"
+          G_GINT64_FORMAT ", segtotal %d, segsize %d", segdone, sample, readseg,
+          sampleoff, to_read, diff, segtotal, segsize);
 
       /* segment too far ahead, reader too slow */
       if (G_UNLIKELY (diff >= segtotal)) {
@@ -1928,7 +2121,8 @@ gst_audio_ring_buffer_read (GstAudioRingBuffer * buf, guint64 sample,
     readseg = readseg % segtotal;
     sampleslen = MIN (sps - sampleoff, to_read);
 
-    GST_DEBUG_OBJECT (buf, "read @%p seg %d, off %d, sampleslen %d",
+    GST_DEBUG_OBJECT (buf,
+        "read @%p seg %" G_GUINT64_FORMAT ", off %d, sampleslen %d",
         dest + readseg * segsize, readseg, sampleoff, sampleslen);
 
     if (need_reorder) {
@@ -1957,7 +2151,8 @@ gst_audio_ring_buffer_read (GstAudioRingBuffer * buf, guint64 sample,
   if (buf->timestamps && timestamp) {
     *timestamp = buf->timestamps[readseg % segtotal];
     GST_DEBUG_OBJECT (buf, "Retrieved timestamp %" GST_TIME_FORMAT
-        " @ %d", GST_TIME_ARGS (*timestamp), readseg % segtotal);
+        " @ %" G_GUINT64_FORMAT, GST_TIME_ARGS (*timestamp),
+        readseg % segtotal);
   }
 
   return len - to_read;
@@ -1990,7 +2185,7 @@ gst_audio_ring_buffer_prepare_read (GstAudioRingBuffer * buf, gint * segment,
     guint8 ** readptr, gint * len)
 {
   guint8 *data;
-  gint segdone;
+  guint64 segdone;
 
   g_return_val_if_fail (GST_IS_AUDIO_RING_BUFFER (buf), FALSE);
 
@@ -2008,14 +2203,15 @@ gst_audio_ring_buffer_prepare_read (GstAudioRingBuffer * buf, gint * segment,
   data = buf->memory;
 
   /* get the position of the pointer */
-  segdone = g_atomic_int_get (&buf->segdone);
+  segdone = gst_atomic_uint64_get (&buf->priv->segdone);
 
   *segment = segdone % buf->spec.segtotal;
   *len = buf->spec.segsize;
   *readptr = data + *segment * *len;
 
-  GST_LOG_OBJECT (buf, "prepare read from segment %d (real %d) @%p",
-      *segment, segdone, *readptr);
+  GST_LOG_OBJECT (buf,
+      "prepare read from segment %d (real %" G_GUINT64_FORMAT ") @%p", *segment,
+      segdone, *readptr);
 
   /* callback to fill the memory with data, for pull based
    * scheduling. */
@@ -2041,6 +2237,7 @@ gst_audio_ring_buffer_advance (GstAudioRingBuffer * buf, guint advance)
   g_return_if_fail (GST_IS_AUDIO_RING_BUFFER (buf));
 
   /* update counter */
+  gst_atomic_uint64_add (&buf->priv->segdone, advance);
   g_atomic_int_add (&buf->segdone, advance);
 
   /* the lock is already taken when the waiting flag is set,
