@@ -969,6 +969,19 @@ gst_riff_create_video_caps (guint32 codec_fcc,
 
       break;
 
+    case GST_MAKE_FOURCC ('L', 'A', 'G', 'S'):
+      caps = gst_caps_new_empty_simple ("video/x-lagarith");
+      if (codec_name)
+        *codec_name = g_strdup ("Lagarith lossless video codec");
+      break;
+
+    case GST_MAKE_FOURCC ('M', '1', '0', '1'):
+    case GST_MAKE_FOURCC ('M', '1', '0', '2'):
+      caps = gst_caps_new_empty_simple ("video/x-m101");
+      if (codec_name)
+        *codec_name = g_strdup ("Matrox uncompressed SD video codec");
+      break;
+
     default:
       GST_WARNING ("Unknown video fourcc %" GST_FOURCC_FORMAT,
           GST_FOURCC_ARGS (codec_fcc));
@@ -1219,18 +1232,24 @@ gst_riff_wavext_get_default_channel_mask (guint nchannels)
     case 11:
       channel_mask |= 0x00400;
       channel_mask |= 0x00200;
+      /* FALLTHROUGH */
     case 9:
       channel_mask |= 0x00100;
+      /* FALLTHROUGH */
     case 8:
       channel_mask |= 0x00080;
       channel_mask |= 0x00040;
+      /* FALLTHROUGH */
     case 6:
       channel_mask |= 0x00020;
       channel_mask |= 0x00010;
+      /* FALLTHROUGH */
     case 4:
       channel_mask |= 0x00008;
+      /* FALLTHROUGH */
     case 3:
       channel_mask |= 0x00004;
+      /* FALLTHROUGH */
     case 2:
       channel_mask |= 0x00002;
       channel_mask |= 0x00001;
@@ -1323,8 +1342,9 @@ gst_riff_create_audio_caps (guint16 codec_id,
          * so either we calculate the bitrate or mark it as invalid as this
          * would probably confuse timing */
         strf->av_bps = 0;
-        if (strf->channels != 0 && strf->rate != 0 && strf->blockalign != 0) {
-          int spb = ((strf->blockalign - strf->channels * 7) / 2) * 2;
+        if (strf->channels != 0 && strf->rate != 0 && strf->blockalign != 0 &&
+            (strf->blockalign / strf->channels) >= 7) {
+          int spb = ((strf->blockalign / strf->channels) - 7) * 2 + 2;
           strf->av_bps =
               gst_util_uint64_scale_int (strf->rate, strf->blockalign, spb);
           GST_DEBUG ("fixing av_bps to calculated value %d of MS ADPCM",
@@ -1445,8 +1465,9 @@ gst_riff_create_audio_caps (guint16 codec_id,
          * header, so either we calculate the bitrate or mark it as invalid
          * as this would probably confuse timing */
         strf->av_bps = 0;
-        if (strf->channels != 0 && strf->rate != 0 && strf->blockalign != 0) {
-          int spb = ((strf->blockalign - strf->channels * 4) / 2) * 2;
+        if (strf->channels != 0 && strf->rate != 0 && strf->blockalign != 0 &&
+            (strf->blockalign / strf->channels) >= 4) {
+          int spb = ((strf->blockalign / strf->channels) - 4) * 2 + 1;
           strf->av_bps =
               gst_util_uint64_scale_int (strf->rate, strf->blockalign, spb);
           GST_DEBUG ("fixing av_bps to calculated value %d of IMA DVI ADPCM",
