@@ -298,6 +298,39 @@ G_BEGIN_DECLS
  */
 #define GST_TAG_CAPTURING_WHITE_BALANCE       "capturing-white-balance"
 
+/**
+ * GST_TAG_CAPTURING_LIGHT_SOURCE:
+ *
+ * Light source used when capturing an image. (string)
+ *
+ * The allowed values are:
+ *   "unknown"
+ *   "daylight"
+ *   "fluorescent"
+ *   "tungsten"
+ *   "flash"
+ *   "fine-weather"
+ *   "cloudy-weather"
+ *   "shade"
+ *   "daylight-fluorescent"
+ *   "day-white-fluorescent"
+ *   "cool-white-fluorescent"
+ *   "white-fluorescent"
+ *   "warm-white-fluorescent"
+ *   "standard-light-A"
+ *   "standard-light-B"
+ *   "standard-light-C"
+ *   "D55"
+ *   "D65"
+ *   "D75"
+ *   "D50"
+ *   "iso-studio-tungsten"
+ *   "other"
+ *
+ * Since: 1.26
+ */
+#define GST_TAG_CAPTURING_LIGHT_SOURCE        "capturing-light-source"
+
 /**
  * GST_TAG_CAPTURING_CONTRAST:
  *
