@@ -170,10 +170,8 @@ set_default_colorimetry (GstVideoInfo * info)
 
   if (GST_VIDEO_FORMAT_INFO_IS_YUV (finfo)) {
     if (info->height > 576) {
-      info->chroma_site = GST_VIDEO_CHROMA_SITE_H_COSITED;
       info->colorimetry = default_color[DEFAULT_YUV_HD];
     } else {
-      info->chroma_site = GST_VIDEO_CHROMA_SITE_NONE;
       info->colorimetry = default_color[DEFAULT_YUV_SD];
     }
   } else if (GST_VIDEO_FORMAT_INFO_IS_GRAY (finfo)) {
@@ -186,7 +184,7 @@ set_default_colorimetry (GstVideoInfo * info)
 }
 
 static gboolean
-validate_colorimetry (GstVideoInfo * info)
+validate_colorimetry (const GstVideoInfo * info)
 {
   const GstVideoFormatInfo *finfo = info->finfo;
 
@@ -209,6 +207,48 @@ validate_colorimetry (GstVideoInfo * info)
   return TRUE;
 }
 
+static void
+set_default_chroma_site (GstVideoInfo * info)
+{
+  const GstVideoFormatInfo *finfo = info->finfo;
+
+  if (GST_VIDEO_FORMAT_INFO_IS_YUV (finfo)) {
+    if (info->height > 576) {
+      info->chroma_site = GST_VIDEO_CHROMA_SITE_H_COSITED;
+    } else {
+      info->chroma_site = GST_VIDEO_CHROMA_SITE_NONE;
+    }
+  } else {
+    info->chroma_site = GST_VIDEO_CHROMA_SITE_UNKNOWN;
+  }
+}
+
+static gboolean
+validate_chroma_site (const GstVideoInfo * info)
+{
+  const GstVideoFormatInfo *finfo = info->finfo;
+
+  if (GST_VIDEO_FORMAT_INFO_IS_YUV (finfo)) {
+    // FIXME: Might also want to check here for subsampling?
+    // - chroma-site only makes sense with subsampled formats?
+    // - ALT_LINE only makes sense for formats with vertical subsampling, and if
+    //   also V_COSITED?
+    if ((info->chroma_site & GST_VIDEO_CHROMA_SITE_NONE) &&
+        (info->chroma_site & (GST_VIDEO_CHROMA_SITE_H_COSITED |
+                GST_VIDEO_CHROMA_SITE_V_COSITED))) {
+      GST_WARNING
+          ("No chroma siting together with horizontal or vertical cositing is invalid");
+      return FALSE;
+    }
+  } else if (info->chroma_site != GST_VIDEO_CHROMA_SITE_UNKNOWN) {
+    GST_WARNING ("chroma-site only makes sense for YUV formats, %s is none",
+        finfo->name);
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
 static gboolean
 gst_video_info_set_format_common (GstVideoInfo * info, GstVideoFormat format,
     guint width, guint height)
@@ -507,10 +547,19 @@ gst_video_info_from_caps (GstVideoInfo * info, const GstCaps * caps)
      * PAR to be doubled/halved too many times */
   }
 
-  if ((s = gst_structure_get_string (structure, "chroma-site")))
+  if ((s = gst_structure_get_string (structure, "chroma-site"))) {
     info->chroma_site = gst_video_chroma_site_from_string (s);
-  else
-    info->chroma_site = GST_VIDEO_CHROMA_SITE_UNKNOWN;
+    if (!validate_chroma_site (info)) {
+      GST_WARNING ("invalid chroma-site, using default");
+      set_default_chroma_site (info);
+    } else if (GST_VIDEO_FORMAT_INFO_IS_YUV (info->finfo)
+        && info->chroma_site == GST_VIDEO_CHROMA_SITE_UNKNOWN) {
+      /* force a default chroma-site for YUV formats */
+      set_default_chroma_site (info);
+    }
+  } else {
+    set_default_chroma_site (info);
+  }
 
   if ((s = gst_structure_get_string (structure, "colorimetry"))) {
     if (!gst_video_colorimetry_from_string (&info->colorimetry, s)) {
@@ -682,7 +731,7 @@ gst_video_info_to_caps (const GstVideoInfo * info)
   format = gst_video_format_to_string (info->finfo->format);
   g_return_val_if_fail (format != NULL, NULL);
 
-  caps = gst_caps_new_simple ("video/x-raw",
+  caps = gst_caps_new_static_str_simple ("video/x-raw",
       "format", G_TYPE_STRING, format,
       "width", G_TYPE_INT, info->width,
       "height", G_TYPE_INT, info->height, NULL);
@@ -690,13 +739,14 @@ gst_video_info_to_caps (const GstVideoInfo * info)
   par_n = info->par_n;
   par_d = info->par_d;
 
-  gst_caps_set_simple (caps, "interlace-mode", G_TYPE_STRING,
+  gst_caps_set_simple_static_str (caps, "interlace-mode", G_TYPE_STRING,
       gst_video_interlace_mode_to_string (info->interlace_mode), NULL);
 
   if ((info->interlace_mode == GST_VIDEO_INTERLACE_MODE_INTERLEAVED ||
+          info->interlace_mode == GST_VIDEO_INTERLACE_MODE_FIELDS ||
           info->interlace_mode == GST_VIDEO_INTERLACE_MODE_ALTERNATE) &&
       GST_VIDEO_INFO_FIELD_ORDER (info) != GST_VIDEO_FIELD_ORDER_UNKNOWN) {
-    gst_caps_set_simple (caps, "field-order", G_TYPE_STRING,
+    gst_caps_set_simple_static_str (caps, "field-order", G_TYPE_STRING,
         gst_video_field_order_to_string (GST_VIDEO_INFO_FIELD_ORDER (info)),
         NULL);
   }
@@ -706,7 +756,9 @@ gst_video_info_to_caps (const GstVideoInfo * info)
      */
     GstCapsFeatures *features;
 
-    features = gst_caps_features_new (GST_CAPS_FEATURE_FORMAT_INTERLACED, NULL);
+    features =
+        gst_caps_features_new_static_str (GST_CAPS_FEATURE_FORMAT_INTERLACED,
+        NULL);
     gst_caps_set_features (caps, 0, features);
   }
 
@@ -740,13 +792,13 @@ gst_video_info_to_caps (const GstVideoInfo * info)
         gst_video_multiview_mode_to_caps_string (GST_VIDEO_INFO_MULTIVIEW_MODE
         (info));
     if (caps_str != NULL) {
-      gst_caps_set_simple (caps, "multiview-mode", G_TYPE_STRING,
+      gst_caps_set_simple_static_str (caps, "multiview-mode", G_TYPE_STRING,
           caps_str, "multiview-flags", GST_TYPE_VIDEO_MULTIVIEW_FLAGSET,
           multiview_flags, GST_FLAG_SET_MASK_EXACT, NULL);
     }
   }
 
-  gst_caps_set_simple (caps, "pixel-aspect-ratio",
+  gst_caps_set_simple_static_str (caps, "pixel-aspect-ratio",
       GST_TYPE_FRACTION, par_n, par_d, NULL);
 
   if (info->chroma_site != GST_VIDEO_CHROMA_SITE_UNKNOWN) {
@@ -756,7 +808,7 @@ gst_video_info_to_caps (const GstVideoInfo * info)
       GST_WARNING ("Couldn't convert chroma-site 0x%x to string",
           info->chroma_site);
     } else {
-      gst_caps_set_simple (caps,
+      gst_caps_set_simple_static_str (caps,
           "chroma-site", G_TYPE_STRING, chroma_site, NULL);
       g_free (chroma_site);
     }
@@ -771,20 +823,22 @@ gst_video_info_to_caps (const GstVideoInfo * info)
     colorimetry.matrix = GST_VIDEO_COLOR_MATRIX_RGB;
   }
   if ((color = gst_video_colorimetry_to_string (&colorimetry))) {
-    gst_caps_set_simple (caps, "colorimetry", G_TYPE_STRING, color, NULL);
+    gst_caps_set_simple_static_str (caps, "colorimetry", G_TYPE_STRING, color,
+        NULL);
     g_free (color);
   }
 
   if (info->views > 1)
-    gst_caps_set_simple (caps, "views", G_TYPE_INT, info->views, NULL);
+    gst_caps_set_simple_static_str (caps, "views", G_TYPE_INT, info->views,
+        NULL);
 
   if (info->flags & GST_VIDEO_FLAG_VARIABLE_FPS && info->fps_n != 0) {
     /* variable fps with a max-framerate */
-    gst_caps_set_simple (caps, "framerate", GST_TYPE_FRACTION, 0, 1,
+    gst_caps_set_simple_static_str (caps, "framerate", GST_TYPE_FRACTION, 0, 1,
         "max-framerate", GST_TYPE_FRACTION, info->fps_n, info->fps_d, NULL);
   } else {
     /* no variable fps or no max-framerate */
-    gst_caps_set_simple (caps, "framerate", GST_TYPE_FRACTION,
+    gst_caps_set_simple_static_str (caps, "framerate", GST_TYPE_FRACTION,
         info->fps_n, info->fps_d, NULL);
   }
 
@@ -863,6 +917,8 @@ fill_planes (GstVideoInfo * info, gsize plane_size[GST_VIDEO_MAX_PLANES])
     case GST_VIDEO_FORMAT_Y210:
     case GST_VIDEO_FORMAT_Y212_BE:
     case GST_VIDEO_FORMAT_Y212_LE:
+    case GST_VIDEO_FORMAT_Y216_BE:
+    case GST_VIDEO_FORMAT_Y216_LE:
       info->stride[0] = GST_ROUND_UP_8 (width * 4);
       info->offset[0] = 0;
       info->size = info->stride[0] * height;
@@ -908,6 +964,8 @@ fill_planes (GstVideoInfo * info, gsize plane_size[GST_VIDEO_MAX_PLANES])
     case GST_VIDEO_FORMAT_AYUV64:
     case GST_VIDEO_FORMAT_Y412_BE:
     case GST_VIDEO_FORMAT_Y412_LE:
+    case GST_VIDEO_FORMAT_Y416_BE:
+    case GST_VIDEO_FORMAT_Y416_LE:
       info->stride[0] = width * 8;
       info->offset[0] = 0;
       info->size = info->stride[0] * height;
@@ -1237,6 +1295,11 @@ fill_planes (GstVideoInfo * info, gsize plane_size[GST_VIDEO_MAX_PLANES])
       cr_h = GST_ROUND_UP_2 (height) / 2;
       info->size = info->offset[1] + info->stride[0] * cr_h;
       break;
+    case GST_VIDEO_FORMAT_GRAY10_LE16:
+      info->stride[0] = GST_ROUND_UP_4 (width * 2);
+      info->offset[0] = 0;
+      info->size = info->stride[0] * height;
+      break;
     case GST_VIDEO_FORMAT_GRAY10_LE32:
       info->stride[0] = (width + 2) / 3 * 4;
       info->offset[0] = 0;
