@@ -32,6 +32,10 @@
 
 G_BEGIN_DECLS
 
+#ifdef _MSC_VER
+#pragma warning(disable: 5287)
+#endif
+
 typedef struct _GstQuery GstQuery;
 
 #include <gst/gstminiobject.h>
