@@ -377,7 +377,7 @@ ucnvsel_swap(const UDataSwapper *ds,
   }
 
   /* check data format and format version */
-  const UDataInfo *pInfo = (const UDataInfo *)((const char *)inData + 4);
+  const UDataInfo* pInfo = reinterpret_cast<const UDataInfo*>(static_cast<const char*>(inData) + 4);
   if(!(
     pInfo->dataFormat[0] == 0x43 &&  /* dataFormat="CSel" */
     pInfo->dataFormat[1] == 0x53 &&
@@ -407,11 +407,11 @@ ucnvsel_swap(const UDataSwapper *ds,
     }
   }
 
-  const uint8_t *inBytes = (const uint8_t *)inData + headerSize;
-  uint8_t *outBytes = (uint8_t *)outData + headerSize;
+  const uint8_t* inBytes = static_cast<const uint8_t*>(inData) + headerSize;
+  uint8_t* outBytes = static_cast<uint8_t*>(outData) + headerSize;
 
   /* read the indexes */
-  const int32_t *inIndexes = (const int32_t *)inBytes;
+  const int32_t* inIndexes = reinterpret_cast<const int32_t*>(inBytes);
   int32_t indexes[16];
   int32_t i;
   for(i = 0; i < 16; ++i) {
