@@ -133,7 +133,7 @@ public:
      * @return the hash code.
      * @stable ICU 2.0
      */
-    virtual int32_t hashCode(void) const = 0;
+    virtual int32_t hashCode() const = 0;
 
     /**
      * Returns a UClassID for this ForwardCharacterIterator ("poor man's
@@ -142,7 +142,7 @@ public:
      * @return a UClassID for this ForwardCharacterIterator
      * @stable ICU 2.0
      */
-    virtual UClassID getDynamicClassID(void) const override = 0;
+    virtual UClassID getDynamicClassID() const override = 0;
 
     /**
      * Gets the current code unit for returning and advances to the next code unit
@@ -152,7 +152,7 @@ public:
      * @return the current code unit.
      * @stable ICU 2.0
      */
-    virtual char16_t         nextPostInc(void) = 0;
+    virtual char16_t nextPostInc() = 0;
 
     /**
      * Gets the current code point for returning and advances to the next code point
@@ -162,7 +162,7 @@ public:
      * @return the current code point.
      * @stable ICU 2.0
      */
-    virtual UChar32       next32PostInc(void) = 0;
+    virtual UChar32 next32PostInc() = 0;
 
     /**
      * Returns false if there are no more code units or code points
@@ -389,7 +389,7 @@ public:
      * @return the first code unit in its iteration range.
      * @stable ICU 2.0
      */
-    virtual char16_t         first(void) = 0;
+    virtual char16_t first() = 0;
 
     /**
      * Sets the iterator to refer to the first code unit in its
@@ -399,7 +399,7 @@ public:
      * @return the first code unit in its iteration range.
      * @stable ICU 2.0
      */
-    virtual char16_t         firstPostInc(void);
+    virtual char16_t firstPostInc();
 
     /**
      * Sets the iterator to refer to the first code point in its
@@ -410,7 +410,7 @@ public:
      * @return the first code point in its iteration range.
      * @stable ICU 2.0
      */
-    virtual UChar32       first32(void) = 0;
+    virtual UChar32 first32() = 0;
 
     /**
      * Sets the iterator to refer to the first code point in its
@@ -420,7 +420,7 @@ public:
      * @return the first code point in its iteration range.
      * @stable ICU 2.0
      */
-    virtual UChar32       first32PostInc(void);
+    virtual UChar32 first32PostInc();
 
     /**
      * Sets the iterator to refer to the first code unit or code point in its
@@ -438,7 +438,7 @@ public:
      * @return the last code unit.
      * @stable ICU 2.0
      */
-    virtual char16_t         last(void) = 0;
+    virtual char16_t last() = 0;
 
     /**
      * Sets the iterator to refer to the last code point in its
@@ -447,7 +447,7 @@ public:
      * @return the last code point.
      * @stable ICU 2.0
      */
-    virtual UChar32       last32(void) = 0;
+    virtual UChar32 last32() = 0;
 
     /**
      * Sets the iterator to the end of its iteration range, just behind
@@ -486,14 +486,14 @@ public:
      * @return the current code unit.
      * @stable ICU 2.0
      */
-    virtual char16_t         current(void) const = 0;
+    virtual char16_t current() const = 0;
 
     /**
      * Returns the code point the iterator currently refers to.
      * @return the current code point.
      * @stable ICU 2.0
      */
-    virtual UChar32       current32(void) const = 0;
+    virtual UChar32 current32() const = 0;
 
     /**
      * Advances to the next code unit in the iteration range
@@ -502,7 +502,7 @@ public:
      * @return the next code unit.
      * @stable ICU 2.0
      */
-    virtual char16_t         next(void) = 0;
+    virtual char16_t next() = 0;
 
     /**
      * Advances to the next code point in the iteration range
@@ -514,7 +514,7 @@ public:
      * @return the next code point.
      * @stable ICU 2.0
      */
-    virtual UChar32       next32(void) = 0;
+    virtual UChar32 next32() = 0;
 
     /**
      * Advances to the previous code unit in the iteration range
@@ -523,7 +523,7 @@ public:
      * @return the previous code unit.
      * @stable ICU 2.0
      */
-    virtual char16_t         previous(void) = 0;
+    virtual char16_t previous() = 0;
 
     /**
      * Advances to the previous code point in the iteration range
@@ -532,7 +532,7 @@ public:
      * @return the previous code point.
      * @stable ICU 2.0
      */
-    virtual UChar32       previous32(void) = 0;
+    virtual UChar32 previous32() = 0;
 
     /**
      * Returns false if there are no more code units or code points
@@ -555,7 +555,7 @@ public:
      * object of the character returned by first().
      * @stable ICU 2.0
      */
-    inline int32_t       startIndex(void) const;
+    inline int32_t startIndex() const;
 
     /**
      * Returns the numeric index in the underlying text-storage
@@ -566,7 +566,7 @@ public:
      * returned by last().
      * @stable ICU 2.0
      */
-    inline int32_t       endIndex(void) const;
+    inline int32_t endIndex() const;
 
     /**
      * Returns the numeric index in the underlying text-storage
@@ -576,7 +576,7 @@ public:
      * the character the iterator currently refers to
      * @stable ICU 2.0
      */
-    inline int32_t       getIndex(void) const;
+    inline int32_t getIndex() const;
 
     /**
      * Returns the length of the entire text in the underlying
@@ -708,22 +708,22 @@ CharacterIterator::setToEnd() {
 }
 
 inline int32_t
-CharacterIterator::startIndex(void) const {
+CharacterIterator::startIndex() const {
     return begin;
 }
 
 inline int32_t
-CharacterIterator::endIndex(void) const {
+CharacterIterator::endIndex() const {
     return end;
 }
 
 inline int32_t
-CharacterIterator::getIndex(void) const {
+CharacterIterator::getIndex() const {
     return pos;
 }
 
 inline int32_t
-CharacterIterator::getLength(void) const {
+CharacterIterator::getLength() const {
     return textLength;
 }
 
