@@ -42,13 +42,13 @@ U_NAMESPACE_BEGIN
 
 static inline uint32_t
 getWeightTrail(uint32_t weight, int32_t length) {
-    return (uint32_t)(weight>>(8*(4-length)))&0xff;
+    return (weight >> (8 * (4 - length))) & 0xff;
 }
 
 static inline uint32_t
 setWeightTrail(uint32_t weight, int32_t length, uint32_t trail) {
     length=8*(4-length);
-    return (uint32_t)((weight&(0xffffff00<<length))|(trail<<length));
+    return static_cast<uint32_t>((weight & (0xffffff00 << length)) | (trail << length));
 }
 
 static inline uint32_t
@@ -62,7 +62,7 @@ setWeightByte(uint32_t weight, int32_t idx, uint32_t byte) {
 
     idx*=8;
     if(idx<32) {
-        mask=((uint32_t)0xffffffff)>>idx;
+        mask = (static_cast<uint32_t>(0xffffffff)) >> idx;
     } else {
         // Do not use uint32_t>>32 because on some platforms that does not shift at all
         // while we need it to become 0.
@@ -77,22 +77,22 @@ setWeightByte(uint32_t weight, int32_t idx, uint32_t byte) {
     }
     idx=32-idx;
     mask|=0xffffff00<<idx;
-    return (uint32_t)((weight&mask)|(byte<<idx));
+    return ((weight & mask) | (byte << idx));
 }
 
 static inline uint32_t
 truncateWeight(uint32_t weight, int32_t length) {
-    return (uint32_t)(weight&(0xffffffff<<(8*(4-length))));
+    return static_cast<uint32_t>(weight & (0xffffffff << (8 * (4 - length))));
 }
 
 static inline uint32_t
 incWeightTrail(uint32_t weight, int32_t length) {
-    return (uint32_t)(weight+(1UL<<(8*(4-length))));
+    return static_cast<uint32_t>(weight + (1UL << (8 * (4 - length))));
 }
 
 static inline uint32_t
 decWeightTrail(uint32_t weight, int32_t length) {
-    return (uint32_t)(weight-(1UL<<(8*(4-length))));
+    return static_cast<uint32_t>(weight - (1UL << (8 * (4 - length))));
 }
 
 CollationWeights::CollationWeights()
@@ -169,7 +169,7 @@ uint32_t
 CollationWeights::incWeightByOffset(uint32_t weight, int32_t length, int32_t offset) const {
     for(;;) {
         offset += getWeightByte(weight, length);
-        if((uint32_t)offset <= maxBytes[length]) {
+        if (static_cast<uint32_t>(offset) <= maxBytes[length]) {
             return setWeightByte(weight, length, offset);
         } else {
             // Split the offset between this byte and the previous one.
@@ -196,8 +196,8 @@ static int32_t U_CALLCONV
 compareRanges(const void * /*context*/, const void *left, const void *right) {
     uint32_t l, r;
 
-    l=((const CollationWeights::WeightRange *)left)->start;
-    r=((const CollationWeights::WeightRange *)right)->start;
+    l = static_cast<const CollationWeights::WeightRange*>(left)->start;
+    r = static_cast<const CollationWeights::WeightRange*>(right)->start;
     if(l<r) {
         return -1;
     } else if(l>r) {
@@ -295,7 +295,7 @@ CollationWeights::getWeightRanges(uint32_t lowerLimit, uint32_t upperLimit) {
     /* set the middle range */
     middle.length=middleLength;
     if(middle.end>=middle.start) {
-        middle.count=(int32_t)((middle.end-middle.start)>>(8*(4-middleLength)))+1;
+        middle.count = static_cast<int32_t>((middle.end - middle.start) >> (8 * (4 - middleLength))) + 1;
     } else {
         /* no middle range, eliminate overlaps */
         for(int32_t length=4; length>middleLength; --length) {
@@ -322,8 +322,8 @@ CollationWeights::getWeightRanges(uint32_t lowerLimit, uint32_t upperLimit) {
                     // Intersect these two ranges.
                     lower[length].end=upper[length].end;
                     lower[length].count=
-                            (int32_t)getWeightTrail(lower[length].end, length)-
-                            (int32_t)getWeightTrail(lower[length].start, length)+1;
+                            static_cast<int32_t>(getWeightTrail(lower[length].end, length)) -
+                            static_cast<int32_t>(getWeightTrail(lower[length].start, length)) + 1;
                     // count might be <=0 in which case there is no room,
                     // and the range-collecting code below will ignore this range.
                     merged=true;
