@@ -210,7 +210,7 @@ DecimalFormat::setAttribute(UNumberFormatAttribute attr, int32_t newValue, UErro
             break;
 
         case UNUM_ROUNDING_MODE:
-            setRoundingMode((DecimalFormat::ERoundingMode) newValue);
+            setRoundingMode(static_cast<DecimalFormat::ERoundingMode>(newValue));
             break;
 
         case UNUM_FORMAT_WIDTH:
@@ -219,7 +219,7 @@ DecimalFormat::setAttribute(UNumberFormatAttribute attr, int32_t newValue, UErro
 
         case UNUM_PADDING_POSITION:
             /** The position at which padding will take place. */
-            setPadPosition((DecimalFormat::EPadPosition) newValue);
+            setPadPosition(static_cast<DecimalFormat::EPadPosition>(newValue));
             break;
 
         case UNUM_SECONDARY_GROUPING_SIZE:
@@ -228,20 +228,20 @@ DecimalFormat::setAttribute(UNumberFormatAttribute attr, int32_t newValue, UErro
 
 #if UCONFIG_HAVE_PARSEALLINPUT
         case UNUM_PARSE_ALL_INPUT:
-            setParseAllInput((UNumberFormatAttributeValue) newValue);
+            setParseAllInput(static_cast<UNumberFormatAttributeValue>(newValue));
             break;
 #endif
 
         case UNUM_PARSE_NO_EXPONENT:
-            setParseNoExponent((UBool) newValue);
+            setParseNoExponent(static_cast<UBool>(newValue));
             break;
 
         case UNUM_PARSE_DECIMAL_MARK_REQUIRED:
-            setDecimalPatternMatchRequired((UBool) newValue);
+            setDecimalPatternMatchRequired(static_cast<UBool>(newValue));
             break;
 
         case UNUM_CURRENCY_USAGE:
-            setCurrencyUsage((UCurrencyUsage) newValue, &status);
+            setCurrencyUsage(static_cast<UCurrencyUsage>(newValue), &status);
             break;
 
         case UNUM_MINIMUM_GROUPING_DIGITS:
@@ -498,7 +498,7 @@ DecimalFormat* DecimalFormat::clone() const {
 }
 
 bool DecimalFormat::operator==(const Format& other) const {
-    auto* otherDF = dynamic_cast<const DecimalFormat*>(&other);
+    const auto* otherDF = dynamic_cast<const DecimalFormat*>(&other);
     if (otherDF == nullptr) {
         return false;
     }
