@@ -489,7 +489,6 @@ void MeasureFormat::parseObject(
         const UnicodeString & /*source*/,
         Formattable & /*result*/,
         ParsePosition& /*pos*/) const {
-    return;
 }
 
 UnicodeString &MeasureFormat::formatMeasurePerUnit(
@@ -501,14 +500,14 @@ UnicodeString &MeasureFormat::formatMeasurePerUnit(
     if (U_FAILURE(status)) {
         return appendTo;
     }
-    auto* df = dynamic_cast<const DecimalFormat*>(&getNumberFormatInternal());
+    const auto* df = dynamic_cast<const DecimalFormat*>(&getNumberFormatInternal());
     if (df == nullptr) {
         // Don't know how to handle other types of NumberFormat
         status = U_UNSUPPORTED_ERROR;
         return appendTo;
     }
     UFormattedNumberData result;
-    if (auto* lnf = df->toNumberFormatter(status)) {
+    if (const auto* lnf = df->toNumberFormatter(status)) {
         result.quantity.setToDouble(measure.getNumber().getDouble(status));
         lnf->unit(measure.getUnit())
             .perUnit(perUnit)
@@ -691,7 +690,7 @@ UnicodeString &MeasureFormat::formatMeasure(
                 pos,
                 status);
     }
-    auto* df = dynamic_cast<const DecimalFormat*>(&nf);
+    const auto* df = dynamic_cast<const DecimalFormat*>(&nf);
     if (df == nullptr) {
         // Handle other types of NumberFormat using the ICU 63 code, modified to
         // get the unitPattern from LongNameHandler and handle fallback to OTHER.
@@ -708,7 +707,7 @@ UnicodeString &MeasureFormat::formatMeasure(
         return QuantityFormatter::format(formatter, formattedNumber, appendTo, pos, status);
     }
     UFormattedNumberData result;
-    if (auto* lnf = df->toNumberFormatter(status)) {
+    if (const auto* lnf = df->toNumberFormatter(status)) {
         result.quantity.setToDouble(amtNumber.getDouble(status));
         lnf->unit(amtUnit)
             .unitWidth(getUnitWidth(fWidth))
@@ -761,7 +760,7 @@ UnicodeString &MeasureFormat::formatNumeric(
         return appendTo;
     }
     number::LocalizedNumberFormatter numberFormatter2;
-    if (auto* lnf = numberFormatter->toNumberFormatter(status)) {
+    if (const auto* lnf = numberFormatter->toNumberFormatter(status)) {
         numberFormatter2 = lnf->integerWidth(number::IntegerWidth::zeroFillTo(2));
     } else {
         return appendTo;
