@@ -42,7 +42,9 @@
 #include "unicode/utypes.h"
 #include "unicode/ustring.h"
 #include "uassert.h"
+#include "uinvchar.h"
 #include "ustr_imp.h"
+#include "util.h"
 
 #ifdef U_DEBUG_TZ
 # include <stdio.h>
@@ -75,7 +77,6 @@ static char gStrBuf[256];
 #include "unicode/gregocal.h"
 #include "unicode/ures.h"
 #include "unicode/tzfmt.h"
-#include "unicode/numfmt.h"
 #include "gregoimp.h"
 #include "uresimp.h" // struct UResourceBundle
 #include "olsontz.h"
@@ -159,17 +160,17 @@ static UBool U_CALLCONV timeZone_cleanup()
 
     LEN_SYSTEM_ZONES = 0;
     uprv_free(MAP_SYSTEM_ZONES);
-    MAP_SYSTEM_ZONES = 0;
+    MAP_SYSTEM_ZONES = nullptr;
     gSystemZonesInitOnce.reset();
 
     LEN_CANONICAL_SYSTEM_ZONES = 0;
     uprv_free(MAP_CANONICAL_SYSTEM_ZONES);
-    MAP_CANONICAL_SYSTEM_ZONES = 0;
+    MAP_CANONICAL_SYSTEM_ZONES = nullptr;
     gCanonicalZonesInitOnce.reset();
 
     LEN_CANONICAL_SYSTEM_LOCATION_ZONES = 0;
     uprv_free(MAP_CANONICAL_SYSTEM_LOCATION_ZONES);
-    MAP_CANONICAL_SYSTEM_LOCATION_ZONES = 0;
+    MAP_CANONICAL_SYSTEM_LOCATION_ZONES = nullptr;
     gCanonicalLocationZonesInitOnce.reset();
 
     return true;
@@ -194,7 +195,7 @@ static int32_t findInStringArray(UResourceBundle* array, const UnicodeString& id
     U_DEBUG_TZ_MSG(("fisa: Looking for %s, between %d and %d\n", U_DEBUG_TZ_STR(UnicodeString(id).getTerminatedBuffer()), start, limit));
 
     for (;;) {
-        mid = (int32_t)((start + limit) / 2);
+        mid = static_cast<int32_t>((start + limit) / 2);
         if (lastMid == mid) {   /* Have we moved? */
             break;  /* We haven't moved, and it wasn't found. */
         }
@@ -257,7 +258,7 @@ static UResourceBundle* getZoneByName(const UResourceBundle* top, const UnicodeS
 
 UResourceBundle* TimeZone::loadRule(const UResourceBundle* top, const UnicodeString& ruleid, UResourceBundle* oldbundle, UErrorCode& status) {
     char key[64];
-    ruleid.extract(0, sizeof(key)-1, key, (int32_t)sizeof(key)-1, US_INV);
+    ruleid.extract(0, sizeof(key) - 1, key, static_cast<int32_t>(sizeof(key)) - 1, US_INV);
     U_DEBUG_TZ_MSG(("loadRule(%s)\n", key));
     UResourceBundle *r = ures_getByKey(top, kRULES, oldbundle, &status);
     U_DEBUG_TZ_MSG(("loadRule(%s) -> kRULES [%s]\n", key, u_errorName(status)));
@@ -282,7 +283,7 @@ static UResourceBundle* openOlsonResource(const UnicodeString& id,
     char buf[128];
     id.extract(0, sizeof(buf)-1, buf, sizeof(buf), "");
 #endif
-    UResourceBundle *top = ures_openDirect(0, kZONEINFO, &ec);
+    UResourceBundle *top = ures_openDirect(nullptr, kZONEINFO, &ec);
     U_DEBUG_TZ_MSG(("pre: res sz=%d\n", ures_getSize(&res)));
     /* &res = */ getZoneByName(top, id, &res, ec);
     // Dereference if this is an alias.  Docs say result should be 1
@@ -391,7 +392,7 @@ createSystemTimeZone(const UnicodeString& id, UErrorCode& ec) {
     if (U_FAILURE(ec)) {
         return nullptr;
     }
-    TimeZone* z = 0;
+    TimeZone* z = nullptr;
     StackUResourceBundle res;
     U_DEBUG_TZ_MSG(("pre-err=%s\n", u_errorName(ec)));
     UResourceBundle *top = openOlsonResource(id, res.ref(), ec);
@@ -625,11 +626,11 @@ TimeZone::setDefault(const TimeZone& zone)
 static void U_CALLCONV initMap(USystemTimeZoneType type, UErrorCode& ec) {
     ucln_i18n_registerCleanup(UCLN_I18N_TIMEZONE, timeZone_cleanup);
 
-    UResourceBundle *res = ures_openDirect(0, kZONEINFO, &ec);
+    UResourceBundle *res = ures_openDirect(nullptr, kZONEINFO, &ec);
     res = ures_getByKey(res, kNAMES, res, &ec); // dereference Zones section
     if (U_SUCCESS(ec)) {
         int32_t size = ures_getSize(res);
-        int32_t *m = (int32_t *)uprv_malloc(size * sizeof(int32_t));
+        int32_t* m = static_cast<int32_t*>(uprv_malloc(size * sizeof(int32_t)));
         if (m == nullptr) {
             ec = U_MEMORY_ALLOCATION_ERROR;
         } else {
@@ -668,7 +669,7 @@ static void U_CALLCONV initMap(USystemTimeZoneType type, UErrorCode& ec) {
             }
             if (U_SUCCESS(ec)) {
                 int32_t *tmp = m;
-                m = (int32_t *)uprv_realloc(tmp, numEntries * sizeof(int32_t));
+                m = static_cast<int32_t*>(uprv_realloc(tmp, numEntries * sizeof(int32_t)));
                 if (m == nullptr) {
                     // realloc failed.. use the original one even it has unused
                     // area at the end
@@ -729,13 +730,13 @@ void TimeZone::getOffset(UDate date, UBool local, int32_t& rawOffset,
     // (with 7 args) twice when local == true and DST is
     // detected in the initial call.
     for (int32_t pass=0; ; ++pass) {
-        int32_t year, month, dom, dow, millis;
-        double day = ClockMath::floorDivide(date, U_MILLIS_PER_DAY, &millis);
-
-        Grego::dayToFields(day, year, month, dom, dow);
+        int32_t year, millis;
+        int8_t month, dom, dow;
+        Grego::timeToFields(date, year, month, dom, dow, millis, ec);
+        if (U_FAILURE(ec)) return;
 
         dstOffset = getOffset(GregorianCalendar::AD, year, month, dom,
-                              (uint8_t) dow, millis,
+                              static_cast<uint8_t>(dow), millis,
                               Grego::monthLength(year, month),
                               ec) - rawOffset;
 
@@ -773,7 +774,7 @@ private:
     UBool getID(int32_t i, UErrorCode& ec) {
         int32_t idLen = 0;
         const char16_t* id = nullptr;
-        UResourceBundle *top = ures_openDirect(0, kZONEINFO, &ec);
+        UResourceBundle *top = ures_openDirect(nullptr, kZONEINFO, &ec);
         top = ures_getByKey(top, kNAMES, top, &ec); // dereference Zones section
         id = ures_getStringByIndex(top, i, &idLen, &ec);
         if(U_FAILURE(ec)) {
@@ -842,14 +843,14 @@ public:
 
         if (region != nullptr || rawOffset != nullptr) {
             int32_t filteredMapSize = DEFAULT_FILTERED_MAP_SIZE;
-            filteredMap = (int32_t *)uprv_malloc(filteredMapSize * sizeof(int32_t));
+            filteredMap = static_cast<int32_t*>(uprv_malloc(filteredMapSize * sizeof(int32_t)));
             if (filteredMap == nullptr) {
                 ec = U_MEMORY_ALLOCATION_ERROR;
                 return nullptr;
             }
 
             // Walk through the base map
-            UResourceBundle *res = ures_openDirect(0, kZONEINFO, &ec);
+            UResourceBundle *res = ures_openDirect(nullptr, kZONEINFO, &ec);
             res = ures_getByKey(res, kNAMES, res, &ec); // dereference Zones section
             for (int32_t i = 0; i < baseLen; i++) {
                 int32_t zidx = baseMap[i];
@@ -886,7 +887,7 @@ public:
 
                 if (filteredMapSize <= numEntries) {
                     filteredMapSize += MAP_INCREMENT_SIZE;
-                    int32_t *tmp = (int32_t *)uprv_realloc(filteredMap, filteredMapSize * sizeof(int32_t));
+                    int32_t* tmp = static_cast<int32_t*>(uprv_realloc(filteredMap, filteredMapSize * sizeof(int32_t)));
                     if (tmp == nullptr) {
                         ec = U_MEMORY_ALLOCATION_ERROR;
                         break;
@@ -929,7 +930,7 @@ public:
 
     TZEnumeration(const TZEnumeration &other) : StringEnumeration(), map(nullptr), localMap(nullptr), len(0), pos(0) {
         if (other.localMap != nullptr) {
-            localMap = (int32_t *)uprv_malloc(other.len * sizeof(int32_t));
+            localMap = static_cast<int32_t*>(uprv_malloc(other.len * sizeof(int32_t)));
             if (localMap != nullptr) {
                 len = other.len;
                 uprv_memcpy(localMap, other.localMap, len * sizeof(int32_t));
@@ -964,7 +965,7 @@ public:
             ++pos;
             return &unistr;
         }
-        return 0;
+        return nullptr;
     }
 
     virtual void reset(UErrorCode& /*status*/) override {
@@ -1050,7 +1051,7 @@ TimeZone::countEquivalentIDs(const UnicodeString& id) {
 
 // ---------------------------------------
 
-const UnicodeString U_EXPORT2
+UnicodeString U_EXPORT2
 TimeZone::getEquivalentID(const UnicodeString& id, int32_t index) {
     U_DEBUG_TZ_MSG(("gEI(%d)\n", index));
     UnicodeString result;
@@ -1369,123 +1370,94 @@ TimeZone::getCustomID(const UnicodeString& id, UnicodeString& normalized, UError
 UBool
 TimeZone::parseCustomID(const UnicodeString& id, int32_t& sign,
                         int32_t& hour, int32_t& min, int32_t& sec) {
-    static const int32_t         kParseFailed = -99999;
-
-    NumberFormat* numberFormat = 0;
-    UnicodeString idUppercase = id;
-    idUppercase.toUpper("");
-
-    if (id.length() > GMT_ID_LENGTH &&
-        idUppercase.startsWith(GMT_ID, GMT_ID_LENGTH))
-    {
-        ParsePosition pos(GMT_ID_LENGTH);
-        sign = 1;
-        hour = 0;
-        min = 0;
-        sec = 0;
-
-        if (id[pos.getIndex()] == MINUS /*'-'*/) {
-            sign = -1;
-        } else if (id[pos.getIndex()] != PLUS /*'+'*/) {
-            return false;
-        }
-        pos.setIndex(pos.getIndex() + 1);
-
-        UErrorCode success = U_ZERO_ERROR;
-        numberFormat = NumberFormat::createInstance(success);
-        if(U_FAILURE(success)){
-            return false;
-        }
-        numberFormat->setParseIntegerOnly(true);
-        //numberFormat->setLenient(true); // TODO: May need to set this, depends on latest timezone parsing
-
-        // Look for either hh:mm, hhmm, or hh
-        int32_t start = pos.getIndex();
-        Formattable n(kParseFailed);
-        numberFormat->parse(id, n, pos);
-        if (pos.getIndex() == start) {
-            delete numberFormat;
-            return false;
-        }
-        hour = n.getLong();
-
-        if (pos.getIndex() < id.length()) {
-            if (pos.getIndex() - start > 2
-                || id[pos.getIndex()] != COLON) {
-                delete numberFormat;
-                return false;
-            }
-            // hh:mm
-            pos.setIndex(pos.getIndex() + 1);
-            int32_t oldPos = pos.getIndex();
-            n.setLong(kParseFailed);
-            numberFormat->parse(id, n, pos);
-            if ((pos.getIndex() - oldPos) != 2) {
-                // must be 2 digits
-                delete numberFormat;
-                return false;
-            }
-            min = n.getLong();
-            if (pos.getIndex() < id.length()) {
-                if (id[pos.getIndex()] != COLON) {
-                    delete numberFormat;
-                    return false;
-                }
-                // [:ss]
-                pos.setIndex(pos.getIndex() + 1);
-                oldPos = pos.getIndex();
-                n.setLong(kParseFailed);
-                numberFormat->parse(id, n, pos);
-                if (pos.getIndex() != id.length()
-                        || (pos.getIndex() - oldPos) != 2) {
-                    delete numberFormat;
-                    return false;
-                }
-                sec = n.getLong();
-            }
-        } else {
-            // Supported formats are below -
-            //
-            // HHmmss
-            // Hmmss
-            // HHmm
-            // Hmm
-            // HH
-            // H
-
-            int32_t length = pos.getIndex() - start;
-            if (length <= 0 || 6 < length) {
-                // invalid length
-                delete numberFormat;
-                return false;
-            }
-            switch (length) {
-                case 1:
-                case 2:
-                    // already set to hour
-                    break;
-                case 3:
-                case 4:
-                    min = hour % 100;
-                    hour /= 100;
-                    break;
-                case 5:
-                case 6:
-                    sec = hour % 100;
-                    min = (hour/100) % 100;
-                    hour /= 10000;
-                    break;
-            }
-        }
-
-        delete numberFormat;
-
-        if (hour > kMAX_CUSTOM_HOUR || min > kMAX_CUSTOM_MIN || sec > kMAX_CUSTOM_SEC) {
-            return false;
-        }
-        return true;
+    if (id.length() < GMT_ID_LENGTH) {
+      return false;
     }
-    return false;
+    if (0 != u_strncasecmp(id.getBuffer(), GMT_ID, GMT_ID_LENGTH, 0)) {
+        return false;
+    }
+    sign = 1;
+    hour = 0;
+    min = 0;
+    sec = 0;
+
+    if (id[GMT_ID_LENGTH] == MINUS /*'-'*/) {
+        sign = -1;
+    } else if (id[GMT_ID_LENGTH] != PLUS /*'+'*/) {
+        return false;
+    }
+
+    int32_t start = GMT_ID_LENGTH + 1;
+    int32_t pos = start;
+    hour = ICU_Utility::parseNumber(id, pos, 10);
+    if (pos == id.length()) {
+        // Handle the following cases
+        // HHmmss
+        // Hmmss
+        // HHmm
+        // Hmm
+        // HH
+        // H
+
+        // Get all digits
+        // Should be 1 to 6 digits.
+        int32_t length = pos - start;
+        switch (length) {
+            case 1:  // H
+            case 2:  // HH
+                // already set to hour
+                break;
+            case 3:  // Hmm
+            case 4:  // HHmm
+                min = hour % 100;
+                hour /= 100;
+                break;
+            case 5:  // Hmmss
+            case 6:  // HHmmss
+                sec = hour % 100;
+                min = (hour/100) % 100;
+                hour /= 10000;
+                break;
+            default:
+                // invalid range
+                return false;
+        }
+    } else {
+        // Handle the following cases
+        // HH:mm:ss
+        // H:mm:ss
+        // HH:mm
+        // H:mm
+        if (pos - start < 1 || pos - start > 2 || id[pos] != COLON) {
+            return false;
+        }
+        pos++; // skip : after H or HH
+        if (id.length() == pos) {
+            return false;
+        }
+        start = pos;
+        min = ICU_Utility::parseNumber(id, pos, 10);
+        if (pos - start != 2) {
+            return false;
+        }
+        if (id.length() > pos) {
+            if (id[pos] != COLON) {
+                return false;
+            }
+            pos++; // skip : after mm
+            start = pos;
+            sec = ICU_Utility::parseNumber(id, pos, 10);
+            if (pos - start != 2 || id.length() > pos) {
+                return false;
+            }
+        }
+    }
+    if (hour > kMAX_CUSTOM_HOUR ||
+        min > kMAX_CUSTOM_MIN ||
+        sec > kMAX_CUSTOM_SEC) {
+        return false;
+    }
+    return true;
 }
 
 UnicodeString&
@@ -1495,33 +1467,33 @@ TimeZone::formatCustomID(int32_t hour, int32_t min, int32_t sec,
     id.setTo(GMT_ID, GMT_ID_LENGTH);
     if (hour | min | sec) {
         if (negative) {
-            id += (char16_t)MINUS;
+            id += static_cast<char16_t>(MINUS);
         } else {
-            id += (char16_t)PLUS;
+            id += static_cast<char16_t>(PLUS);
         }
 
         if (hour < 10) {
-            id += (char16_t)ZERO_DIGIT;
+            id += static_cast<char16_t>(ZERO_DIGIT);
         } else {
-            id += (char16_t)(ZERO_DIGIT + hour/10);
+            id += static_cast<char16_t>(ZERO_DIGIT + hour / 10);
         }
-        id += (char16_t)(ZERO_DIGIT + hour%10);
-        id += (char16_t)COLON;
+        id += static_cast<char16_t>(ZERO_DIGIT + hour % 10);
+        id += static_cast<char16_t>(COLON);
         if (min < 10) {
-            id += (char16_t)ZERO_DIGIT;
+            id += static_cast<char16_t>(ZERO_DIGIT);
         } else {
-            id += (char16_t)(ZERO_DIGIT + min/10);
+            id += static_cast<char16_t>(ZERO_DIGIT + min / 10);
         }
-        id += (char16_t)(ZERO_DIGIT + min%10);
+        id += static_cast<char16_t>(ZERO_DIGIT + min % 10);
 
         if (sec) {
-            id += (char16_t)COLON;
+            id += static_cast<char16_t>(COLON);
             if (sec < 10) {
-                id += (char16_t)ZERO_DIGIT;
+                id += static_cast<char16_t>(ZERO_DIGIT);
             } else {
-                id += (char16_t)(ZERO_DIGIT + sec/10);
+                id += static_cast<char16_t>(ZERO_DIGIT + sec / 10);
             }
-            id += (char16_t)(ZERO_DIGIT + sec%10);
+            id += static_cast<char16_t>(ZERO_DIGIT + sec % 10);
         }
     }
     return id;
@@ -1543,7 +1515,7 @@ static void U_CALLCONV initTZDataVersion(UErrorCode &status) {
     const char16_t *tzver = ures_getStringByKey(bundle.getAlias(), kTZVERSION, &len, &status);
 
     if (U_SUCCESS(status)) {
-        if (len >= (int32_t)sizeof(TZDATA_VERSION)) {
+        if (len >= static_cast<int32_t>(sizeof(TZDATA_VERSION))) {
             // Ensure that there is always space for a trailing nul in TZDATA_VERSION
             len = sizeof(TZDATA_VERSION) - 1;
         }
@@ -1629,8 +1601,11 @@ TimeZone::getWindowsID(const UnicodeString& id, UnicodeString& winid, UErrorCode
         return winid;
     }
 
-    UResourceBundle *mapTimezones = ures_openDirect(nullptr, "windowsZones", &status);
-    ures_getByKey(mapTimezones, "mapTimezones", mapTimezones, &status);
+    LocalUResourceBundlePointer mapTimezones(ures_openDirect(nullptr, "windowsZones", &status));
+    if (U_FAILURE(status)) {
+        return winid;
+    }
+    ures_getByKey(mapTimezones.getAlias(), "mapTimezones", mapTimezones.getAlias(), &status);
 
     if (U_FAILURE(status)) {
         return winid;
@@ -1638,8 +1613,8 @@ TimeZone::getWindowsID(const UnicodeString& id, UnicodeString& winid, UErrorCode
 
     UResourceBundle *winzone = nullptr;
     UBool found = false;
-    while (ures_hasNext(mapTimezones) && !found) {
-        winzone = ures_getNextResource(mapTimezones, winzone, &status);
+    while (ures_hasNext(mapTimezones.getAlias()) && !found) {
+        winzone = ures_getNextResource(mapTimezones.getAlias(), winzone, &status);
         if (U_FAILURE(status)) {
             break;
         }
@@ -1664,7 +1639,7 @@ TimeZone::getWindowsID(const UnicodeString& id, UnicodeString& winid, UErrorCode
             const char16_t *start = tzids;
             UBool hasNext = true;
             while (hasNext) {
-                const char16_t *end = u_strchr(start, (char16_t)0x20);
+                const char16_t* end = u_strchr(start, static_cast<char16_t>(0x20));
                 if (end == nullptr) {
                     end = tzids + len;
                     hasNext = false;
@@ -1680,7 +1655,6 @@ TimeZone::getWindowsID(const UnicodeString& id, UnicodeString& winid, UErrorCode
         ures_close(regionalData);
     }
     ures_close(winzone);
-    ures_close(mapTimezones);
 
     return winid;
 }
@@ -1705,7 +1679,7 @@ TimeZone::getIDForWindowsID(const UnicodeString& winid, const char* region, Unic
     char winidKey[MAX_WINDOWS_ID_SIZE];
     int32_t winKeyLen = winid.extract(0, winid.length(), winidKey, sizeof(winidKey) - 1, US_INV);
 
-    if (winKeyLen == 0 || winKeyLen >= (int32_t)sizeof(winidKey)) {
+    if (winKeyLen == 0 || winKeyLen >= static_cast<int32_t>(sizeof(winidKey))) {
         ures_close(zones);
         return id;
     }
@@ -1726,7 +1700,7 @@ TimeZone::getIDForWindowsID(const UnicodeString& winid, const char* region, Unic
                                                                                 // regional mapping is optional
         if (U_SUCCESS(tmperr)) {
             // first ID delimited by space is the default one
-            const char16_t *end = u_strchr(tzids, (char16_t)0x20);
+            const char16_t* end = u_strchr(tzids, static_cast<char16_t>(0x20));
             if (end == nullptr) {
                 id.setTo(tzids, -1);
             } else {
