@@ -16,12 +16,12 @@
 #if !UCONFIG_NO_FORMATTING
 
 #include "unicode/strenum.h"
+#include "unicode/stringpiece.h"
 #include "unicode/ustring.h"
 #include "unicode/timezone.h"
 #include "unicode/utf16.h"
 
 #include "tznames_impl.h"
-#include "bytesinkutil.h"
 #include "charstr.h"
 #include "cmemory.h"
 #include "cstring.h"
@@ -33,6 +33,7 @@
 #include "ureslocs.h"
 #include "zonemeta.h"
 #include "ucln_in.h"
+#include "uinvchar.h"
 #include "uvector.h"
 #include "olsontz.h"
 
@@ -72,7 +73,9 @@ enum UTimeZoneNameTypeIndex {
     UTZNM_INDEX_SHORT_DAYLIGHT,
     UTZNM_INDEX_COUNT
 };
-static const char16_t* const EMPTY_NAMES[UTZNM_INDEX_COUNT] = {0,0,0,0,0,0,0};
+static const char16_t* const EMPTY_NAMES[UTZNM_INDEX_COUNT] = {
+    nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr
+};
 
 U_CDECL_BEGIN
 static UBool U_CALLCONV tzdbTimeZoneNames_cleanup() {
@@ -110,7 +113,7 @@ struct ZMatchInfo {
 };
 
 // Helper functions
-static void mergeTimeZoneKey(const UnicodeString& mzID, char* result);
+static void mergeTimeZoneKey(const UnicodeString& mzID, char* result, size_t capacity, UErrorCode& status);
 
 #define DEFAULT_CHARACTERNODE_CAPACITY 1
 
@@ -129,7 +132,7 @@ void CharacterNode::deleteValues(UObjectDeleter *valueDeleter) {
             valueDeleter(fValues);
         }
     } else {
-        delete (UVector *)fValues;
+        delete static_cast<UVector*>(fValues);
     }
 }
 
@@ -165,7 +168,7 @@ CharacterNode::addValue(void *value, UObjectDeleter *valueDeleter, UErrorCode &s
             fHasValuesVector = true;
         }
         // Add the new value.
-        UVector *values = (UVector *)fValues;
+        UVector* values = static_cast<UVector*>(fValues);
         if (values->hasDeleter()) {
             values->adoptElement(value, status);
         } else {
@@ -232,31 +235,25 @@ TextTrieMap::put(const char16_t *key, void *value, UErrorCode &status) {
         LocalPointer<UVector> lpLazyContents(new UVector(status), status);
         fLazyContents = lpLazyContents.orphan();
     }
-    if (U_FAILURE(status)) {
-        if (fValueDeleter) {
-            fValueDeleter((void*) key);
+    if (U_SUCCESS(status)) {
+        U_ASSERT(fLazyContents != nullptr);
+        char16_t *s = const_cast<char16_t *>(key);
+        fLazyContents->addElement(s, status);
+        if (U_SUCCESS(status)) {
+            fLazyContents->addElement(value, status);
+            return;
         }
-        return;
     }
-    U_ASSERT(fLazyContents != nullptr);
-
-    char16_t *s = const_cast<char16_t *>(key);
-    fLazyContents->addElement(s, status);
-    if (U_FAILURE(status)) {
-        if (fValueDeleter) {
-            fValueDeleter((void*) key);
-        }
-        return;
+    if (fValueDeleter) {
+        fValueDeleter(value);
     }
-
-    fLazyContents->addElement(value, status);
 }
 
 void
 TextTrieMap::putImpl(const UnicodeString &key, void *value, UErrorCode &status) {
     if (fNodes == nullptr) {
         fNodesCapacity = 512;
-        fNodes = (CharacterNode *)uprv_malloc(fNodesCapacity * sizeof(CharacterNode));
+        fNodes = static_cast<CharacterNode*>(uprv_malloc(fNodesCapacity * sizeof(CharacterNode)));
         if (fNodes == nullptr) {
             status = U_MEMORY_ALLOCATION_ERROR;
             return;
@@ -295,7 +292,7 @@ TextTrieMap::growNodes() {
     if (newCapacity > 0xffff) {
         newCapacity = 0xffff;
     }
-    CharacterNode *newNodes = (CharacterNode *)uprv_malloc(newCapacity * sizeof(CharacterNode));
+    CharacterNode* newNodes = static_cast<CharacterNode*>(uprv_malloc(newCapacity * sizeof(CharacterNode)));
     if (newNodes == nullptr) {
         return false;
     }
@@ -328,7 +325,7 @@ TextTrieMap::addChildNode(CharacterNode *parent, char16_t c, UErrorCode &status)
 
     // Ensure capacity. Grow fNodes[] if needed.
     if (fNodesCount == fNodesCapacity) {
-        int32_t parentIndex = (int32_t)(parent - fNodes);
+        int32_t parentIndex = static_cast<int32_t>(parent - fNodes);
         if (!growNodes()) {
             status = U_MEMORY_ALLOCATION_ERROR;
             return nullptr;
@@ -342,9 +339,9 @@ TextTrieMap::addChildNode(CharacterNode *parent, char16_t c, UErrorCode &status)
     node->fCharacter = c;
     node->fNextSibling = nodeIndex;
     if (prevIndex == 0) {
-        parent->fFirstChild = (uint16_t)fNodesCount;
+        parent->fFirstChild = static_cast<uint16_t>(fNodesCount);
     } else {
-        fNodes[prevIndex].fNextSibling = (uint16_t)fNodesCount;
+        fNodes[prevIndex].fNextSibling = static_cast<uint16_t>(fNodesCount);
     }
     ++fNodesCount;
     return node;
@@ -375,7 +372,7 @@ TextTrieMap::getChildNode(CharacterNode *parent, char16_t c) const {
 void TextTrieMap::buildTrie(UErrorCode &status) {
     if (fLazyContents != nullptr) {
         for (int32_t i=0; i<fLazyContents->size(); i+=2) {
-            const char16_t *key = (char16_t *)fLazyContents->elementAt(i);
+            const char16_t* key = static_cast<char16_t*>(fLazyContents->elementAt(i));
             void  *val = fLazyContents->elementAt(i+1);
             UnicodeString keyString(true, key, -1);  // Aliasing UnicodeString constructor.
             putImpl(keyString, val, status);
@@ -675,7 +672,7 @@ private:
             if (locationNameUniStr.length() > 0) {
                 const char16_t* buff = locationNameUniStr.getTerminatedBuffer();
                 int32_t len = sizeof(char16_t) * (locationNameUniStr.length() + 1);
-                locationName = (char16_t*) uprv_malloc(len);
+                locationName = static_cast<char16_t*>(uprv_malloc(len));
                 if (locationName == nullptr) {
                     status = U_MEMORY_ALLOCATION_ERROR;
                     return nullptr;
@@ -718,14 +715,14 @@ private:
         for (int32_t i = 0; i < UTZNM_INDEX_COUNT; i++) {
             const char16_t* name = fNames[i];
             if (name != nullptr) {
-                ZNameInfo *nameinfo = (ZNameInfo *)uprv_malloc(sizeof(ZNameInfo));
+                ZNameInfo* nameinfo = static_cast<ZNameInfo*>(uprv_malloc(sizeof(ZNameInfo)));
                 if (nameinfo == nullptr) {
                     status = U_MEMORY_ALLOCATION_ERROR;
                     return;
                 }
                 nameinfo->mzID = mzID;
                 nameinfo->tzID = tzID;
-                nameinfo->type = getTZNameType((UTimeZoneNameTypeIndex)i);
+                nameinfo->type = getTZNameType(static_cast<UTimeZoneNameTypeIndex>(i));
                 trie.put(name, nameinfo, status); // trie.put() takes ownership of the key
                 if (U_FAILURE(status)) {
                     return;
@@ -755,7 +752,7 @@ struct ZNames::ZNamesLoader : public ResourceSink {
         if (U_FAILURE(errorCode)) { return; }
 
         char key[ZID_KEY_MAX + 1];
-        mergeTimeZoneKey(mzID, key);
+        mergeTimeZoneKey(mzID, key, sizeof(key), errorCode);
 
         loadNames(zoneStrings, key, errorCode);
     }
@@ -764,12 +761,16 @@ struct ZNames::ZNamesLoader : public ResourceSink {
         // Replace "/" with ":".
         UnicodeString uKey(tzID);
         for (int32_t i = 0; i < uKey.length(); i++) {
-            if (uKey.charAt(i) == (char16_t)0x2F) {
-                uKey.setCharAt(i, (char16_t)0x3A);
+            if (uKey.charAt(i) == static_cast<char16_t>(0x2F)) {
+                uKey.setCharAt(i, static_cast<char16_t>(0x3A));
             }
         }
 
         char key[ZID_KEY_MAX + 1];
+        if (uKey.length() > ZID_KEY_MAX) {
+            errorCode = U_INTERNAL_PROGRAM_ERROR;
+            return;
+        }
         uKey.extract(0, uKey.length(), key, sizeof(key), US_INV);
 
         loadNames(zoneStrings, key, errorCode);
@@ -898,7 +899,7 @@ MetaZoneIDsEnumeration::MetaZoneIDsEnumeration(LocalPointer<UVector> mzIDs)
 const UnicodeString*
 MetaZoneIDsEnumeration::snext(UErrorCode& status) {
     if (U_SUCCESS(status) && fMetaZoneIDs != nullptr && fPos < fLen) {
-        unistr.setTo((const char16_t*)fMetaZoneIDs->elementAt(fPos++), -1);
+        unistr.setTo(static_cast<const char16_t*>(fMetaZoneIDs->elementAt(fPos++)), -1);
         return &unistr;
     }
     return nullptr;
@@ -940,9 +941,7 @@ ZNameSearchHandler::ZNameSearchHandler(uint32_t types)
 }
 
 ZNameSearchHandler::~ZNameSearchHandler() {
-    if (fResults != nullptr) {
-        delete fResults;
-    }
+    delete fResults;
 }
 
 UBool
@@ -1069,8 +1068,6 @@ TimeZoneNamesImpl::initialize(const Locale& locale, UErrorCode& status) {
         loadStrings(UnicodeString(tzID), status);
     }
     delete tz;
-
-    return;
 }
 
 /*
@@ -1165,7 +1162,7 @@ TimeZoneNamesImpl::_getAvailableMetaZoneIDs(const UnicodeString& tzID, UErrorCod
         U_ASSERT(mzIDs.isValid());
         for (int32_t i = 0; U_SUCCESS(status) && i < mappings->size(); i++) {
 
-            OlsonToMetaMappingEntry *map = (OlsonToMetaMappingEntry *)mappings->elementAt(i);
+            OlsonToMetaMappingEntry* map = static_cast<OlsonToMetaMappingEntry*>(mappings->elementAt(i));
             const char16_t *mzID = map->mzid;
             if (!mzIDs->contains((void *)mzID)) {
                 mzIDs->addElement((void *)mzID, status);
@@ -1282,19 +1279,30 @@ TimeZoneNamesImpl::getExemplarLocationName(const UnicodeString& tzID, UnicodeStr
 
 
 // Merge the MZ_PREFIX and mzId
-static void mergeTimeZoneKey(const UnicodeString& mzID, char* result) {
+static void mergeTimeZoneKey(const UnicodeString& mzID, char* result, size_t capacity,
+                             UErrorCode& status) {
+    if (U_FAILURE(status)) {
+        return;
+    }
     if (mzID.isEmpty()) {
         result[0] = '\0';
         return;
     }
 
-    char mzIdChar[ZID_KEY_MAX + 1];
-    int32_t keyLen;
-    int32_t prefixLen = static_cast<int32_t>(uprv_strlen(gMZPrefix));
-    keyLen = mzID.extract(0, mzID.length(), mzIdChar, ZID_KEY_MAX + 1, US_INV);
-    uprv_memcpy((void *)result, (void *)gMZPrefix, prefixLen);
-    uprv_memcpy((void *)(result + prefixLen), (void *)mzIdChar, keyLen);
-    result[keyLen + prefixLen] = '\0';
+    if (MZ_PREFIX_LEN + 1 > capacity) {
+        result[0] = '\0';
+        status = U_INTERNAL_PROGRAM_ERROR;
+        return;
+    }
+    uprv_memcpy((void *)result, (void *)gMZPrefix, MZ_PREFIX_LEN);
+    if (static_cast<size_t>(MZ_PREFIX_LEN +  mzID.length() + 1) > capacity) {
+        result[0] = '\0';
+        status = U_INTERNAL_PROGRAM_ERROR;
+        return;
+    }
+    int32_t keyLen = mzID.extract(0, mzID.length(), result + MZ_PREFIX_LEN,
+                                  static_cast<int32_t>(capacity - MZ_PREFIX_LEN), US_INV);
+    result[keyLen + MZ_PREFIX_LEN] = '\0';
 }
 
 /*
@@ -1303,11 +1311,16 @@ static void mergeTimeZoneKey(const UnicodeString& mzID, char* result) {
 ZNames*
 TimeZoneNamesImpl::loadMetaZoneNames(const UnicodeString& mzID, UErrorCode& status) {
     if (U_FAILURE(status)) { return nullptr; }
-    U_ASSERT(mzID.length() <= ZID_KEY_MAX - MZ_PREFIX_LEN);
+    if (mzID.length() > ZID_KEY_MAX - MZ_PREFIX_LEN) {
+        status = U_INTERNAL_PROGRAM_ERROR;
+        return nullptr;
+    }
 
     char16_t mzIDKey[ZID_KEY_MAX + 1];
-    mzID.extract(mzIDKey, ZID_KEY_MAX + 1, status);
-    U_ASSERT(U_SUCCESS(status));   // already checked length above
+    mzID.extract(mzIDKey, ZID_KEY_MAX, status);
+    if (U_FAILURE(status)) {
+        return nullptr;
+    }
     mzIDKey[mzID.length()] = 0;
 
     void* mznames = uhash_get(fMZNamesMap, mzIDKey);
@@ -1319,7 +1332,7 @@ TimeZoneNamesImpl::loadMetaZoneNames(const UnicodeString& mzID, UErrorCode& stat
     }
 
     if (mznames != EMPTY) {
-        return (ZNames*)mznames;
+        return static_cast<ZNames*>(mznames);
     } else {
         return nullptr;
     }
@@ -1331,10 +1344,13 @@ TimeZoneNamesImpl::loadMetaZoneNames(const UnicodeString& mzID, UErrorCode& stat
 ZNames*
 TimeZoneNamesImpl::loadTimeZoneNames(const UnicodeString& tzID, UErrorCode& status) {
     if (U_FAILURE(status)) { return nullptr; }
-    U_ASSERT(tzID.length() <= ZID_KEY_MAX);
+    if (tzID.length() > ZID_KEY_MAX) {
+        status = U_INTERNAL_PROGRAM_ERROR;
+        return nullptr;
+    }
 
     char16_t tzIDKey[ZID_KEY_MAX + 1];
-    int32_t tzIDKeyLen = tzID.extract(tzIDKey, ZID_KEY_MAX + 1, status);
+    int32_t tzIDKeyLen = tzID.extract(tzIDKey, ZID_KEY_MAX, status);
     U_ASSERT(U_SUCCESS(status));   // already checked length above
     tzIDKey[tzIDKeyLen] = 0;
 
@@ -1347,7 +1363,7 @@ TimeZoneNamesImpl::loadTimeZoneNames(const UnicodeString& tzID, UErrorCode& stat
     }
 
     // tznames is never EMPTY
-    return (ZNames*)tznames;
+    return static_cast<ZNames*>(tznames);
 }
 
 TimeZoneNames::MatchInfoCollection*
@@ -1419,8 +1435,8 @@ void TimeZoneNamesImpl::addAllNamesIntoTrie(UErrorCode& status) {
     pos = UHASH_FIRST;
     while ((element = uhash_nextElement(fMZNamesMap, &pos)) != nullptr) {
         if (element->value.pointer == EMPTY) { continue; }
-        char16_t* mzID = (char16_t*) element->key.pointer;
-        ZNames* znames = (ZNames*) element->value.pointer;
+        char16_t* mzID = static_cast<char16_t*>(element->key.pointer);
+        ZNames* znames = static_cast<ZNames*>(element->value.pointer);
         znames->addAsMetaZoneIntoTrie(mzID, fNamesTrie, status);
         if (U_FAILURE(status)) { return; }
     }
@@ -1428,8 +1444,8 @@ void TimeZoneNamesImpl::addAllNamesIntoTrie(UErrorCode& status) {
     pos = UHASH_FIRST;
     while ((element = uhash_nextElement(fTZNamesMap, &pos)) != nullptr) {
         if (element->value.pointer == EMPTY) { continue; }
-        char16_t* tzID = (char16_t*) element->key.pointer;
-        ZNames* znames = (ZNames*) element->value.pointer;
+        char16_t* tzID = static_cast<char16_t*>(element->key.pointer);
+        ZNames* znames = static_cast<ZNames*>(element->value.pointer);
         znames->addAsTimeZoneIntoTrie(tzID, fNamesTrie, status);
         if (U_FAILURE(status)) { return; }
     }
@@ -1459,7 +1475,7 @@ struct TimeZoneNamesImpl::ZoneStringsLoader : public ResourceSink {
 
     void* createKey(const char* key, UErrorCode& status) {
         int32_t len = sizeof(char) * (static_cast<int32_t>(uprv_strlen(key)) + 1);
-        char* newKey = (char*) uprv_malloc(len);
+        char* newKey = static_cast<char*>(uprv_malloc(len));
         if (newKey == nullptr) {
             status = U_MEMORY_ALLOCATION_ERROR;
             return nullptr;
@@ -1496,8 +1512,8 @@ struct TimeZoneNamesImpl::ZoneStringsLoader : public ResourceSink {
         const UHashElement* element;
         while ((element = uhash_nextElement(keyToLoader, &pos)) != nullptr) {
             if (element->value.pointer == DUMMY_LOADER) { continue; }
-            ZNames::ZNamesLoader* loader = (ZNames::ZNamesLoader*) element->value.pointer;
-            char* key = (char*) element->key.pointer;
+            ZNames::ZNamesLoader* loader = static_cast<ZNames::ZNamesLoader*>(element->value.pointer);
+            char* key = static_cast<char*>(element->key.pointer);
 
             if (isMetaZone(key)) {
                 UnicodeString mzID = mzIDFromKey(key);
@@ -1556,7 +1572,7 @@ struct TimeZoneNamesImpl::ZoneStringsLoader : public ResourceSink {
 
         if (loader != DUMMY_LOADER) {
             // Let the ZNamesLoader consume the names table.
-            ((ZNames::ZNamesLoader*)loader)->put(key, value, noFallback, status);
+            static_cast<ZNames::ZNamesLoader*>(loader)->put(key, value, noFallback, status);
         }
     }
 
@@ -1612,7 +1628,7 @@ void TimeZoneNamesImpl::getDisplayNames(const UnicodeString& tzID,
     // Load the values into the dest array
     for (int i = 0; i < numTypes; i++) {
         UTimeZoneNameType type = types[i];
-        const char16_t* name = ((ZNames*)tznames)->getName(type);
+        const char16_t* name = static_cast<ZNames*>(tznames)->getName(type);
         if (name == nullptr) {
             if (mznames == nullptr) {
                 // Load the meta zone name
@@ -1635,7 +1651,7 @@ void TimeZoneNamesImpl::getDisplayNames(const UnicodeString& tzID,
             }
             U_ASSERT(mznames != nullptr);
             if (mznames != EMPTY) {
-                name = ((ZNames*)mznames)->getName(type);
+                name = static_cast<ZNames*>(mznames)->getName(type);
             }
         }
         if (name != nullptr) {
@@ -1673,9 +1689,7 @@ void TimeZoneNamesImpl::internalLoadAllDisplayNames(UErrorCode& status) {
                 }
             }
         }
-        if (tzIDs != nullptr) {
-            delete tzIDs;
-        }
+        delete tzIDs;
     }
 }
 
@@ -1696,11 +1710,11 @@ TimeZoneNamesImpl::getDefaultExemplarLocationName(const UnicodeString& tzID, Uni
         return name;
     }
 
-    int32_t sep = tzID.lastIndexOf((char16_t)0x2F /* '/' */);
+    int32_t sep = tzID.lastIndexOf(static_cast<char16_t>(0x2F) /* '/' */);
     if (sep > 0 && sep + 1 < tzID.length()) {
         name.setTo(tzID, sep + 1);
-        name.findAndReplace(UnicodeString((char16_t)0x5f /* _ */),
-                            UnicodeString((char16_t)0x20 /* space */));
+        name.findAndReplace(UnicodeString(static_cast<char16_t>(0x5f) /* _ */),
+                            UnicodeString(static_cast<char16_t>(0x20) /* space */));
     } else {
         name.setToBogus();
     }
@@ -1770,7 +1784,7 @@ TZDBNames::createInstance(UResourceBundle* rb, const char* key) {
         return nullptr;
     }
 
-    names = (const char16_t **)uprv_malloc(sizeof(const char16_t*) * TZDBNAMES_KEYS_SIZE);
+    names = static_cast<const char16_t**>(uprv_malloc(sizeof(const char16_t*) * TZDBNAMES_KEYS_SIZE));
     UBool isEmpty = true;
     if (names != nullptr) {
         for (int32_t i = 0; i < TZDBNAMES_KEYS_SIZE; i++) {
@@ -1797,7 +1811,7 @@ TZDBNames::createInstance(UResourceBundle* rb, const char* key) {
     if (U_SUCCESS(status)) {
         numRegions = ures_getSize(regionsRes);
         if (numRegions > 0) {
-            regions = (char**)uprv_malloc(sizeof(char*) * numRegions);
+            regions = static_cast<char**>(uprv_malloc(sizeof(char*) * numRegions));
             if (regions != nullptr) {
                 char **pRegion = regions;
                 for (int32_t i = 0; i < numRegions; i++, pRegion++) {
@@ -1812,7 +1826,7 @@ TZDBNames::createInstance(UResourceBundle* rb, const char* key) {
                         regionError = true;
                         break;
                     }
-                    *pRegion = (char*)uprv_malloc(sizeof(char) * (len + 1));
+                    *pRegion = static_cast<char*>(uprv_malloc(sizeof(char) * (len + 1)));
                     if (*pRegion == nullptr) {
                         regionError = true;
                         break;
@@ -1889,7 +1903,7 @@ U_CDECL_END
 
 class TZDBNameSearchHandler : public TextTrieMapSearchResultHandler {
 public:
-    TZDBNameSearchHandler(uint32_t types, const char* region);
+    TZDBNameSearchHandler(uint32_t types, StringPiece region);
     virtual ~TZDBNameSearchHandler();
 
     UBool handleMatch(int32_t matchLength, const CharacterNode *node, UErrorCode &status) override;
@@ -1899,17 +1913,15 @@ private:
     uint32_t fTypes;
     int32_t fMaxMatchLen;
     TimeZoneNames::MatchInfoCollection* fResults;
-    const char* fRegion;
+    StringPiece fRegion;
 };
 
-TZDBNameSearchHandler::TZDBNameSearchHandler(uint32_t types, const char* region)
+TZDBNameSearchHandler::TZDBNameSearchHandler(uint32_t types, StringPiece region)
 : fTypes(types), fMaxMatchLen(0), fResults(nullptr), fRegion(region) {
 }
 
 TZDBNameSearchHandler::~TZDBNameSearchHandler() {
-    if (fResults != nullptr) {
-        delete fResults;
-    }
+    delete fResults;
 }
 
 UBool
@@ -1951,7 +1963,7 @@ TZDBNameSearchHandler::handleMatch(int32_t matchLength, const CharacterNode *nod
                     // as metazone China (China Standard Time).
                     for (int32_t j = 0; j < ninfo->nRegions; j++) {
                         const char *region = ninfo->parseRegions[j];
-                        if (uprv_strcmp(fRegion, region) == 0) {
+                        if (fRegion == region) {
                             match = ninfo;
                             matchRegion = true;
                             break;
@@ -2064,7 +2076,7 @@ static void U_CALLCONV prepareFind(UErrorCode &status) {
     const UnicodeString *mzID;
     StringEnumeration *mzIDs = TimeZoneNamesImpl::_getAvailableMetaZoneIDs(status);
     if (U_SUCCESS(status)) {
-        while ((mzID = mzIDs->snext(status)) != 0 && U_SUCCESS(status)) {
+        while ((mzID = mzIDs->snext(status)) != nullptr && U_SUCCESS(status)) {
             const TZDBNames *names = TZDBTimeZoneNames::getMetaZoneNames(*mzID, status);
             if (U_FAILURE(status)) {
                 break;
@@ -2130,27 +2142,27 @@ static void U_CALLCONV prepareFind(UErrorCode &status) {
 U_CDECL_END
 
 TZDBTimeZoneNames::TZDBTimeZoneNames(const Locale& locale)
-: fLocale(locale) {
+: fLocale(locale), fRegion() {
     UBool useWorld = true;
     const char* region = fLocale.getCountry();
     int32_t regionLen = static_cast<int32_t>(uprv_strlen(region));
     if (regionLen == 0) {
         UErrorCode status = U_ZERO_ERROR;
-        CharString loc;
-        {
-            CharStringByteSink sink(&loc);
-            ulocimp_addLikelySubtags(fLocale.getName(), sink, &status);
-        }
-        regionLen = uloc_getCountry(loc.data(), fRegion, sizeof(fRegion), &status);
-        if (U_SUCCESS(status) && regionLen < (int32_t)sizeof(fRegion)) {
+        CharString loc = ulocimp_addLikelySubtags(fLocale.getName(), status);
+        ulocimp_getSubtags(loc.toStringPiece(), nullptr, nullptr, &fRegion, nullptr, nullptr, status);
+        if (U_SUCCESS(status)) {
             useWorld = false;
         }
-    } else if (regionLen < (int32_t)sizeof(fRegion)) {
-        uprv_strcpy(fRegion, region);
+    } else {
+        UErrorCode status = U_ZERO_ERROR;
+        fRegion.append(region, regionLen, status);
+        U_ASSERT(U_SUCCESS(status));
         useWorld = false;
     }
     if (useWorld) {
-        uprv_strcpy(fRegion, "001");
+        UErrorCode status = U_ZERO_ERROR;
+        fRegion.append("001", status);
+        U_ASSERT(U_SUCCESS(status));
     }
 }
 
@@ -2228,7 +2240,7 @@ TZDBTimeZoneNames::find(const UnicodeString& text, int32_t start, uint32_t types
         return nullptr;
     }
 
-    TZDBNameSearchHandler handler(types, fRegion);
+    TZDBNameSearchHandler handler(types, fRegion.toStringPiece());
     gTZDBNamesTrie->search(text, start, (TextTrieMapSearchResultHandler *)&handler, status);
     if (U_FAILURE(status)) {
         return nullptr;
@@ -2247,9 +2259,15 @@ TZDBTimeZoneNames::getMetaZoneNames(const UnicodeString& mzID, UErrorCode& statu
     TZDBNames* tzdbNames = nullptr;
 
     char16_t mzIDKey[ZID_KEY_MAX + 1];
-    mzID.extract(mzIDKey, ZID_KEY_MAX + 1, status);
-    U_ASSERT(status == U_ZERO_ERROR);   // already checked length above
+    mzID.extract(mzIDKey, ZID_KEY_MAX, status);
+    if (U_FAILURE(status)) {
+        return nullptr;
+    }
     mzIDKey[mzID.length()] = 0;
+    if (!uprv_isInvariantUString(mzIDKey, mzID.length())) {
+        status = U_ILLEGAL_ARGUMENT_ERROR;
+        return nullptr;
+    }
 
     static UMutex gTZDBNamesMapLock;
     umtx_lock(&gTZDBNamesMapLock);
@@ -2258,9 +2276,9 @@ TZDBTimeZoneNames::getMetaZoneNames(const UnicodeString& mzID, UErrorCode& statu
         if (cacheVal == nullptr) {
             UResourceBundle *zoneStringsRes = ures_openDirect(U_ICUDATA_ZONE, "tzdbNames", &status);
             zoneStringsRes = ures_getByKey(zoneStringsRes, gZoneStrings, zoneStringsRes, &status);
+            char key[ZID_KEY_MAX + 1];
+            mergeTimeZoneKey(mzID, key, sizeof(key), status);
             if (U_SUCCESS(status)) {
-                char key[ZID_KEY_MAX + 1];
-                mergeTimeZoneKey(mzID, key);
                 tzdbNames = TZDBNames::createInstance(zoneStringsRes, key);
 
                 if (tzdbNames == nullptr) {
@@ -2292,7 +2310,7 @@ TZDBTimeZoneNames::getMetaZoneNames(const UnicodeString& mzID, UErrorCode& statu
             }
             ures_close(zoneStringsRes);
         } else if (cacheVal != EMPTY) {
-            tzdbNames = (TZDBNames *)cacheVal;
+            tzdbNames = static_cast<TZDBNames*>(cacheVal);
         }
     }
     umtx_unlock(&gTZDBNamesMapLock);
