@@ -355,8 +355,9 @@ AnnualTimeZoneRule::getNextStart(UDate base,
                                  int32_t prevDSTSavings,
                                  UBool inclusive,
                                  UDate& result) const {
-    int32_t year, month, dom, dow, doy, mid;
-    Grego::timeToFields(base, year, month, dom, dow, doy, mid);
+    UErrorCode status = U_ZERO_ERROR;
+    int32_t year = Grego::timeToYear(base, status);
+    U_ASSERT(U_SUCCESS(status));
     if (year < fStartYear) {
         return getFirstStart(prevRawOffset, prevDSTSavings, result);
     }
@@ -379,8 +380,9 @@ AnnualTimeZoneRule::getPreviousStart(UDate base,
                                      int32_t prevDSTSavings,
                                      UBool inclusive,
                                      UDate& result) const {
-    int32_t year, month, dom, dow, doy, mid;
-    Grego::timeToFields(base, year, month, dom, dow, doy, mid);
+    UErrorCode status = U_ZERO_ERROR;
+    int32_t year = Grego::timeToYear(base, status);
+    U_ASSERT(U_SUCCESS(status));
     if (year > fEndYear) {
         return getFinalStart(prevRawOffset, prevDSTSavings, result);
     }
@@ -587,7 +589,7 @@ TimeArrayTimeZoneRule::initStartTimes(const UDate source[], int32_t size, UError
     }
     // Allocate new one if needed
     if (size > TIMEARRAY_STACK_BUFFER_SIZE) {
-        fStartTimes = (UDate*)uprv_malloc(sizeof(UDate)*size);
+        fStartTimes = static_cast<UDate*>(uprv_malloc(sizeof(UDate) * size));
         if (fStartTimes == nullptr) {
             status = U_MEMORY_ALLOCATION_ERROR;
             fNumStartTimes = 0;
@@ -599,7 +601,7 @@ TimeArrayTimeZoneRule::initStartTimes(const UDate source[], int32_t size, UError
     uprv_memcpy(fStartTimes, source, sizeof(UDate)*size);
     fNumStartTimes = size;
     // Sort dates
-    uprv_sortArray(fStartTimes, fNumStartTimes, (int32_t)sizeof(UDate), compareDates, nullptr, true, &status);
+    uprv_sortArray(fStartTimes, fNumStartTimes, static_cast<int32_t>(sizeof(UDate)), compareDates, nullptr, true, &status);
     if (U_FAILURE(status)) {
         if (fStartTimes != nullptr && fStartTimes != fLocalStartTimes) {
             uprv_free(fStartTimes);
