@@ -22,6 +22,7 @@
 #include "unicode/ustring.h"
 #include "unicode/strenum.h"
 #include "unicode/localpointer.h"
+#include "charstr.h"
 #include "cmemory.h"
 #include "cstring.h"
 #include "iso8601cal.h"
@@ -41,7 +42,7 @@ _createTimeZone(const char16_t* zoneID, int32_t len, UErrorCode* ec) {
         // failure we will see is a memory allocation failure.
         int32_t l = (len<0 ? u_strlen(zoneID) : len);
         UnicodeString zoneStrID;
-        zoneStrID.setTo((UBool)(len < 0), zoneID, l); /* temporary read-only alias */
+        zoneStrID.setTo(static_cast<UBool>(len < 0), zoneID, l); /* temporary read-only alias */
         zone = TimeZone::createTimeZone(zoneStrID);
         if (zone == nullptr) {
             *ec = U_MEMORY_ALLOCATION_ERROR;
@@ -167,21 +168,15 @@ ucal_open(  const char16_t*  zoneID,
   }
 
   if ( caltype == UCAL_GREGORIAN ) {
-      char localeBuf[ULOC_LOCALE_IDENTIFIER_CAPACITY];
       if ( locale == nullptr ) {
           locale = uloc_getDefault();
       }
-      int32_t localeLength = static_cast<int32_t>(uprv_strlen(locale));
-      if (localeLength >= ULOC_LOCALE_IDENTIFIER_CAPACITY) {
-          *status = U_ILLEGAL_ARGUMENT_ERROR;
-          return nullptr;
-      }
-      uprv_strcpy(localeBuf, locale);
-      uloc_setKeywordValue("calendar", "gregorian", localeBuf, ULOC_LOCALE_IDENTIFIER_CAPACITY, status);
+      CharString localeBuf(locale, *status);
+      ulocimp_setKeywordValue("calendar", "gregorian", localeBuf, *status);
       if (U_FAILURE(*status)) {
           return nullptr;
       }
-      return (UCalendar*)Calendar::createInstance(zone.orphan(), Locale(localeBuf), *status);
+      return (UCalendar*)Calendar::createInstance(zone.orphan(), Locale(localeBuf.data()), *status);
   }
   return (UCalendar*)Calendar::createInstance(zone.orphan(), Locale(locale), *status);
 }
@@ -198,13 +193,13 @@ U_CAPI UCalendar* U_EXPORT2
 ucal_clone(const UCalendar* cal,
            UErrorCode*      status)
 {
-  if(U_FAILURE(*status)) return 0;
+  if (U_FAILURE(*status)) return nullptr;
 
   Calendar* res = ((Calendar*)cal)->clone();
 
-  if(res == 0) {
+  if (res == nullptr) {
     *status = U_MEMORY_ALLOCATION_ERROR;
-    return 0;
+    return nullptr;
   }
 
   return (UCalendar*) res;
@@ -549,7 +544,7 @@ ucal_getLimit(    const    UCalendar*              cal,
               UCalendarDateFields     field,
               UCalendarLimitType      type,
               UErrorCode        *status) UPRV_NO_SANITIZE_UNDEFINED {
-    if(status==0 || U_FAILURE(*status)) {
+    if (status == nullptr || U_FAILURE(*status)) {
         return -1;
     }
     if (field < 0 || UCAL_FIELD_COUNT <= field) {
@@ -605,13 +600,13 @@ ucal_getTZDataVersion(UErrorCode* status)
 U_CAPI int32_t U_EXPORT2
 ucal_getCanonicalTimeZoneID(const char16_t* id, int32_t len,
                             char16_t* result, int32_t resultCapacity, UBool *isSystemID, UErrorCode* status) {
-    if(status == 0 || U_FAILURE(*status)) {
+    if (status == nullptr || U_FAILURE(*status)) {
         return 0;
     }
     if (isSystemID) {
         *isSystemID = false;
     }
-    if (id == 0 || len == 0 || result == 0 || resultCapacity <= 0) {
+    if (id == nullptr || len == 0 || result == nullptr || resultCapacity <= 0) {
         *status = U_ILLEGAL_ARGUMENT_ERROR;
         return 0;
     }
@@ -721,13 +716,12 @@ static const char * const CAL_TYPES[] = {
 U_CAPI UEnumeration* U_EXPORT2
 ucal_getKeywordValuesForLocale(const char * /* key */, const char* locale, UBool commonlyUsed, UErrorCode *status) {
     // Resolve region
-    char prefRegion[ULOC_COUNTRY_CAPACITY];
-    (void)ulocimp_getRegionForSupplementalData(locale, true, prefRegion, sizeof(prefRegion), status);
+    CharString prefRegion = ulocimp_getRegionForSupplementalData(locale, true, *status);
 
     // Read preferred calendar values from supplementalData calendarPreference
     UResourceBundle *rb = ures_openDirect(nullptr, "supplementalData", status);
     ures_getByKey(rb, "calendarPreferenceData", rb, status);
-    UResourceBundle *order = ures_getByKey(rb, prefRegion, nullptr, status);
+    UResourceBundle *order = ures_getByKey(rb, prefRegion.data(), nullptr, status);
     if (*status == U_MISSING_RESOURCE_ERROR && rb != nullptr) {
         *status = U_ZERO_ERROR;
         order = ures_getByKey(rb, "001", nullptr, status);
