@@ -43,6 +43,7 @@ U_NAMESPACE_BEGIN
 /* forward declaration */
 class SimpleDateFormat;
 class Hashtable;
+class CharString;
 
 /**
  * DateFormatSymbols is a public class for encapsulating localizable date-time
@@ -567,7 +568,7 @@ public:
      * @return    the non-localized date-time pattern characters
      * @stable ICU 2.0
      */
-    static const char16_t * U_EXPORT2 getPatternUChars(void);
+    static const char16_t* U_EXPORT2 getPatternUChars();
 
     /**
      * Gets localized date-time pattern characters. For example: 'u', 't', etc.
@@ -917,8 +918,8 @@ private:
     /** valid/actual locale information
      *  these are always ICU locales, so the length should not be a problem
      */
-    char validLocale[ULOC_FULLNAME_CAPACITY];
-    char actualLocale[ULOC_FULLNAME_CAPACITY];
+    CharString* validLocale = nullptr;
+    CharString* actualLocale = nullptr;
 
     DateFormatSymbols() = delete; // default constructor not implemented
 
@@ -971,7 +972,7 @@ private:
     /**
      * Delete all the storage owned by this object.
      */
-    void dispose(void);
+    void dispose();
 
     /**
      * Copy all of the other's data to this.
@@ -982,12 +983,12 @@ private:
     /**
      * Create zone strings array by locale if not yet available
      */
-    void initZoneStringsArray(void);
+    void initZoneStringsArray();
 
     /**
      * Delete just the zone strings.
      */
-    void disposeZoneStrings(void);
+    void disposeZoneStrings();
 
     /**
      * Returns the date format field index of the pattern character c,
