@@ -462,11 +462,18 @@ class U_I18N_API UnlocalizedNumberRangeFormatter
     explicit UnlocalizedNumberRangeFormatter(
             NumberRangeFormatterSettings<UnlocalizedNumberRangeFormatter>&& src) noexcept;
 
+    explicit UnlocalizedNumberRangeFormatter(const impl::RangeMacroProps &macros);
+
+    explicit UnlocalizedNumberRangeFormatter(impl::RangeMacroProps &&macros);
+
     // To give the fluent setters access to this class's constructor:
     friend class NumberRangeFormatterSettings<UnlocalizedNumberRangeFormatter>;
 
     // To give NumberRangeFormatter::with() access to this class's constructor:
     friend class NumberRangeFormatter;
+
+    // To give LNRF::withoutLocale() access to this class's constructor:
+    friend class LocalizedNumberRangeFormatter;
 };
 
 /**
@@ -496,6 +503,23 @@ class U_I18N_API LocalizedNumberRangeFormatter
     FormattedNumberRange formatFormattableRange(
         const Formattable& first, const Formattable& second, UErrorCode& status) const;
 
+    /**
+     * Disassociate the locale from this formatter.
+     *
+     * @return The fluent chain.
+     * @stable ICU 75
+     */
+    UnlocalizedNumberRangeFormatter withoutLocale() const &;
+
+    /**
+     * Overload of withoutLocale() for use on an rvalue reference.
+     *
+     * @return The fluent chain.
+     * @see #withoutLocale
+     * @stable ICU 75
+     */
+    UnlocalizedNumberRangeFormatter withoutLocale() &&;
+
     /**
      * Default constructor: puts the formatter into a valid but undefined state.
      *
