@@ -190,11 +190,6 @@ public:
      * @param status  output param set to success/failure code on exit, which
      *                must not indicate a failure before the function call.
      * @stable ICU 4.0
-         * <p>
-         * <h4>Sample code</h4>
-         * \snippet samples/plurfmtsample/plurfmtsample.cpp PluralFormatExample1
-         * \snippet samples/plurfmtsample/plurfmtsample.cpp PluralFormatExample
-         * <p>
      */
     PluralFormat(const Locale& locale, const PluralRules& rules, UErrorCode& status);
 
@@ -513,7 +508,7 @@ public:
      * @stable ICU 4.0
      *
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * ICU "poor man's RTTI", returns a UClassID for the actual class.
