@@ -88,23 +88,24 @@ enum URBNFRuleSetTag {
 };
 
 /**
- * The RuleBasedNumberFormat class formats numbers according to a set of rules. This number formatter is
- * typically used for spelling out numeric values in words (e.g., 25,3476 as
- * &quot;twenty-five thousand three hundred seventy-six&quot; or &quot;vingt-cinq mille trois
+ * The RuleBasedNumberFormat class formats numbers according to a set of rules.
+ *
+ * <p>This number formatter is typically used for spelling out numeric values in words (e.g., 25,3476
+ * as &quot;twenty-five thousand three hundred seventy-six&quot; or &quot;vingt-cinq mille trois
  * cents soixante-seize&quot; or
  * &quot;f&uuml;nfundzwanzigtausenddreihundertsechsundsiebzig&quot;), but can also be used for
  * other complicated formatting tasks, such as formatting a number of seconds as hours,
- * minutes and seconds (e.g., 3,730 as &quot;1:02:10&quot;).
+ * minutes and seconds (e.g., 3,730 as &quot;1:02:10&quot;).</p>
  *
  * <p>The resources contain three predefined formatters for each locale: spellout, which
  * spells out a value in words (123 is &quot;one hundred twenty-three&quot;); ordinal, which
  * appends an ordinal suffix to the end of a numeral (123 is &quot;123rd&quot;); and
  * duration, which shows a duration in seconds as hours, minutes, and seconds (123 is
- * &quot;2:03&quot;).&nbsp; The client can also define more specialized <tt>RuleBasedNumberFormat</tt>s
+ * &quot;2:03&quot;).&nbsp; The client can also define more specialized <code>RuleBasedNumberFormat</code>s
  * by supplying programmer-defined rule sets.</p>
  *
- * <p>The behavior of a <tt>RuleBasedNumberFormat</tt> is specified by a textual description
- * that is either passed to the constructor as a <tt>String</tt> or loaded from a resource
+ * <p>The behavior of a <code>RuleBasedNumberFormat</code> is specified by a textual description
+ * that is either passed to the constructor as a <code>String</code> or loaded from a resource
  * bundle. In its simplest form, the description consists of a semicolon-delimited list of <em>rules.</em>
  * Each rule has a string of output text and a value or range of values it is applicable to.
  * In a typical spellout rule set, the first twenty rules are the words for the numbers from
@@ -116,7 +117,8 @@ enum URBNFRuleSetTag {
  * <p>For larger numbers, we can use the preceding set of rules to format the ones place, and
  * we only have to supply the words for the multiples of 10:</p>
  *
- * <pre> 20: twenty[-&gt;&gt;];
+ * <pre>
+ * 20: twenty[-&gt;&gt;];
  * 30: thirty[-&gt;&gt;];
  * 40: forty[-&gt;&gt;];
  * 50: fifty[-&gt;&gt;];
@@ -137,7 +139,8 @@ enum URBNFRuleSetTag {
  * <p>For even larger numbers, we can actually look up several parts of the number in the
  * list:</p>
  *
- * <pre>100: &lt;&lt; hundred[ &gt;&gt;];</pre>
+ * <pre>
+ * 100: &lt;&lt; hundred[ &gt;&gt;];</pre>
  *
  * <p>The &quot;&lt;&lt;&quot; represents a new kind of substitution. The &lt;&lt; isolates
  * the hundreds digit (and any digits to its left), formats it using this same rule set, and
@@ -155,13 +158,15 @@ enum URBNFRuleSetTag {
  *
  * <p>This rule covers values up to 999, at which point we add another rule:</p>
  *
- * <pre>1000: &lt;&lt; thousand[ &gt;&gt;];</pre>
+ * <pre>
+ * 1000: &lt;&lt; thousand[ &gt;&gt;];</pre>
  *
  * <p>Again, the meanings of the brackets and substitution tokens shift because the rule's
  * base value is a higher power of 10, changing the rule's divisor. This rule can actually be
  * used all the way up to 999,999. This allows us to finish out the rules as follows:</p>
  *
- * <pre> 1,000,000: &lt;&lt; million[ &gt;&gt;];
+ * <pre>
+ * 1,000,000: &lt;&lt; million[ &gt;&gt;];
  * 1,000,000,000: &lt;&lt; billion[ &gt;&gt;];
  * 1,000,000,000,000: &lt;&lt; trillion[ &gt;&gt;];
  * 1,000,000,000,000,000: OUT OF RANGE!;</pre>
@@ -177,30 +182,30 @@ enum URBNFRuleSetTag {
  * <p>To see how these rules actually work in practice, consider the following example:
  * Formatting 25,430 with this rule set would work like this:</p>
  *
- * <table border="0" width="100%">
+ * <table style="border-collapse: collapse;">
  *   <tr>
- *     <td><strong>&lt;&lt; thousand &gt;&gt;</strong></td>
- *     <td>[the rule whose base value is 1,000 is applicable to 25,340]</td>
+ *     <td style="width: 257; vertical-align: top;"><strong>&lt;&lt; thousand &gt;&gt;</strong></td>
+ *     <td style="width: 340; vertical-align: top;">[the rule whose base value is 1,000 is applicable to 25,340]</td>
  *   </tr>
  *   <tr>
- *     <td><strong>twenty-&gt;&gt;</strong> thousand &gt;&gt;</td>
- *     <td>[25,340 over 1,000 is 25. The rule for 20 applies.]</td>
+ *     <td style="width: 257; vertical-align: top;"><strong>twenty-&gt;&gt;</strong> thousand &gt;&gt;</td>
+ *     <td style="width: 340; vertical-align: top;">[25,340 over 1,000 is 25. The rule for 20 applies.]</td>
  *   </tr>
  *   <tr>
- *     <td>twenty-<strong>five</strong> thousand &gt;&gt;</td>
- *     <td>[25 mod 10 is 5. The rule for 5 is &quot;five.&quot;</td>
+ *     <td style="width: 257; vertical-align: top;">twenty-<strong>five</strong> thousand &gt;&gt;</td>
+ *     <td style="width: 340; vertical-align: top;">[25 mod 10 is 5. The rule for 5 is &quot;five.&quot;</td>
  *   </tr>
  *   <tr>
- *     <td>twenty-five thousand <strong>&lt;&lt; hundred &gt;&gt;</strong></td>
- *     <td>[25,340 mod 1,000 is 340. The rule for 100 applies.]</td>
+ *     <td style="width: 257; vertical-align: top;">twenty-five thousand <strong>&lt;&lt; hundred &gt;&gt;</strong></td>
+ *     <td style="width: 340; vertical-align: top;">[25,340 mod 1,000 is 340. The rule for 100 applies.]</td>
  *   </tr>
  *   <tr>
- *     <td>twenty-five thousand <strong>three</strong> hundred &gt;&gt;</td>
- *     <td>[340 over 100 is 3. The rule for 3 is &quot;three.&quot;]</td>
+ *     <td style="width: 257; vertical-align: top;">twenty-five thousand <strong>three</strong> hundred &gt;&gt;</td>
+ *     <td style="width: 340; vertical-align: top;">[340 over 100 is 3. The rule for 3 is &quot;three.&quot;]</td>
  *   </tr>
  *   <tr>
- *     <td>twenty-five thousand three hundred <strong>forty</strong></td>
- *     <td>[340 mod 100 is 40. The rule for 40 applies. Since 40 divides
+ *     <td style="width: 257; vertical-align: top;">twenty-five thousand three hundred <strong>forty</strong></td>
+ *     <td style="width: 340; vertical-align: top;">[340 mod 100 is 40. The rule for 40 applies. Since 40 divides
  *     evenly by 10, the hyphen and substitution in the brackets are omitted.]</td>
  *   </tr>
  * </table>
@@ -237,20 +242,20 @@ enum URBNFRuleSetTag {
  *
  * <hr>
  *
- * <p>The description of a <tt>RuleBasedNumberFormat</tt>'s behavior consists of one or more <em>rule
+ * <p>The description of a <code>RuleBasedNumberFormat</code>'s behavior consists of one or more <em>rule
  * sets.</em> Each rule set consists of a name, a colon, and a list of <em>rules.</em> A rule
  * set name must begin with a % sign. Rule sets with names that begin with a single % sign
  * are <em>public:</em> the caller can specify that they be used to format and parse numbers.
  * Rule sets with names that begin with %% are <em>private:</em> they exist only for the use
  * of other rule sets. If a formatter only has one rule set, the name may be omitted.</p>
  *
- * <p>The user can also specify a special &quot;rule set&quot; named <tt>%%lenient-parse</tt>.
- * The body of <tt>%%lenient-parse</tt> isn't a set of number-formatting rules, but a <tt>RuleBasedCollator</tt>
+ * <p>The user can also specify a special &quot;rule set&quot; named <code>%%lenient-parse</code>.
+ * The body of <code>%%lenient-parse</code> isn't a set of number-formatting rules, but a <code>RuleBasedCollator</code>
  * description which is used to define equivalences for lenient parsing. For more information
- * on the syntax, see <tt>RuleBasedCollator</tt>. For more information on lenient parsing,
- * see <tt>setLenientParse()</tt>.  <em>Note:</em> symbols that have syntactic meaning
+ * on the syntax, see <code>RuleBasedCollator</code>. For more information on lenient parsing,
+ * see <code>setLenientParse()</code>. <em>Note:</em> symbols that have syntactic meaning
  * in collation rules, such as '&amp;', have no particular meaning when appearing outside
- * of the <tt>lenient-parse</tt> rule set.</p>
+ * of the <code>lenient-parse</code> rule set.</p>
  *
  * <p>The body of a rule set consists of an ordered, semicolon-delimited list of <em>rules.</em>
  * Internally, every rule has a base value, a divisor, rule text, and zero, one, or two <em>substitutions.</em>
@@ -260,42 +265,46 @@ enum URBNFRuleSetTag {
  * <p>A rule descriptor can take one of the following forms (text in <em>italics</em> is the
  * name of a token):</p>
  *
- * <table border="0" width="100%">
+ * <table style="border-collapse: collapse;">
  *   <tr>
- *     <td><em>bv</em>:</td>
- *     <td><em>bv</em> specifies the rule's base value. <em>bv</em> is a decimal
+ *     <th style="padding-left: 1em; padding-right: 1em;">Descriptor</th>
+ *     <th>Description</th>
+ *   </tr>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;"><em>bv</em>:</td>
+ *     <td style="vertical-align: top;"><em>bv</em> specifies the rule's base value. <em>bv</em> is a decimal
  *     number expressed using ASCII digits. <em>bv</em> may contain spaces, period, and commas,
  *     which are ignored. The rule's divisor is the highest power of 10 less than or equal to
  *     the base value.</td>
  *   </tr>
- *   <tr>
- *     <td><em>bv</em>/<em>rad</em>:</td>
- *     <td><em>bv</em> specifies the rule's base value. The rule's divisor is the
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;"><em>bv</em>/<em>rad</em>:</td>
+ *     <td style="vertical-align: top;"><em>bv</em> specifies the rule's base value. The rule's divisor is the
  *     highest power of <em>rad</em> less than or equal to the base value.</td>
  *   </tr>
- *   <tr>
- *     <td><em>bv</em>&gt;:</td>
- *     <td><em>bv</em> specifies the rule's base value. To calculate the divisor,
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;"><em>bv</em>&gt;:</td>
+ *     <td style="vertical-align: top;"><em>bv</em> specifies the rule's base value. To calculate the divisor,
  *     let the radix be 10, and the exponent be the highest exponent of the radix that yields a
  *     result less than or equal to the base value. Every &gt; character after the base value
  *     decreases the exponent by 1. If the exponent is positive or 0, the divisor is the radix
  *     raised to the power of the exponent; otherwise, the divisor is 1.</td>
  *   </tr>
- *   <tr>
- *     <td><em>bv</em>/<em>rad</em>&gt;:</td>
- *     <td><em>bv</em> specifies the rule's base value. To calculate the divisor,
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;"><em>bv</em>/<em>rad</em>&gt;:</td>
+ *     <td style="vertical-align: top;"><em>bv</em> specifies the rule's base value. To calculate the divisor,
  *     let the radix be <em>rad</em>, and the exponent be the highest exponent of the radix that
  *     yields a result less than or equal to the base value. Every &gt; character after the radix
  *     decreases the exponent by 1. If the exponent is positive or 0, the divisor is the radix
  *     raised to the power of the exponent; otherwise, the divisor is 1.</td>
  *   </tr>
- *   <tr>
- *     <td>-x:</td>
- *     <td>The rule is a negative-number rule.</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">-x:</td>
+ *     <td style="vertical-align: top;">The rule is a negative-number rule.</td>
  *   </tr>
- *   <tr>
- *     <td>x.x:</td>
- *     <td>The rule is an <em>improper fraction rule</em>. If the full stop in
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">x.x:</td>
+ *     <td style="vertical-align: top;">The rule is an <em>improper fraction rule</em>. If the full stop in
  *     the middle of the rule name is replaced with the decimal point
  *     that is used in the language or DecimalFormatSymbols, then that rule will
  *     have precedence when formatting and parsing this rule. For example, some
@@ -304,39 +313,39 @@ enum URBNFRuleSetTag {
  *     handle the decimal point that matches the language's natural spelling of
  *     the punctuation of either the full stop or comma.</td>
  *   </tr>
- *   <tr>
- *     <td>0.x:</td>
- *     <td>The rule is a <em>proper fraction rule</em>. If the full stop in
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">0.x:</td>
+ *     <td style="vertical-align: top;">The rule is a <em>proper fraction rule</em>. If the full stop in
  *     the middle of the rule name is replaced with the decimal point
  *     that is used in the language or DecimalFormatSymbols, then that rule will
  *     have precedence when formatting and parsing this rule. For example, some
  *     languages use the comma, and can thus be written as 0,x instead. For example,
  *     you can use "0.x: point &gt;&gt;;0,x: comma &gt;&gt;;" to
  *     handle the decimal point that matches the language's natural spelling of
- *     the punctuation of either the full stop or comma.</td>
+ *     the punctuation of either the full stop or comma</td>
  *   </tr>
- *   <tr>
- *     <td>x.0:</td>
- *     <td>The rule is a <em>default rule</em>. If the full stop in
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">x.0:</td>
+ *     <td style="vertical-align: top;">The rule is a <em>default rule</em>. If the full stop in
  *     the middle of the rule name is replaced with the decimal point
  *     that is used in the language or DecimalFormatSymbols, then that rule will
  *     have precedence when formatting and parsing this rule. For example, some
  *     languages use the comma, and can thus be written as x,0 instead. For example,
  *     you can use "x.0: &lt;&lt; point;x,0: &lt;&lt; comma;" to
  *     handle the decimal point that matches the language's natural spelling of
- *     the punctuation of either the full stop or comma.</td>
+ *     the punctuation of either the full stop or comma</td>
  *   </tr>
- *   <tr>
- *     <td>Inf:</td>
- *     <td>The rule for infinity.</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">Inf:</td>
+ *     <td style="vertical-align: top;">The rule for infinity.</td>
  *   </tr>
- *   <tr>
- *     <td>NaN:</td>
- *     <td>The rule for an IEEE 754 NaN (not a number).</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">NaN:</td>
+ *     <td style="vertical-align: top;">The rule for an IEEE 754 NaN (not a number).</td>
  *   </tr>
- *   <tr>
- *     <td><em>nothing</em></td>
- *     <td>If the rule's rule descriptor is left out, the base value is one plus the
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;"><em>nothing</em></td>
+ *     <td style="vertical-align: top;">If the rule's rule descriptor is left out, the base value is one plus the
  *     preceding rule's base value (or zero if this is the first rule in the list) in a normal
  *     rule set.&nbsp; In a fraction rule set, the base value is the same as the preceding rule's
  *     base value.</td>
@@ -352,8 +361,8 @@ enum URBNFRuleSetTag {
  * algorithms: If the rule set is a regular rule set, do the following:
  *
  * <ul>
- *   <li>If the rule set includes a default rule (and the number was passed in as a <tt>double</tt>),
- *     use the default rule.&nbsp; (If the number being formatted was passed in as a <tt>long</tt>,
+ *   <li>If the rule set includes a default rule (and the number was passed in as a <code>double</code>),
+ *     use the default rule.&nbsp; (If the number being formatted was passed in as a <code>long</code>,
  *     the default rule is ignored.)</li>
  *   <li>If the number is negative, use the negative-number rule.</li>
  *   <li>If the number has a fractional part and is greater than 1, use the improper fraction
@@ -400,112 +409,142 @@ enum URBNFRuleSetTag {
  *
  * <p>The meanings of the substitution token characters are as follows:</p>
  *
- * <table border="0" width="100%">
+ * <table style="border-collapse: collapse;">
  *   <tr>
- *     <td>&gt;&gt;</td>
- *     <td>in normal rule</td>
+ *     <th>Syntax</th>
+ *     <th>Usage</th>
+ *     <th>Description</th>
+ *   </tr>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;" rowspan="4">&gt;&gt;</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in normal rule</td>
  *     <td>Divide the number by the rule's divisor and format the remainder</td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in negative-number rule</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in negative-number rule</td>
  *     <td>Find the absolute value of the number and format the result</td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in fraction or default rule</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in fraction or default rule</td>
  *     <td>Isolate the number's fractional part and format it.</td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in rule in fraction rule set</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in rule in fraction rule set</td>
  *     <td>Not allowed.</td>
  *   </tr>
- *   <tr>
- *     <td>&gt;&gt;&gt;</td>
- *     <td>in normal rule</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;" rowspan="2">&gt;&gt;&gt;</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in normal rule</td>
  *     <td>Divide the number by the rule's divisor and format the remainder,
  *       but bypass the normal rule-selection process and just use the
  *       rule that precedes this one in this rule list.</td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in all other rules</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in all other rules</td>
+ *     <td>Not allowed.</td>
+ *   </tr>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;" rowspan="4">&lt;&lt;</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in normal rule</td>
+ *     <td>Divide the number by the rule's divisor, perform floor() on the quotient,
+ *         and format the resulting value.<br>
+ *         If there is a DecimalFormat pattern between the &lt; characters and the
+ *         rule does NOT also contain a &gt;&gt; substitution, we DON'T perform
+ *         floor() on the quotient-- the quotient is passed through to the DecimalFormat
+ *         intact.  That is, for the value 1,900:<br>
+ *         - "1/1000: &lt;&lt; thousand;" will produce "one thousand"<br>
+ *         - "1/1000: &lt;0&lt; thousand;" will produce "2 thousand" (NOT "1 thousand")<br>
+ *         - "1/1000: &lt;0&lt; seconds &gt;0&gt; milliseconds;" will produce "1 second 900 milliseconds"
+ *     </td>
+ *   </tr>
+ *   <tr>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in negative-number rule</td>
  *     <td>Not allowed.</td>
  *   </tr>
  *   <tr>
- *     <td>&lt;&lt;</td>
- *     <td>in normal rule</td>
- *     <td>Divide the number by the rule's divisor and format the quotient</td>
- *   </tr>
- *   <tr>
- *     <td></td>
- *     <td>in negative-number rule</td>
- *     <td>Not allowed.</td>
- *   </tr>
- *   <tr>
- *     <td></td>
- *     <td>in fraction or default rule</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in fraction or default rule</td>
  *     <td>Isolate the number's integral part and format it.</td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in rule in fraction rule set</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in rule in fraction rule set</td>
  *     <td>Multiply the number by the rule's base value and format the result.</td>
  *   </tr>
- *   <tr>
- *     <td>==</td>
- *     <td>in all rule sets</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;">==</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in all rule sets</td>
  *     <td>Format the number unchanged</td>
  *   </tr>
- *   <tr>
- *     <td>[]</td>
- *     <td>in normal rule</td>
- *     <td>Omit the optional text if the number is an even multiple of the rule's divisor</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;" rowspan="6">[]<br/>[|]</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in normal rule</td>
+ *     <td>
+ *       <ul>
+ *         <li>When the number is not an even multiple of the rule's divisor, use the text and rules between the beginning square bracket,
+ *         and the end square bracket or the | symbol.</li>
+ *         <li>When the number is an even multiple of the rule's divisor, and no | symbol is used, omit the text.</li>
+ *         <li>When the number is an even multiple of the rule's divisor, and | symbol is used, use the text and rules between the | symbol,
+ *         and the end square bracket.</li>
+ *       </ul>
+ *     </td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in negative-number rule</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in improper-fraction rule</td>
+ *     <td>This syntax is the same as specifying both an x.x rule and a 0.x rule.
+ *       <ul>
+ *         <li>When the number is not between 0 and 1, use the text and rules between the beginning square bracket,
+ *         and the end square bracket or the | symbol.</li>
+ *         <li>When the number is between 0 and 1, and no | symbol is used, omit the text.</li>
+ *         <li>When the number is between 0 and 1, and | symbol is used, use the text and rules between the | symbol,
+ *         and the end square bracket.</li>
+ *       </ul>
+ *     </td>
+ *   </tr>
+ *   <tr>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in default rule</td>
+ *     <td>This syntax is the same as specifying both an x.x rule and an x.0 rule.
+ *       <ul>
+ *         <li>When the number is not an integer, use the text and rules between the beginning square bracket,
+ *         and the end square bracket or the | symbol.</li>
+ *         <li>When the number is an integer, and no | symbol is used, omit the text.</li>
+ *         <li>When the number is an integer, and | symbol is used, use the text and rules between the | symbol,
+ *         and the end square bracket.</li>
+ *       </ul>
+ *     </td>
+ *   </tr>
+ *   <tr>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in rule in fraction rule set</td>
+ *     <td>
+ *       <ul>
+ *         <li>When multiplying the number by the rule's base value does not yield 1, use the text and rules between the beginning square bracket,
+ *         and the end square bracket or the | symbol.</li>
+ *         <li>When multiplying the number by the rule's base value yields 1, and no | symbol is used, omit the text.</li>
+ *         <li>When multiplying the number by the rule's base value yields 1, and | symbol is used, use the text and rules between the | symbol,
+ *         and the end square bracket.</li>
+ *       </ul>
+ *     </td>
+ *   </tr>
+ *   <tr>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in proper-fraction rule</td>
  *     <td>Not allowed.</td>
  *   </tr>
  *   <tr>
- *     <td></td>
- *     <td>in improper-fraction rule</td>
- *     <td>Omit the optional text if the number is between 0 and 1 (same as specifying both an
- *     x.x rule and a 0.x rule)</td>
- *   </tr>
- *   <tr>
- *     <td></td>
- *     <td>in default rule</td>
- *     <td>Omit the optional text if the number is an integer (same as specifying both an x.x
- *     rule and an x.0 rule)</td>
- *   </tr>
- *   <tr>
- *     <td></td>
- *     <td>in proper-fraction rule</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in negative-number rule</td>
  *     <td>Not allowed.</td>
  *   </tr>
- *   <tr>
- *     <td></td>
- *     <td>in rule in fraction rule set</td>
- *     <td>Omit the optional text if multiplying the number by the rule's base value yields 1.</td>
- *   </tr>
- *   <tr>
- *     <td width="37">$(cardinal,<i>plural syntax</i>)$</td>
- *     <td width="23"></td>
- *     <td width="165" valign="top">in all rule sets</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;">$(cardinal,<i>plural syntax</i>)$</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in all rule sets</td>
  *     <td>This provides the ability to choose a word based on the number divided by the radix to the power of the
  *     exponent of the base value for the specified locale, which is normally equivalent to the &lt;&lt; value.
- *     This uses the cardinal plural rules from PluralFormat. All strings used in the plural format are treated
+ *     This uses the cardinal plural rules from {@link PluralFormat}. All strings used in the plural format are treated
  *     as the same base value for parsing.</td>
  *   </tr>
- *   <tr>
- *     <td width="37">$(ordinal,<i>plural syntax</i>)$</td>
- *     <td width="23"></td>
- *     <td width="165" valign="top">in all rule sets</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="white-space: nowrap;">$(ordinal,<i>plural syntax</i>)$</td>
+ *     <td style="white-space: nowrap; vertical-align: top; padding-left: 1em; padding-right: 1em;">in all rule sets</td>
  *     <td>This provides the ability to choose a word based on the number divided by the radix to the power of the
  *     exponent of the base value for the specified locale, which is normally equivalent to the &lt;&lt; value.
- *     This uses the ordinal plural rules from PluralFormat. All strings used in the plural format are treated
+ *     This uses the ordinal plural rules from {@link PluralFormat}. All strings used in the plural format are treated
  *     as the same base value for parsing.</td>
  *   </tr>
  * </table>
@@ -513,22 +552,25 @@ enum URBNFRuleSetTag {
  * <p>The substitution descriptor (i.e., the text between the token characters) may take one
  * of three forms:</p>
  *
- * <table border="0" width="100%">
+ * <table style="border-collapse: collapse;">
  *   <tr>
- *     <td>a rule set name</td>
+ *     <th>Descriptor</th>
+ *     <th>Description</th>
+ *   </tr>
+ *   <tr>
+ *     <td style="vertical-align: top;">a rule set name</td>
  *     <td>Perform the mathematical operation on the number, and format the result using the
  *     named rule set.</td>
  *   </tr>
- *   <tr>
- *     <td>a DecimalFormat pattern</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">a DecimalFormat pattern</td>
  *     <td>Perform the mathematical operation on the number, and format the result using a
  *     DecimalFormat with the specified pattern.&nbsp; The pattern must begin with 0 or #.</td>
  *   </tr>
- *   <tr>
- *     <td>nothing</td>
+ *   <tr style="border-top: 1px solid black;">
+ *     <td style="vertical-align: top;">nothing</td>
  *     <td>Perform the mathematical operation on the number, and format the result using the rule
- *     set containing the current rule, except:
- *     <ul>
+ *     set containing the current rule, except:<ul>
  *       <li>You can't have an empty substitution descriptor with a == substitution.</li>
  *       <li>If you omit the substitution descriptor in a &gt;&gt; substitution in a fraction rule,
  *         format the result one digit at a time using the rule set containing the current rule.</li>
@@ -764,7 +806,7 @@ public:
    * @return the number of locales for which we have localized rule set display names.
    * @stable ICU 3.2
    */
-  virtual int32_t getNumberOfRuleSetDisplayNameLocales(void) const;
+  virtual int32_t getNumberOfRuleSetDisplayNameLocales() const;
 
   /**
    * Return the index'th display name locale.
@@ -978,7 +1020,7 @@ public:
    * @see #setLenient
    * @stable ICU 2.0
    */
-  virtual inline UBool isLenient(void) const override;
+  virtual inline UBool isLenient() const override;
 
 #endif
 
@@ -1017,7 +1059,7 @@ public:
      * @return A rounding mode
      * @stable ICU 60
      */
-    virtual ERoundingMode getRoundingMode(void) const override;
+    virtual ERoundingMode getRoundingMode() const override;
 
     /**
      * Set the rounding mode.
@@ -1032,14 +1074,14 @@ public:
      *
      * @stable ICU 2.8
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * ICU "poor man's RTTI", returns a UClassID for the actual class.
      *
      * @stable ICU 2.8
      */
-    virtual UClassID getDynamicClassID(void) const override;
+    virtual UClassID getDynamicClassID() const override;
 
     /**
      * Sets the decimal format symbols, which is generally not changed
@@ -1122,7 +1164,7 @@ private:
 #if !UCONFIG_NO_COLLATION
 
 inline UBool
-RuleBasedNumberFormat::isLenient(void) const {
+RuleBasedNumberFormat::isLenient() const {
     return lenient;
 }
 
