@@ -124,7 +124,7 @@ public:
      * @return current index in the text being searched.
      * @stable ICU 2.0
      */
-    virtual int32_t getOffset(void) const = 0;
+    virtual int32_t getOffset() const = 0;
 
     /**
     * Sets the text searching attributes located in the enum
@@ -163,7 +163,7 @@ public:
     * @see #last
     * @stable ICU 2.0
     */
-    int32_t getMatchedStart(void) const;
+    int32_t getMatchedStart() const;
 
     /**
      * Returns the length of text in the string which matches the search
@@ -179,7 +179,7 @@ public:
      * @see #last
      * @stable ICU 2.0
      */
-    int32_t getMatchedLength(void) const;
+    int32_t getMatchedLength() const;
 
     /**
      * Returns the text that was matched by the most recent call to
@@ -224,7 +224,7 @@ public:
      * @see #setBreakIterator
      * @stable ICU 2.0
      */
-    const BreakIterator * getBreakIterator(void) const;
+    const BreakIterator* getBreakIterator() const;
 
     /**
      * Set the string text to be searched. Text iteration will hence begin at
@@ -260,7 +260,7 @@ public:
      * @return text string to be searched.
      * @stable ICU 2.0
      */
-    const UnicodeString & getText(void) const;
+    const UnicodeString& getText() const;
 
     // operator overloading ----------------------------------------------
 
@@ -291,7 +291,7 @@ public:
      * @return cloned object
      * @stable ICU 2.0
      */
-    virtual SearchIterator* safeClone(void) const = 0;
+    virtual SearchIterator* safeClone() const = 0;
 
     /**
      * Returns the first index at which the string text matches the search
