@@ -163,7 +163,7 @@ public:
      * @see getUnknown
      * @stable ICU 2.0
      */
-    static const TimeZone* U_EXPORT2 getGMT(void);
+    static const TimeZone* U_EXPORT2 getGMT();
 
     /**
      * Creates a <code>TimeZone</code> for the given ID.
@@ -323,7 +323,7 @@ public:
      * @see #countEquivalentIDs
      * @stable ICU 2.0
      */
-    static const UnicodeString U_EXPORT2 getEquivalentID(const UnicodeString& id,
+    static UnicodeString U_EXPORT2 getEquivalentID(const UnicodeString& id,
                                                int32_t index);
 
     /**
@@ -364,7 +364,7 @@ public:
      * @see getUnknown
      * @stable ICU 2.0
      */
-    static TimeZone* U_EXPORT2 createDefault(void);
+    static TimeZone* U_EXPORT2 createDefault();
 
 #ifndef U_HIDE_INTERNAL_API
     /**
@@ -445,7 +445,6 @@ public:
         UnicodeString& canonicalID, UBool& isSystemID, UErrorCode& status);
 
 
-#ifndef U_HIDE_DRAFT_API
     /**
      * Returns the preferred time zone ID in the IANA time zone database for the given time zone ID.
      * There are two types of preferred IDs. The first type is the one defined in zone.tab file,
@@ -469,11 +468,10 @@ public:
      * @param status    Receives the status.  When the given time zone ID is not a known time zone
      *                  ID, U_ILLEGAL_ARGUMENT_ERROR is set.
      * @return  A reference to the result.
-     * @draft ICU 74
+     * @stable ICU 74
      */
     static UnicodeString& U_EXPORT2 getIanaID(const UnicodeString&id, UnicodeString& ianaID,
         UErrorCode& status);
-#endif // U_HIDE_DRAFT_API
 
     /**
     * Converts a system time zone ID to an equivalent Windows time zone ID. For example,
@@ -644,7 +642,7 @@ public:
      * @return   The TimeZone's raw GMT offset.
      * @stable ICU 2.0
      */
-    virtual int32_t getRawOffset(void) const = 0;
+    virtual int32_t getRawOffset() const = 0;
 
     /**
      * Fills in "ID" with the TimeZone's ID.
@@ -813,7 +811,7 @@ public:
      *
      * @stable ICU 2.0
      */
-    virtual UBool useDaylightTime(void) const = 0;
+    virtual UBool useDaylightTime() const = 0;
 
 #ifndef U_FORCE_HIDE_DEPRECATED_API
     /**
@@ -857,7 +855,7 @@ public:
      * @return The class ID for all objects of this class.
      * @stable ICU 2.0
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * Returns a unique class ID POLYMORPHICALLY. This method is to
@@ -870,7 +868,7 @@ public:
      *           same class ID. Objects of other classes have different class IDs.
      * @stable ICU 2.0
      */
-    virtual UClassID getDynamicClassID(void) const override = 0;
+    virtual UClassID getDynamicClassID() const override = 0;
 
     /**
      * Returns the amount of time to be added to local standard time
