@@ -80,7 +80,7 @@ public:
      * @return  The standard time offset from UTC in milliseconds.
      * @stable ICU 3.8
      */
-    int32_t getRawOffset(void) const;
+    int32_t getRawOffset() const;
 
     /**
      * Gets the amount of daylight saving delta time from the standard time.
@@ -88,7 +88,7 @@ public:
      *          in milliseconds.
      * @stable ICU 3.8
      */
-    int32_t getDSTSavings(void) const;
+    int32_t getDSTSavings() const;
 
     /**
      * Returns if this rule represents the same rule and offsets as another.
@@ -340,7 +340,7 @@ public:
      * @return          The class ID for all objects of this class.
      * @stable ICU 3.8
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * Returns a unique class ID POLYMORPHICALLY. Pure virtual override. This
@@ -353,7 +353,7 @@ public:
      *                  other classes have different class IDs.
      * @stable ICU 3.8
      */
-    virtual UClassID getDynamicClassID(void) const override;
+    virtual UClassID getDynamicClassID() const override;
 };
 
 /**
@@ -461,7 +461,7 @@ public:
      *          rule used by this time zone rule.
      * @stable ICU 3.8
      */
-    const DateTimeRule* getRule(void) const;
+    const DateTimeRule* getRule() const;
 
     /**
      * Gets the first year when this rule takes effect.
@@ -469,7 +469,7 @@ public:
      *          with 0 == 1 BCE, -1 == 2 BCE, etc.
      * @stable ICU 3.8
      */
-    int32_t getStartYear(void) const;
+    int32_t getStartYear() const;
 
     /**
      * Gets the end year when this rule takes effect.
@@ -477,7 +477,7 @@ public:
      *          with 0 == 1 BCE, -1 == 2 BCE, etc.
      * @stable ICU 3.8
      */
-    int32_t getEndYear(void) const;
+    int32_t getEndYear() const;
 
     /**
      * Gets the time when this rule takes effect in the given year.
@@ -581,7 +581,7 @@ public:
      * @return          The class ID for all objects of this class.
      * @stable ICU 3.8
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * Returns a unique class ID POLYMORPHICALLY. Pure virtual override. This
@@ -594,7 +594,7 @@ public:
      *                  other classes have different class IDs.
      * @stable ICU 3.8
      */
-    virtual UClassID getDynamicClassID(void) const override;
+    virtual UClassID getDynamicClassID() const override;
 };
 
 /**
@@ -679,7 +679,7 @@ public:
      * @return The time type used of the start times used by this rule.
      * @stable ICU 3.8
      */
-    DateTimeRule::TimeRuleType getTimeType(void) const;
+    DateTimeRule::TimeRuleType getTimeType() const;
 
     /**
      * Gets a start time at the index stored in this rule.
@@ -697,7 +697,7 @@ public:
      * @return The number of start times.
      * @stable ICU 3.8
      */
-    int32_t countStartTimes(void) const;
+    int32_t countStartTimes() const;
 
     /**
      * Returns if this rule represents the same rule and offsets as another.
@@ -792,7 +792,7 @@ public:
      * @return          The class ID for all objects of this class.
      * @stable ICU 3.8
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * Returns a unique class ID POLYMORPHICALLY. Pure virtual override. This
@@ -805,7 +805,7 @@ public:
      *                  other classes have different class IDs.
      * @stable ICU 3.8
      */
-    virtual UClassID getDynamicClassID(void) const override;
+    virtual UClassID getDynamicClassID() const override;
 };
 
 
