@@ -167,9 +167,9 @@ unum_clone(const UNumberFormat *fmt,
        UErrorCode *status)
 {
     if(U_FAILURE(*status))
-        return 0;
+        return nullptr;
 
-    Format *res = 0;
+    Format* res = nullptr;
     const NumberFormat* nf = reinterpret_cast<const NumberFormat*>(fmt);
     const DecimalFormat* df = dynamic_cast<const DecimalFormat*>(nf);
     if (df != nullptr) {
@@ -180,9 +180,9 @@ unum_clone(const UNumberFormat *fmt,
         res = rbnf->clone();
     }
 
-    if(res == 0) {
+    if (res == nullptr) {
         *status = U_MEMORY_ALLOCATION_ERROR;
-        return 0;
+        return nullptr;
     }
 
     return (UNumberFormat*) res;
@@ -219,12 +219,12 @@ unum_formatInt64(const UNumberFormat* fmt,
 
     FieldPosition fp;
 
-    if(pos != 0)
+    if (pos != nullptr)
         fp.setField(pos->field);
 
     ((const NumberFormat*)fmt)->format(number, res, fp, *status);
 
-    if(pos != 0) {
+    if (pos != nullptr) {
         pos->beginIndex = fp.getBeginIndex();
         pos->endIndex = fp.getEndIndex();
     }
@@ -252,12 +252,12 @@ unum_formatDouble(    const    UNumberFormat*  fmt,
 
   FieldPosition fp;
 
-  if(pos != 0)
+  if (pos != nullptr)
     fp.setField(pos->field);
 
   ((const NumberFormat*)fmt)->format(number, res, fp, *status);
 
-  if(pos != 0) {
+  if (pos != nullptr) {
     pos->beginIndex = fp.getBeginIndex();
     pos->endIndex = fp.getEndIndex();
   }
@@ -311,7 +311,7 @@ unum_formatDecimal(const    UNumberFormat*  fmt,
     }
 
     FieldPosition fp;
-    if(pos != 0) {
+    if (pos != nullptr) {
         fp.setField(pos->field);
     }
 
@@ -327,7 +327,7 @@ unum_formatDecimal(const    UNumberFormat*  fmt,
         resultStr.setTo(result, 0, resultLength);
     }
     ((const NumberFormat*)fmt)->format(numFmtbl, resultStr, fp, *status);
-    if(pos != 0) {
+    if (pos != nullptr) {
         pos->beginIndex = fp.getBeginIndex();
         pos->endIndex = fp.getEndIndex();
     }
@@ -355,7 +355,7 @@ unum_formatDoubleCurrency(const UNumberFormat* fmt,
     }
 
     FieldPosition fp;
-    if (pos != 0) {
+    if (pos != nullptr) {
         fp.setField(pos->field);
     }
     CurrencyAmount *tempCurrAmnt = new CurrencyAmount(number, currency, *status);
@@ -367,7 +367,7 @@ unum_formatDoubleCurrency(const UNumberFormat* fmt,
     Formattable n(tempCurrAmnt);
     ((const NumberFormat*)fmt)->format(n, res, fp, *status);
 
-    if (pos != 0) {
+    if (pos != nullptr) {
         pos->beginIndex = fp.getBeginIndex();
         pos->endIndex = fp.getEndIndex();
     }
@@ -386,20 +386,20 @@ parseRes(Formattable& res,
     if(U_FAILURE(*status))
         return;
 
-    const UnicodeString src((UBool)(textLength == -1), text, textLength);
+    const UnicodeString src(static_cast<UBool>(textLength == -1), text, textLength);
     ParsePosition pp;
 
-    if(parsePos != 0)
+    if (parsePos != nullptr)
         pp.setIndex(*parsePos);
 
-    ((const NumberFormat*)fmt)->parse(src, res, pp);
+    reinterpret_cast<const NumberFormat*>(fmt)->parse(src, res, pp);
 
     if(pp.getErrorIndex() != -1) {
         *status = U_PARSE_ERROR;
-        if(parsePos != 0) {
+        if (parsePos != nullptr) {
             *parsePos = pp.getErrorIndex();
         }
-    } else if(parsePos != 0) {
+    } else if (parsePos != nullptr) {
         *parsePos = pp.getIndex();
     }
 }
@@ -485,7 +485,7 @@ unum_parseDoubleCurrency(const UNumberFormat* fmt,
     if (U_FAILURE(*status)) {
         return doubleVal;
     }
-    const UnicodeString src((UBool)(textLength == -1), text, textLength);
+    const UnicodeString src(textLength == -1, text, textLength);
     ParsePosition pp;
     if (parsePos != nullptr) {
         pp.setIndex(*parsePos);
@@ -923,7 +923,6 @@ unum_setContext(UNumberFormat* fmt, UDisplayContext value, UErrorCode* status)
         return;
     }
     ((NumberFormat*)fmt)->setContext(value, *status);
-    return;
 }
 
 U_CAPI UDisplayContext U_EXPORT2
@@ -978,12 +977,12 @@ unum_formatUFormattable(const UNumberFormat* fmt,
 
     FieldPosition fp;
 
-    if(pos != 0)
+    if (pos != nullptr)
         fp.setField(pos->field);
 
     ((const NumberFormat*)fmt)->format(*(Formattable::fromUFormattable(number)), res, fp, *status);
 
-    if(pos != 0) {
+    if (pos != nullptr) {
         pos->beginIndex = fp.getBeginIndex();
         pos->endIndex = fp.getEndIndex();
     }
