@@ -30,7 +30,6 @@
 #include "unicode/timezone.h"
 #include "unicode/utmscale.h"
 
-#include "bytesinkutil.h"
 #include "charstr.h"
 #include "cmemory.h"
 #include "ulocimp.h"
@@ -47,6 +46,7 @@
 #   define NOIME
 #   define NOMCX
 #include <windows.h>
+#include <typeinfo>
 
 U_NAMESPACE_BEGIN
 
@@ -104,11 +104,7 @@ static UErrorCode GetEquivalentWindowsLocaleName(const Locale& locale, UnicodeSt
     UErrorCode status = U_ZERO_ERROR;
 
     // Convert from names like "en_CA" and "de_DE@collation=phonebook" to "en-CA" and "de-DE-u-co-phonebk".
-    CharString asciiBCP47Tag;
-    {
-        CharStringByteSink sink(&asciiBCP47Tag);
-        ulocimp_toLanguageTag(locale.getName(), sink, false, &status);
-    }
+    CharString asciiBCP47Tag = ulocimp_toLanguageTag(locale.getName(), false, status);
 
     if (U_SUCCESS(status))
     {
@@ -256,7 +252,7 @@ UnicodeString &Win32DateFormat::format(Calendar &cal, UnicodeString &appendTo, F
         formatDate(&st_local, date);
         formatTime(&st_local, time);
 
-        if (strcmp(fCalendar->getType(), cal.getType()) != 0) {
+        if (typeid(cal) != typeid(*fCalendar)) {
             pattern = getTimeDateFormat(&cal, &fLocale, status);
         }
 
@@ -277,7 +273,7 @@ void Win32DateFormat::parse(const UnicodeString& /* text */, Calendar& /* cal */
 
 void Win32DateFormat::adoptCalendar(Calendar *newCalendar)
 {
-    if (fCalendar == nullptr || strcmp(fCalendar->getType(), newCalendar->getType()) != 0) {
+    if (fCalendar == nullptr || typeid(*fCalendar) != typeid(*newCalendar)) {
         UErrorCode status = U_ZERO_ERROR;
 
         if (fDateStyle != DateFormat::kNone && fTimeStyle != DateFormat::kNone) {
@@ -412,4 +408,3 @@ U_NAMESPACE_END
 #endif /* #if !UCONFIG_NO_FORMATTING */
 
 #endif // U_PLATFORM_USES_ONLY_WIN32_API
-
