@@ -24,7 +24,6 @@
 #include "unicode/locid.h"
 #include "unicode/ustring.h"
 
-#include "bytesinkutil.h"
 #include "charstr.h"
 #include "cmemory.h"
 #include "uassert.h"
@@ -149,11 +148,7 @@ static UErrorCode GetEquivalentWindowsLocaleName(const Locale& locale, UnicodeSt
     UErrorCode status = U_ZERO_ERROR;
 
     // Convert from names like "en_CA" and "de_DE@collation=phonebook" to "en-CA" and "de-DE-u-co-phonebk".
-    CharString asciiBCP47Tag;
-    {
-        CharStringByteSink sink(&asciiBCP47Tag);
-        ulocimp_toLanguageTag(locale.getName(), sink, false, &status);
-    }
+    CharString asciiBCP47Tag = ulocimp_toLanguageTag(locale.getName(), false, status);
 
     if (U_SUCCESS(status))
     {
