@@ -29,9 +29,9 @@
 #include "private/save.h"
 
 /************************************************************************
- *                                    *
- *        Getting/Setting encoding meta tags            *
- *                                    *
+ *                                                                      *
+ *              Getting/Setting encoding meta tags                      *
+ *                                                                      *
  ************************************************************************/
 
 /**
@@ -49,41 +49,41 @@ htmlGetMetaEncoding(htmlDocPtr doc) {
     const xmlChar *encoding;
 
     if (doc == NULL)
-    return(NULL);
+        return(NULL);
     cur = doc->children;
 
     /*
      * Search the html
      */
     while (cur != NULL) {
-    if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
-        if (xmlStrEqual(cur->name, BAD_CAST"html"))
-        break;
-        if (xmlStrEqual(cur->name, BAD_CAST"head"))
-        goto found_head;
-        if (xmlStrEqual(cur->name, BAD_CAST"meta"))
-        goto found_meta;
-    }
-    cur = cur->next;
+        if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
+            if (xmlStrEqual(cur->name, BAD_CAST"html"))
+                break;
+            if (xmlStrEqual(cur->name, BAD_CAST"head"))
+                goto found_head;
+            if (xmlStrEqual(cur->name, BAD_CAST"meta"))
+                goto found_meta;
+        }
+        cur = cur->next;
     }
     if (cur == NULL)
-    return(NULL);
+        return(NULL);
     cur = cur->children;
 
     /*
      * Search the head
      */
     while (cur != NULL) {
-    if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
-        if (xmlStrEqual(cur->name, BAD_CAST"head"))
-        break;
-        if (xmlStrEqual(cur->name, BAD_CAST"meta"))
-        goto found_meta;
-    }
-    cur = cur->next;
+        if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
+            if (xmlStrEqual(cur->name, BAD_CAST"head"))
+                break;
+            if (xmlStrEqual(cur->name, BAD_CAST"meta"))
+                goto found_meta;
+        }
+        cur = cur->next;
     }
     if (cur == NULL)
-    return(NULL);
+        return(NULL);
 found_head:
     cur = cur->children;
 
@@ -92,55 +92,55 @@ found_head:
      */
 found_meta:
     while (cur != NULL) {
-    if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
-        if (xmlStrEqual(cur->name, BAD_CAST"meta")) {
-        xmlAttrPtr attr = cur->properties;
-        int http;
-        const xmlChar *value;
+        if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
+            if (xmlStrEqual(cur->name, BAD_CAST"meta")) {
+                xmlAttrPtr attr = cur->properties;
+                int http;
+                const xmlChar *value;
 
-        content = NULL;
-        http = 0;
-        while (attr != NULL) {
-            if ((attr->children != NULL) &&
-                (attr->children->type == XML_TEXT_NODE) &&
-                (attr->children->next == NULL)) {
-            value = attr->children->content;
-            if ((!xmlStrcasecmp(attr->name, BAD_CAST"http-equiv"))
-             && (!xmlStrcasecmp(value, BAD_CAST"Content-Type")))
-                http = 1;
-            else if ((value != NULL)
-             && (!xmlStrcasecmp(attr->name, BAD_CAST"content")))
-                content = value;
-            if ((http != 0) && (content != NULL))
-                goto found_content;
+                content = NULL;
+                http = 0;
+                while (attr != NULL) {
+                    if ((attr->children != NULL) &&
+                        (attr->children->type == XML_TEXT_NODE) &&
+                        (attr->children->next == NULL)) {
+                        value = attr->children->content;
+                        if ((!xmlStrcasecmp(attr->name, BAD_CAST"http-equiv"))
+                         && (!xmlStrcasecmp(value, BAD_CAST"Content-Type")))
+                            http = 1;
+                        else if ((value != NULL)
+                         && (!xmlStrcasecmp(attr->name, BAD_CAST"content")))
+                            content = value;
+                        if ((http != 0) && (content != NULL))
+                            goto found_content;
+                    }
+                    attr = attr->next;
+                }
             }
-            attr = attr->next;
         }
-        }
-    }
-    cur = cur->next;
+        cur = cur->next;
     }
     return(NULL);
 
 found_content:
     encoding = xmlStrstr(content, BAD_CAST"charset=");
     if (encoding == NULL)
-    encoding = xmlStrstr(content, BAD_CAST"Charset=");
+        encoding = xmlStrstr(content, BAD_CAST"Charset=");
     if (encoding == NULL)
-    encoding = xmlStrstr(content, BAD_CAST"CHARSET=");
+        encoding = xmlStrstr(content, BAD_CAST"CHARSET=");
     if (encoding != NULL) {
-    encoding += 8;
+        encoding += 8;
     } else {
-    encoding = xmlStrstr(content, BAD_CAST"charset =");
-    if (encoding == NULL)
-        encoding = xmlStrstr(content, BAD_CAST"Charset =");
-    if (encoding == NULL)
-        encoding = xmlStrstr(content, BAD_CAST"CHARSET =");
-    if (encoding != NULL)
-        encoding += 9;
+        encoding = xmlStrstr(content, BAD_CAST"charset =");
+        if (encoding == NULL)
+            encoding = xmlStrstr(content, BAD_CAST"Charset =");
+        if (encoding == NULL)
+            encoding = xmlStrstr(content, BAD_CAST"CHARSET =");
+        if (encoding != NULL)
+            encoding += 9;
     }
     if (encoding != NULL) {
-    while ((*encoding == ' ') || (*encoding == '\t')) encoding++;
+        while ((*encoding == ' ') || (*encoding == '\t')) encoding++;
     }
     return(encoding);
 }
@@ -165,16 +165,16 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
     newcontent[0] = 0;
 
     if (doc == NULL)
-    return(-1);
+        return(-1);
 
     /* html isn't a real encoding it's just libxml2 way to get entities */
     if (!xmlStrcasecmp(encoding, BAD_CAST "html"))
         return(-1);
 
     if (encoding != NULL) {
-    snprintf(newcontent, sizeof(newcontent), "text/html; charset=%s",
+        snprintf(newcontent, sizeof(newcontent), "text/html; charset=%s",
                 (char *)encoding);
-    newcontent[sizeof(newcontent) - 1] = 0;
+        newcontent[sizeof(newcontent) - 1] = 0;
     }
 
     cur = doc->children;
@@ -183,36 +183,36 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
      * Search the html
      */
     while (cur != NULL) {
-    if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
-        if (xmlStrcasecmp(cur->name, BAD_CAST"html") == 0)
-        break;
-        if (xmlStrcasecmp(cur->name, BAD_CAST"head") == 0)
-        goto found_head;
-        if (xmlStrcasecmp(cur->name, BAD_CAST"meta") == 0)
-        goto found_meta;
-    }
-    cur = cur->next;
+        if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
+            if (xmlStrcasecmp(cur->name, BAD_CAST"html") == 0)
+                break;
+            if (xmlStrcasecmp(cur->name, BAD_CAST"head") == 0)
+                goto found_head;
+            if (xmlStrcasecmp(cur->name, BAD_CAST"meta") == 0)
+                goto found_meta;
+        }
+        cur = cur->next;
     }
     if (cur == NULL)
-    return(-1);
+        return(-1);
     cur = cur->children;
 
     /*
      * Search the head
      */
     while (cur != NULL) {
-    if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
-        if (xmlStrcasecmp(cur->name, BAD_CAST"head") == 0)
-        break;
-        if (xmlStrcasecmp(cur->name, BAD_CAST"meta") == 0) {
+        if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
+            if (xmlStrcasecmp(cur->name, BAD_CAST"head") == 0)
+                break;
+            if (xmlStrcasecmp(cur->name, BAD_CAST"meta") == 0) {
                 head = cur->parent;
-        goto found_meta;
+                goto found_meta;
             }
-    }
-    cur = cur->next;
+        }
+        cur = cur->next;
     }
     if (cur == NULL)
-    return(-1);
+        return(-1);
 found_head:
     head = cur;
     if (cur->children == NULL)
@@ -225,41 +225,41 @@ found_meta:
      * encoding information
      */
     while (cur != NULL) {
-    if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
-        if (xmlStrcasecmp(cur->name, BAD_CAST"meta") == 0) {
-        xmlAttrPtr attr = cur->properties;
-        int http;
-        const xmlChar *value;
+        if ((cur->type == XML_ELEMENT_NODE) && (cur->name != NULL)) {
+            if (xmlStrcasecmp(cur->name, BAD_CAST"meta") == 0) {
+                xmlAttrPtr attr = cur->properties;
+                int http;
+                const xmlChar *value;
 
-        content = NULL;
-        http = 0;
-        while (attr != NULL) {
-            if ((attr->children != NULL) &&
-                (attr->children->type == XML_TEXT_NODE) &&
-                (attr->children->next == NULL)) {
-            value = attr->children->content;
-            if ((!xmlStrcasecmp(attr->name, BAD_CAST"http-equiv"))
-             && (!xmlStrcasecmp(value, BAD_CAST"Content-Type")))
-                http = 1;
-            else
+                content = NULL;
+                http = 0;
+                while (attr != NULL) {
+                    if ((attr->children != NULL) &&
+                        (attr->children->type == XML_TEXT_NODE) &&
+                        (attr->children->next == NULL)) {
+                        value = attr->children->content;
+                        if ((!xmlStrcasecmp(attr->name, BAD_CAST"http-equiv"))
+                         && (!xmlStrcasecmp(value, BAD_CAST"Content-Type")))
+                            http = 1;
+                        else
                         {
                            if ((value != NULL) &&
                                (!xmlStrcasecmp(attr->name, BAD_CAST"content")))
-                   content = value;
+                               content = value;
                         }
-                if ((http != 0) && (content != NULL))
-                break;
-            }
-            attr = attr->next;
-        }
-        if ((http != 0) && (content != NULL)) {
-            meta = cur;
-            break;
-        }
+                        if ((http != 0) && (content != NULL))
+                            break;
+                    }
+                    attr = attr->next;
+                }
+                if ((http != 0) && (content != NULL)) {
+                    meta = cur;
+                    break;
+                }
 
+            }
         }
-    }
-    cur = cur->next;
+        cur = cur->next;
     }
 create:
     if (meta == NULL) {
@@ -311,6 +311,8 @@ static const char* const htmlBooleanAttrs[] = {
  * htmlIsBooleanAttr:
  * @name:  the name of the attribute to check
  *
+ * DEPRECATED: Internal function, don't use.
+ *
  * Determine if a given attribute is a boolean attribute.
  *
  * returns: false if the attribute is not boolean, true otherwise.
@@ -330,75 +332,20 @@ htmlIsBooleanAttr(const xmlChar *name)
 
 #ifdef LIBXML_OUTPUT_ENABLED
 /************************************************************************
- *                                    *
- *            Output error handlers                *
- *                                    *
+ *                                                                      *
+ *              Dumping HTML tree content to a simple buffer            *
+ *                                                                      *
  ************************************************************************/
 
-/**
- * htmlSaveErr:
- * @code:  the error number
- * @node:  the location of the error.
- * @extra:  extra information
- *
- * Handle an out of memory condition
- */
-static void
-htmlSaveErr(int code, xmlNodePtr node, const char *extra)
-{
-    const char *msg = NULL;
-    int res;
+static xmlParserErrors
+htmlFindOutputEncoder(const char *encoding, xmlCharEncodingHandler **out) {
+    /*
+     * Fallback to HTML if the encoding is unspecified
+     */
+    if (encoding == NULL)
+        encoding = "HTML";
 
-    switch(code) {
-        case XML_SAVE_NOT_UTF8:
-        msg = "string is not in UTF-8\n";
-        break;
-    case XML_SAVE_CHAR_INVALID:
-        msg = "invalid character value\n";
-        break;
-    case XML_SAVE_UNKNOWN_ENCODING:
-        msg = "unknown encoding %s\n";
-        break;
-    case XML_SAVE_NO_DOCTYPE:
-        msg = "HTML has no DOCTYPE\n";
-        break;
-    default:
-        msg = "unexpected error number\n";
-    }
-
-    res = __xmlRaiseError(NULL, NULL, NULL, NULL, node,
-                          XML_FROM_OUTPUT, code, XML_ERR_ERROR, NULL, 0,
-                          extra, NULL, NULL, 0, 0,
-                          msg, extra);
-    if (res < 0)
-        xmlRaiseMemoryError(NULL, NULL, NULL, XML_FROM_OUTPUT, NULL);
-}
-
-/************************************************************************
- *                                    *
- *        Dumping HTML tree content to a simple buffer        *
- *                                    *
- ************************************************************************/
-
-static xmlCharEncodingHandler *
-htmlFindOutputEncoder(const char *encoding) {
-    xmlCharEncodingHandler *handler = NULL;
-
-    if (encoding != NULL) {
-        int res;
-
-        res = xmlOpenCharEncodingHandler(encoding, /* output */ 1,
-                                         &handler);
-        if (res != XML_ERR_OK)
-            htmlSaveErr(XML_SAVE_UNKNOWN_ENCODING, NULL, encoding);
-    } else {
-        /*
-         * Fallback to HTML when the encoding is unspecified
-         */
-        xmlOpenCharEncodingHandler("HTML", /* output */ 1, &handler);
-    }
-
-    return(handler);
+    return(xmlOpenCharEncodingHandler(encoding, /* output */ 1, out));
 }
 
 /**
@@ -414,20 +361,20 @@ htmlFindOutputEncoder(const char *encoding) {
  */
 static size_t
 htmlBufNodeDumpFormat(xmlBufPtr buf, xmlDocPtr doc, xmlNodePtr cur,
-               int format) {
+                   int format) {
     size_t use;
     size_t ret;
     xmlOutputBufferPtr outbuf;
 
     if (cur == NULL) {
-    return ((size_t) -1);
+        return ((size_t) -1);
     }
     if (buf == NULL) {
-    return ((size_t) -1);
+        return ((size_t) -1);
     }
     outbuf = (xmlOutputBufferPtr) xmlMalloc(sizeof(xmlOutputBuffer));
     if (outbuf == NULL)
-    return ((size_t) -1);
+        return ((size_t) -1);
     memset(outbuf, 0, sizeof(xmlOutputBuffer));
     outbuf->buffer = buf;
     outbuf->encoder = NULL;
@@ -460,7 +407,8 @@ htmlBufNodeDumpFormat(xmlBufPtr buf, xmlDocPtr doc, xmlNodePtr cur,
 int
 htmlNodeDump(xmlBufferPtr buf, xmlDocPtr doc, xmlNodePtr cur) {
     xmlBufPtr buffer;
-    size_t ret;
+    size_t ret1;
+    int ret2;
 
     if ((buf == NULL) || (cur == NULL))
         return(-1);
@@ -470,14 +418,13 @@ htmlNodeDump(xmlBufferPtr buf, xmlDocPtr doc, xmlNodePtr cur) {
     if (buffer == NULL)
         return(-1);
 
-    xmlBufSetAllocationScheme(buffer, XML_BUFFER_ALLOC_DOUBLEIT);
-    ret = htmlBufNodeDumpFormat(buffer, doc, cur, 1);
+    ret1 = htmlBufNodeDumpFormat(buffer, doc, cur, 1);
 
-    xmlBufBackToBuffer(buffer);
+    ret2 = xmlBufBackToBuffer(buffer, buf);
 
-    if (ret > INT_MAX)
+    if ((ret1 == (size_t) -1) || (ret2 < 0))
         return(-1);
-    return((int) ret);
+    return(ret1 > INT_MAX ? INT_MAX : ret1);
 }
 
 /**
@@ -496,7 +443,7 @@ htmlNodeDump(xmlBufferPtr buf, xmlDocPtr doc, xmlNodePtr cur) {
  */
 int
 htmlNodeDumpFileFormat(FILE *out, xmlDocPtr doc,
-                   xmlNodePtr cur, const char *encoding, int format) {
+                       xmlNodePtr cur, const char *encoding, int format) {
     xmlOutputBufferPtr buf;
     xmlCharEncodingHandlerPtr handler;
     int ret;
@@ -506,11 +453,12 @@ htmlNodeDumpFileFormat(FILE *out, xmlDocPtr doc,
     /*
      * save the content to a temp buffer.
      */
-    handler = htmlFindOutputEncoder(encoding);
+    if (htmlFindOutputEncoder(encoding, &handler) != XML_ERR_OK)
+        return(-1);
     buf = xmlOutputBufferCreateFile(out, handler);
     if (buf == NULL) {
         xmlCharEncCloseFunc(handler);
-        return(0);
+        return(-1);
     }
 
     htmlNodeDumpFormatOutput(buf, doc, cur, NULL, format);
@@ -556,14 +504,15 @@ htmlDocDumpMemoryFormat(xmlDocPtr cur, xmlChar**mem, int *size, int format) {
     *mem = NULL;
     *size = 0;
     if (cur == NULL)
-    return;
+        return;
 
     encoding = (const char *) htmlGetMetaEncoding(cur);
-    handler = htmlFindOutputEncoder(encoding);
-    buf = xmlAllocOutputBufferInternal(handler);
+    if (htmlFindOutputEncoder(encoding, &handler) != XML_ERR_OK)
+        return;
+    buf = xmlAllocOutputBuffer(handler);
     if (buf == NULL) {
         xmlCharEncCloseFunc(handler);
-    return;
+        return;
     }
 
     htmlDocContentDumpFormatOutput(buf, cur, NULL, format);
@@ -594,14 +543,14 @@ htmlDocDumpMemoryFormat(xmlDocPtr cur, xmlChar**mem, int *size, int format) {
  */
 void
 htmlDocDumpMemory(xmlDocPtr cur, xmlChar**mem, int *size) {
-    htmlDocDumpMemoryFormat(cur, mem, size, 1);
+        htmlDocDumpMemoryFormat(cur, mem, size, 1);
 }
 
 
 /************************************************************************
- *                                    *
- *        Dumping HTML tree content to an I/O output buffer    *
- *                                    *
+ *                                                                      *
+ *              Dumping HTML tree content to an I/O output buffer       *
+ *                                                                      *
  ************************************************************************/
 
 /**
@@ -616,26 +565,24 @@ htmlDocDumpMemory(xmlDocPtr cur, xmlChar**mem, int *size) {
  */
 static void
 htmlDtdDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
-              const char *encoding ATTRIBUTE_UNUSED) {
+                  const char *encoding ATTRIBUTE_UNUSED) {
     xmlDtdPtr cur = doc->intSubset;
 
-    if (cur == NULL) {
-    htmlSaveErr(XML_SAVE_NO_DOCTYPE, (xmlNodePtr) doc, NULL);
-    return;
-    }
+    if (cur == NULL)
+        return;
     xmlOutputBufferWriteString(buf, "<!DOCTYPE ");
     xmlOutputBufferWriteString(buf, (const char *)cur->name);
     if (cur->ExternalID != NULL) {
-    xmlOutputBufferWriteString(buf, " PUBLIC ");
-    xmlOutputBufferWriteQuotedString(buf, cur->ExternalID);
-    if (cur->SystemID != NULL) {
-        xmlOutputBufferWriteString(buf, " ");
-        xmlOutputBufferWriteQuotedString(buf, cur->SystemID);
-    }
+        xmlOutputBufferWriteString(buf, " PUBLIC ");
+        xmlOutputBufferWriteQuotedString(buf, cur->ExternalID);
+        if (cur->SystemID != NULL) {
+            xmlOutputBufferWriteString(buf, " ");
+            xmlOutputBufferWriteQuotedString(buf, cur->SystemID);
+        }
     } else if (cur->SystemID != NULL &&
-           xmlStrcmp(cur->SystemID, BAD_CAST "about:legacy-compat")) {
-    xmlOutputBufferWriteString(buf, " SYSTEM ");
-    xmlOutputBufferWriteQuotedString(buf, cur->SystemID);
+               xmlStrcmp(cur->SystemID, BAD_CAST "about:legacy-compat")) {
+        xmlOutputBufferWriteString(buf, " SYSTEM ");
+        xmlOutputBufferWriteQuotedString(buf, cur->SystemID);
     }
     xmlOutputBufferWriteString(buf, ">\n");
 }
@@ -660,53 +607,53 @@ htmlAttrDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc, xmlAttrPtr cur) {
      */
 
     if (cur == NULL) {
-    return;
+        return;
     }
     xmlOutputBufferWriteString(buf, " ");
     if ((cur->ns != NULL) && (cur->ns->prefix != NULL)) {
         xmlOutputBufferWriteString(buf, (const char *)cur->ns->prefix);
-    xmlOutputBufferWriteString(buf, ":");
+        xmlOutputBufferWriteString(buf, ":");
     }
     xmlOutputBufferWriteString(buf, (const char *)cur->name);
     if ((cur->children != NULL) && (!htmlIsBooleanAttr(cur->name))) {
-    value = xmlNodeListGetString(doc, cur->children, 0);
-    if (value) {
-        xmlOutputBufferWriteString(buf, "=");
-        if ((cur->ns == NULL) && (cur->parent != NULL) &&
-        (cur->parent->ns == NULL) &&
-        ((!xmlStrcasecmp(cur->name, BAD_CAST "href")) ||
-             (!xmlStrcasecmp(cur->name, BAD_CAST "action")) ||
-         (!xmlStrcasecmp(cur->name, BAD_CAST "src")) ||
-         ((!xmlStrcasecmp(cur->name, BAD_CAST "name")) &&
-          (!xmlStrcasecmp(cur->parent->name, BAD_CAST "a"))))) {
-        xmlChar *escaped;
-        xmlChar *tmp = value;
+        value = xmlNodeListGetString(doc, cur->children, 0);
+        if (value) {
+            xmlOutputBufferWriteString(buf, "=");
+            if ((cur->ns == NULL) && (cur->parent != NULL) &&
+                (cur->parent->ns == NULL) &&
+                ((!xmlStrcasecmp(cur->name, BAD_CAST "href")) ||
+                 (!xmlStrcasecmp(cur->name, BAD_CAST "action")) ||
+                 (!xmlStrcasecmp(cur->name, BAD_CAST "src")) ||
+                 ((!xmlStrcasecmp(cur->name, BAD_CAST "name")) &&
+                  (!xmlStrcasecmp(cur->parent->name, BAD_CAST "a"))))) {
+                xmlChar *escaped;
+                xmlChar *tmp = value;
 
-        while (IS_BLANK_CH(*tmp)) tmp++;
+                while (IS_BLANK_CH(*tmp)) tmp++;
 
-        /*
+                /*
                  * Angle brackets are technically illegal in URIs, but they're
                  * used in server side includes, for example. Curly brackets
                  * are illegal as well and often used in templates.
                  * Don't escape non-whitespace, printable ASCII chars for
                  * improved interoperability. Only escape space, control
                  * and non-ASCII chars.
-         */
-        escaped = xmlURIEscapeStr(tmp,
+                 */
+                escaped = xmlURIEscapeStr(tmp,
                         BAD_CAST "\"#$%&+,/:;<=>?@[\\]^`{|}");
-        if (escaped != NULL) {
-            xmlOutputBufferWriteQuotedString(buf, escaped);
-            xmlFree(escaped);
-        } else {
+                if (escaped != NULL) {
+                    xmlOutputBufferWriteQuotedString(buf, escaped);
+                    xmlFree(escaped);
+                } else {
                     buf->error = XML_ERR_NO_MEMORY;
-        }
-        } else {
-        xmlOutputBufferWriteQuotedString(buf, value);
-        }
-        xmlFree(value);
-    } else  {
+                }
+            } else {
+                xmlOutputBufferWriteQuotedString(buf, value);
+            }
+            xmlFree(value);
+        } else  {
             buf->error = XML_ERR_NO_MEMORY;
-    }
+        }
     }
 }
 
@@ -722,7 +669,7 @@ htmlAttrDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc, xmlAttrPtr cur) {
  */
 void
 htmlNodeDumpFormatOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
-                     xmlNodePtr cur, const char *encoding ATTRIBUTE_UNUSED,
+                         xmlNodePtr cur, const char *encoding ATTRIBUTE_UNUSED,
                          int format) {
     xmlNodePtr root, parent;
     xmlAttrPtr attr;
@@ -731,7 +678,7 @@ htmlNodeDumpFormatOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
     xmlInitParser();
 
     if ((cur == NULL) || (buf == NULL)) {
-    return;
+        return;
     }
 
     root = cur;
@@ -957,7 +904,7 @@ htmlNodeDumpFormatOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
  */
 void
 htmlNodeDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
-               xmlNodePtr cur, const char *encoding ATTRIBUTE_UNUSED) {
+                   xmlNodePtr cur, const char *encoding ATTRIBUTE_UNUSED) {
     htmlNodeDumpFormatOutput(buf, doc, cur, NULL, 1);
 }
 
@@ -972,7 +919,7 @@ htmlNodeDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
  */
 void
 htmlDocContentDumpFormatOutput(xmlOutputBufferPtr buf, xmlDocPtr cur,
-                           const char *encoding ATTRIBUTE_UNUSED,
+                               const char *encoding ATTRIBUTE_UNUSED,
                                int format) {
     int type = 0;
     if (cur) {
@@ -994,14 +941,14 @@ htmlDocContentDumpFormatOutput(xmlOutputBufferPtr buf, xmlDocPtr cur,
  */
 void
 htmlDocContentDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr cur,
-                     const char *encoding ATTRIBUTE_UNUSED) {
+                         const char *encoding ATTRIBUTE_UNUSED) {
     htmlNodeDumpFormatOutput(buf, cur, (xmlNodePtr) cur, NULL, 1);
 }
 
 /************************************************************************
- *                                    *
- *        Saving functions front-ends                *
- *                                    *
+ *                                                                      *
+ *              Saving functions front-ends                             *
+ *                                                                      *
  ************************************************************************/
 
 /**
@@ -1023,11 +970,12 @@ htmlDocDump(FILE *f, xmlDocPtr cur) {
     xmlInitParser();
 
     if ((cur == NULL) || (f == NULL)) {
-    return(-1);
+        return(-1);
     }
 
     encoding = (const char *) htmlGetMetaEncoding(cur);
-    handler = htmlFindOutputEncoder(encoding);
+    if (htmlFindOutputEncoder(encoding, &handler) != XML_ERR_OK)
+        return(-1);
     buf = xmlOutputBufferCreateFile(f, handler);
     if (buf == NULL) {
         xmlCharEncCloseFunc(handler);
@@ -1061,12 +1009,11 @@ htmlSaveFile(const char *filename, xmlDocPtr cur) {
     xmlInitParser();
 
     encoding = (const char *) htmlGetMetaEncoding(cur);
-    handler = htmlFindOutputEncoder(encoding);
+    if (htmlFindOutputEncoder(encoding, &handler) != XML_ERR_OK)
+        return(-1);
     buf = xmlOutputBufferCreateFilename(filename, handler, cur->compression);
-    if (buf == NULL) {
-        xmlCharEncCloseFunc(handler);
-        return(0);
-    }
+    if (buf == NULL)
+        return(-1);
 
     htmlDocContentDumpOutput(buf, cur, NULL);
 
@@ -1087,7 +1034,7 @@ htmlSaveFile(const char *filename, xmlDocPtr cur) {
  */
 int
 htmlSaveFileFormat(const char *filename, xmlDocPtr cur,
-               const char *encoding, int format) {
+                   const char *encoding, int format) {
     xmlOutputBufferPtr buf;
     xmlCharEncodingHandlerPtr handler = NULL;
     int ret;
@@ -1097,11 +1044,12 @@ htmlSaveFileFormat(const char *filename, xmlDocPtr cur,
 
     xmlInitParser();
 
-    handler = htmlFindOutputEncoder(encoding);
+    if (htmlFindOutputEncoder(encoding, &handler) != XML_ERR_OK)
+        return(-1);
     if (handler != NULL)
         htmlSetMetaEncoding(cur, (const xmlChar *) handler->name);
     else
-    htmlSetMetaEncoding(cur, (const xmlChar *) "UTF-8");
+        htmlSetMetaEncoding(cur, (const xmlChar *) "UTF-8");
 
     /*
      * save the content to a temp buffer.
