@@ -25,6 +25,7 @@
 #include <string.h>
 
 #include "private/dict.h"
+#include "private/error.h"
 #include "private/globals.h"
 #include "private/threads.h"
 
@@ -143,11 +144,11 @@ xmlDictAddString(xmlDictPtr dict, const xmlChar *name, unsigned int namelen) {
 
     pool = dict->strings;
     while (pool != NULL) {
-    if ((size_t)(pool->end - pool->free) > namelen)
-        goto found_pool;
-    if (pool->size > size) size = pool->size;
+        if ((size_t)(pool->end - pool->free) > namelen)
+            goto found_pool;
+        if (pool->size > size) size = pool->size;
         limit += pool->size;
-    pool = pool->next;
+        pool = pool->next;
     }
     /*
      * Not found, need to allocate
@@ -171,15 +172,15 @@ xmlDictAddString(xmlDictPtr dict, const xmlChar *name, unsigned int namelen) {
             else
                 return(NULL);
         }
-    pool = (xmlDictStringsPtr) xmlMalloc(sizeof(xmlDictStrings) + size);
-    if (pool == NULL)
-        return(NULL);
-    pool->size = size;
-    pool->nbStrings = 0;
-    pool->free = &pool->array[0];
-    pool->end = &pool->array[size];
-    pool->next = dict->strings;
-    dict->strings = pool;
+        pool = (xmlDictStringsPtr) xmlMalloc(sizeof(xmlDictStrings) + size);
+        if (pool == NULL)
+            return(NULL);
+        pool->size = size;
+        pool->nbStrings = 0;
+        pool->free = &pool->array[0];
+        pool->end = &pool->array[size];
+        pool->next = dict->strings;
+        dict->strings = pool;
     }
 found_pool:
     ret = pool->free;
@@ -213,11 +214,11 @@ xmlDictAddQString(xmlDictPtr dict, const xmlChar *prefix, unsigned int plen,
 
     pool = dict->strings;
     while (pool != NULL) {
-    if ((size_t)(pool->end - pool->free) > namelen + plen + 1)
-        goto found_pool;
-    if (pool->size > size) size = pool->size;
+        if ((size_t)(pool->end - pool->free) > namelen + plen + 1)
+            goto found_pool;
+        if (pool->size > size) size = pool->size;
         limit += pool->size;
-    pool = pool->next;
+        pool = pool->next;
     }
     /*
      * Not found, need to allocate
@@ -228,18 +229,18 @@ xmlDictAddQString(xmlDictPtr dict, const xmlChar *prefix, unsigned int plen,
         }
 
         if (size == 0) size = 1000;
-    else size *= 4; /* exponential growth */
+        else size *= 4; /* exponential growth */
         if (size < 4 * (namelen + plen + 1))
-        size = 4 * (namelen + plen + 1); /* just in case ! */
-    pool = (xmlDictStringsPtr) xmlMalloc(sizeof(xmlDictStrings) + size);
-    if (pool == NULL)
-        return(NULL);
-    pool->size = size;
-    pool->nbStrings = 0;
-    pool->free = &pool->array[0];
-    pool->end = &pool->array[size];
-    pool->next = dict->strings;
-    dict->strings = pool;
+            size = 4 * (namelen + plen + 1); /* just in case ! */
+        pool = (xmlDictStringsPtr) xmlMalloc(sizeof(xmlDictStrings) + size);
+        if (pool == NULL)
+            return(NULL);
+        pool->size = size;
+        pool->nbStrings = 0;
+        pool->free = &pool->array[0];
+        pool->end = &pool->array[size];
+        pool->next = dict->strings;
+        dict->strings = pool;
     }
 found_pool:
     ret = pool->free;
@@ -302,7 +303,7 @@ xmlDictCreateSub(xmlDictPtr sub) {
     if ((dict != NULL) && (sub != NULL)) {
         dict->seed = sub->seed;
         dict->subdict = sub;
-    xmlDictReference(dict->subdict);
+        xmlDictReference(dict->subdict);
     }
     return(dict);
 }
@@ -336,7 +337,7 @@ xmlDictFree(xmlDictPtr dict) {
     xmlDictStringsPtr pool, nextp;
 
     if (dict == NULL)
-    return;
+        return;
 
     /* decrement the counter, it may be shared by a parser and docs */
     xmlMutexLock(&xmlDictMutex);
@@ -353,13 +354,13 @@ xmlDictFree(xmlDictPtr dict) {
     }
 
     if (dict->table) {
-    xmlFree(dict->table);
+        xmlFree(dict->table);
     }
     pool = dict->strings;
     while (pool != NULL) {
         nextp = pool->next;
-    xmlFree(pool);
-    pool = nextp;
+        xmlFree(pool);
+        pool = nextp;
     }
     xmlFree(dict);
 }
@@ -379,12 +380,12 @@ xmlDictOwns(xmlDictPtr dict, const xmlChar *str) {
     xmlDictStringsPtr pool;
 
     if ((dict == NULL) || (str == NULL))
-    return(-1);
+        return(-1);
     pool = dict->strings;
     while (pool != NULL) {
         if ((str >= &pool->array[0]) && (str <= pool->free))
-        return(1);
-    pool = pool->next;
+            return(1);
+        pool = pool->next;
     }
     if (dict->subdict)
         return(xmlDictOwns(dict->subdict, str));
@@ -403,7 +404,7 @@ xmlDictOwns(xmlDictPtr dict, const xmlChar *str) {
 int
 xmlDictSize(xmlDictPtr dict) {
     if (dict == NULL)
-    return(-1);
+        return(-1);
     if (dict->subdict)
         return(dict->nbElems + dict->subdict->nbElems);
     return(dict->nbElems);
@@ -424,7 +425,7 @@ xmlDictSetLimit(xmlDictPtr dict, size_t limit) {
     size_t ret;
 
     if (dict == NULL)
-    return(0);
+        return(0);
     ret = dict->limit;
     dict->limit = limit;
     return(ret);
@@ -445,11 +446,11 @@ xmlDictGetUsage(xmlDictPtr dict) {
     size_t limit = 0;
 
     if (dict == NULL)
-    return(0);
+        return(0);
     pool = dict->strings;
     while (pool != NULL) {
         limit += pool->size;
-    pool = pool->next;
+        pool = pool->next;
     }
     return(limit);
 }
@@ -699,12 +700,12 @@ xmlDictLookupInternal(xmlDictPtr dict, const xmlChar *prefix,
                       const xmlChar *name, int maybeLen, int update) {
     xmlDictEntry *entry = NULL;
     const xmlChar *ret;
-    unsigned hashValue;
+    unsigned hashValue, newSize;
     size_t maxLen, len, plen, klen;
     int found = 0;
 
     if ((dict == NULL) || (name == NULL))
-    return(NULL);
+        return(NULL);
 
     maxLen = (maybeLen < 0) ? SIZE_MAX : (size_t) maybeLen;
 
@@ -726,10 +727,21 @@ xmlDictLookupInternal(xmlDictPtr dict, const xmlChar *prefix,
     /*
      * Check for an existing entry
      */
-    if (dict->size > 0)
+    if (dict->size == 0) {
+        newSize = MIN_HASH_SIZE;
+    } else {
         entry = xmlDictFindEntry(dict, prefix, name, klen, hashValue, &found);
-    if (found)
-        return(entry);
+        if (found)
+            return(entry);
+
+        if (dict->nbElems + 1 > dict->size / MAX_FILL_DENOM * MAX_FILL_NUM) {
+            if (dict->size >= MAX_HASH_SIZE)
+                return(NULL);
+            newSize = dict->size * 2;
+        } else {
+            newSize = 0;
+        }
+    }
 
     if ((dict->subdict != NULL) && (dict->subdict->size > 0)) {
         xmlDictEntry *subEntry;
@@ -753,16 +765,9 @@ xmlDictLookupInternal(xmlDictPtr dict, const xmlChar *prefix,
     /*
      * Grow the hash table if needed
      */
-    if (dict->nbElems + 1 > dict->size / MAX_FILL_DENOM * MAX_FILL_NUM) {
-        unsigned newSize, mask, displ, pos;
+    if (newSize > 0) {
+        unsigned mask, displ, pos;
 
-        if (dict->size == 0) {
-            newSize = MIN_HASH_SIZE;
-        } else {
-            if (dict->size >= MAX_HASH_SIZE)
-                return(NULL);
-            newSize = dict->size * 2;
-        }
         if (xmlDictGrow(dict, newSize) != 0)
             return(NULL);
 
@@ -929,13 +934,11 @@ xmlDictQLookup(xmlDictPtr dict, const xmlChar *prefix, const xmlChar *name) {
   #include <windows.h>
   #include <bcrypt.h>
 #else
-  #if defined(HAVE_GETENTROPY)
-    #ifdef HAVE_UNISTD_H
-      #include <unistd.h>
-    #endif
-    #ifdef HAVE_SYS_RANDOM_H
-      #include <sys/random.h>
-    #endif
+  #if HAVE_DECL_GETENTROPY
+    /* POSIX 2024 */
+    #include <unistd.h>
+    /* Older platforms */
+    #include <sys/random.h>
   #endif
   #include <time.h>
 #endif
@@ -958,18 +961,23 @@ xmlInitRandom(void) {
 #ifdef _WIN32
         NTSTATUS status;
 
+        /*
+         * You can find many (recent as of 2025) discussions how
+         * to get a pseudo-random seed on Windows in projects like
+         * Golang, Rust, Chromium and Firefox.
+         *
+         * TODO: Support ProcessPrng available since Windows 10.
+         */
         status = BCryptGenRandom(NULL, (unsigned char *) globalRngState,
                                  sizeof(globalRngState),
                                  BCRYPT_USE_SYSTEM_PREFERRED_RNG);
-        if (!BCRYPT_SUCCESS(status)) {
-            fprintf(stderr, "libxml2: BCryptGenRandom failed with "
-                    "error code %lu\n", GetLastError());
-            abort();
-        }
+        if (!BCRYPT_SUCCESS(status))
+            xmlAbort("libxml2: BCryptGenRandom failed with error code %lu\n",
+                     GetLastError());
 #else
         int var;
 
-#if defined(HAVE_GETENTROPY)
+#if HAVE_DECL_GETENTROPY
         while (1) {
             if (getentropy(globalRngState, sizeof(globalRngState)) == 0)
                 return;
@@ -983,14 +991,20 @@ xmlInitRandom(void) {
             if (errno == ENOSYS)
                 break;
 
-            if (errno != EINTR) {
-                fprintf(stderr, "libxml2: getentropy failed with "
-                        "error code %d\n", errno);
-                abort();
-            }
+            /*
+             * We really don't want to fallback to the unsafe PRNG
+             * for possibly accidental reasons, so we abort on any
+             * unknown error.
+             */
+            if (errno != EINTR)
+                xmlAbort("libxml2: getentropy failed with error code %d\n",
+                         errno);
         }
 #endif
 
+        /*
+         * TODO: Fallback to /dev/urandom for older POSIX systems.
+         */
         globalRngState[0] =
                 (unsigned) time(NULL) ^
                 HASH_ROL((unsigned) ((size_t) &xmlInitRandom & 0xFFFFFFFF), 8);
@@ -1052,10 +1066,6 @@ xmlGlobalRandom(void) {
  */
 unsigned
 xmlRandom(void) {
-#ifdef LIBXML_THREAD_ENABLED
     return(xoroshiro64ss(xmlGetLocalRngState()));
-#else
-    return(xmlGlobalRandom());
-#endif
 }
 
