@@ -17,12 +17,44 @@
 #include <libxml/xmlmemory.h>
 
 #include "private/error.h"
+#include "private/globals.h"
 #include "private/string.h"
 
+/**
+ * xmlIsCatastrophicError:
+ * @level:  error level
+ * @code:  error code
+ *
+ * Returns true if an error is catastrophic.
+ */
+int
+xmlIsCatastrophicError(int level, int code) {
+    int fatal = 0;
+
+    if (level != XML_ERR_FATAL)
+        return(0);
+
+    switch (code) {
+        case XML_ERR_NO_MEMORY:
+        /* case XML_ERR_RESOURCE_LIMIT: */
+        case XML_ERR_SYSTEM:
+        case XML_ERR_ARGUMENT:
+        case XML_ERR_INTERNAL_ERROR:
+            fatal = 1;
+            break;
+        default:
+            if ((code >= 1500) && (code <= 1599))
+                fatal = 1;
+            break;
+    }
+
+    return(fatal);
+}
+
 /************************************************************************
- *                                    *
- *            Error struct                    *
- *                                    *
+ *                                                                      *
+ *                      Error struct                                    *
+ *                                                                      *
  ************************************************************************/
 
 static int
@@ -177,9 +209,9 @@ xmlVUpdateError(xmlError *err,
 }
 
 /************************************************************************
- *                                    *
- *            Handling of out of context errors        *
- *                                    *
+ *                                                                      *
+ *                      Handling of out of context errors               *
+ *                                                                      *
  ************************************************************************/
 
 /**
@@ -195,31 +227,13 @@ xmlGenericErrorDefaultFunc(void *ctx ATTRIBUTE_UNUSED, const char *msg, ...) {
     va_list args;
 
     if (xmlGenericErrorContext == NULL)
-    xmlGenericErrorContext = (void *) stderr;
+        xmlGenericErrorContext = (void *) stderr;
 
     va_start(args, msg);
     vfprintf((FILE *)xmlGenericErrorContext, msg, args);
     va_end(args);
 }
 
-/**
- * initGenericErrorDefaultFunc:
- * @handler:  the handler
- *
- * DEPRECATED: Use xmlSetGenericErrorFunc.
- *
- * Set or reset (if NULL) the default handler for generic errors
- * to the builtin error function.
- */
-void
-initGenericErrorDefaultFunc(xmlGenericErrorFunc * handler)
-{
-    if (handler == NULL)
-        xmlGenericError = xmlGenericErrorDefaultFunc;
-    else
-        xmlGenericError = (*handler);
-}
-
 /**
  * xmlSetGenericErrorFunc:
  * @ctx:  the new error handling context
@@ -245,9 +259,9 @@ void
 xmlSetGenericErrorFunc(void *ctx, xmlGenericErrorFunc handler) {
     xmlGenericErrorContext = ctx;
     if (handler != NULL)
-    xmlGenericError = handler;
+        xmlGenericError = handler;
     else
-    xmlGenericError = xmlGenericErrorDefaultFunc;
+        xmlGenericError = xmlGenericErrorDefaultFunc;
 }
 
 /**
@@ -287,9 +301,9 @@ xmlSetStructuredErrorFunc(void *ctx, xmlStructuredErrorFunc handler) {
 }
 
 /************************************************************************
- *                                    *
- *            Handling of parsing errors            *
- *                                    *
+ *                                                                      *
+ *                      Handling of parsing errors                      *
+ *                                                                      *
  ************************************************************************/
 
 /**
@@ -304,13 +318,13 @@ xmlSetStructuredErrorFunc(void *ctx, xmlStructuredErrorFunc handler) {
 void
 xmlParserPrintFileInfo(xmlParserInputPtr input) {
     if (input != NULL) {
-    if (input->filename)
-        xmlGenericError(xmlGenericErrorContext,
-            "%s:%d: ", input->filename,
-            input->line);
-    else
-        xmlGenericError(xmlGenericErrorContext,
-            "Entity: line %d: ", input->line);
+        if (input->filename)
+            xmlGenericError(xmlGenericErrorContext,
+                    "%s:%d: ", input->filename,
+                    input->line);
+        else
+            xmlGenericError(xmlGenericErrorContext,
+                    "Entity: line %d: ", input->line);
     }
 }
 
@@ -323,9 +337,9 @@ xmlParserPrintFileInfo(xmlParserInputPtr input) {
 
 static void
 xmlParserPrintFileContextInternal(xmlParserInputPtr input ,
-        xmlGenericErrorFunc channel, void *data ) {
+                xmlGenericErrorFunc channel, void *data ) {
     const xmlChar *cur, *base, *start;
-    unsigned int n, col;    /* GCC warns if signed, because compared with sizeof() */
+    unsigned int n, col;        /* GCC warns if signed, because compared with sizeof() */
     xmlChar  content[81]; /* space for 80 chars + line terminator */
     xmlChar *ctnt;
 
@@ -336,12 +350,12 @@ xmlParserPrintFileContextInternal(xmlParserInputPtr input ,
     base = input->base;
     /* skip backwards over any end-of-lines */
     while ((cur > base) && ((*(cur) == '\n') || (*(cur) == '\r'))) {
-    cur--;
+        cur--;
     }
     n = 0;
     /* search backwards for beginning-of-line (to max buff size) */
     while ((n < sizeof(content) - 1) && (cur > base) &&
-       (*cur != '\n') && (*cur != '\r')) {
+           (*cur != '\n') && (*cur != '\r')) {
         cur--;
         n++;
     }
@@ -365,7 +379,7 @@ xmlParserPrintFileContextInternal(xmlParserInputPtr input ,
         if ((c < 0) || (n + len > sizeof(content)-1))
             break;
         cur += len;
-    n += len;
+        n += len;
     }
     memcpy(content, start, n);
     content[n] = 0;
@@ -376,9 +390,9 @@ xmlParserPrintFileContextInternal(xmlParserInputPtr input ,
     ctnt = content;
     /* (leave buffer space for pointer + line terminator) */
     while ((n<col) && (n++ < sizeof(content)-2) && (*ctnt != 0)) {
-    if (*(ctnt) != '\t')
-        *(ctnt) = ' ';
-    ctnt++;
+        if (*(ctnt) != '\t')
+            *(ctnt) = ' ';
+        ctnt++;
     }
     *ctnt++ = '^';
     *ctnt = 0;
@@ -443,8 +457,8 @@ xmlFormatError(const xmlError *err, xmlGenericErrorFunc channel, void *data)
 
     if ((domain == XML_FROM_PARSER) || (domain == XML_FROM_HTML) ||
         (domain == XML_FROM_DTD) || (domain == XML_FROM_NAMESPACE) ||
-    (domain == XML_FROM_IO) || (domain == XML_FROM_VALID)) {
-    ctxt = err->ctxt;
+        (domain == XML_FROM_IO) || (domain == XML_FROM_VALID)) {
+        ctxt = err->ctxt;
     }
 
     if ((node != NULL) && (node->type == XML_ELEMENT_NODE) &&
@@ -469,9 +483,9 @@ xmlFormatError(const xmlError *err, xmlGenericErrorFunc channel, void *data)
         if (file != NULL)
             channel(data, "%s:%d: ", file, line);
         else if ((line != 0) &&
-             ((domain == XML_FROM_PARSER) || (domain == XML_FROM_SCHEMASV)||
-          (domain == XML_FROM_SCHEMASP)||(domain == XML_FROM_DTD) ||
-          (domain == XML_FROM_RELAXNGP)||(domain == XML_FROM_RELAXNGV)))
+                 ((domain == XML_FROM_PARSER) || (domain == XML_FROM_SCHEMASV)||
+                  (domain == XML_FROM_SCHEMASP)||(domain == XML_FROM_DTD) ||
+                  (domain == XML_FROM_RELAXNGP)||(domain == XML_FROM_RELAXNGV)))
             channel(data, "Entity: line %d: ", line);
     }
     if (name != NULL) {
@@ -567,11 +581,11 @@ xmlFormatError(const xmlError *err, xmlGenericErrorFunc channel, void *data)
     }
     if (message != NULL) {
         int len;
-    len = xmlStrlen((const xmlChar *) message);
-    if ((len > 0) && (message[len - 1] != '\n'))
-        channel(data, "%s\n", message);
-    else
-        channel(data, "%s", message);
+        len = xmlStrlen((const xmlChar *) message);
+        if ((len > 0) && (message[len - 1] != '\n'))
+            channel(data, "%s\n", message);
+        else
+            channel(data, "%s", message);
     } else {
         channel(data, "%s\n", "No error message provided");
     }
@@ -604,16 +618,16 @@ xmlFormatError(const xmlError *err, xmlGenericErrorFunc channel, void *data)
     }
     if ((domain == XML_FROM_XPATH) && (err->str1 != NULL) &&
         (err->int1 < 100) &&
-    (err->int1 < xmlStrlen((const xmlChar *)err->str1))) {
-    xmlChar buf[150];
-    int i;
+        (err->int1 < xmlStrlen((const xmlChar *)err->str1))) {
+        xmlChar buf[150];
+        int i;
 
-    channel(data, "%s\n", err->str1);
-    for (i=0;i < err->int1;i++)
-         buf[i] = ' ';
-    buf[i++] = '^';
-    buf[i] = 0;
-    channel(data, "%s\n", buf);
+        channel(data, "%s\n", err->str1);
+        for (i=0;i < err->int1;i++)
+             buf[i] = ' ';
+        buf[i++] = '^';
+        buf[i] = 0;
+        channel(data, "%s\n", buf);
     }
 }
 
@@ -635,7 +649,7 @@ void
 xmlRaiseMemoryError(xmlStructuredErrorFunc schannel, xmlGenericErrorFunc channel,
                     void *data, int domain, xmlError *error)
 {
-    xmlError *lastError = &xmlLastError;
+    xmlError *lastError = xmlGetLastErrorInternal();
 
     xmlResetLastError();
     lastError->domain = domain;
@@ -694,24 +708,22 @@ xmlVRaiseError(xmlStructuredErrorFunc schannel,
 {
     xmlParserCtxtPtr ctxt = NULL;
     /* xmlLastError is a macro retrieving the per-thread global. */
-    xmlErrorPtr lastError = &xmlLastError;
+    xmlErrorPtr lastError = xmlGetLastErrorInternal();
     xmlErrorPtr to = lastError;
 
     if (code == XML_ERR_OK)
         return(0);
 #ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
-    if (code == XML_ERR_INTERNAL_ERROR) {
-        fprintf(stderr, "Unexpected error: %d\n", code);
-        abort();
-    }
+    if (code == XML_ERR_INTERNAL_ERROR)
+        xmlAbort("Unexpected error: %d\n", code);
 #endif
     if ((xmlGetWarningsDefaultValue == 0) && (level == XML_ERR_WARNING))
         return(0);
 
     if ((domain == XML_FROM_PARSER) || (domain == XML_FROM_HTML) ||
         (domain == XML_FROM_DTD) || (domain == XML_FROM_NAMESPACE) ||
-    (domain == XML_FROM_IO) || (domain == XML_FROM_VALID)) {
-    ctxt = (xmlParserCtxtPtr) ctx;
+        (domain == XML_FROM_IO) || (domain == XML_FROM_VALID)) {
+        ctxt = (xmlParserCtxtPtr) ctx;
 
         if (ctxt != NULL)
             to = &ctxt->lastError;
@@ -727,7 +739,7 @@ xmlVRaiseError(xmlStructuredErrorFunc schannel,
     }
 
     if (schannel != NULL) {
-    schannel(data, to);
+        schannel(data, to);
     } else if (xmlStructuredError != NULL) {
         xmlStructuredError(xmlStructuredErrorContext, to);
     } else if (channel != NULL) {
@@ -739,19 +751,19 @@ xmlVRaiseError(xmlStructuredErrorFunc schannel,
             (channel == xmlParserValidityWarning))
             xmlFormatError(to, xmlGenericError, xmlGenericErrorContext);
         else
-        channel(data, "%s", to->message);
+            channel(data, "%s", to->message);
     }
 
     return(0);
 }
 
 /**
- * __xmlRaiseError:
+ * xmlRaiseError:
  * @schannel: the structured callback channel
  * @channel: the old callback channel
  * @data: the callback data
  * @ctx: the parser context or NULL
- * @nod: the node or NULL
+ * @node: the node or NULL
  * @domain: the domain for the error
  * @code: the code for the error
  * @level: the xmlErrorLevel for the error
@@ -772,12 +784,12 @@ xmlVRaiseError(xmlStructuredErrorFunc schannel,
  * Returns 0 on success, -1 if a memory allocation failed.
  */
 int
-__xmlRaiseError(xmlStructuredErrorFunc schannel,
-                xmlGenericErrorFunc channel, void *data, void *ctx,
-                xmlNode *node, int domain, int code, xmlErrorLevel level,
-                const char *file, int line, const char *str1,
-                const char *str2, const char *str3, int int1, int col,
-                const char *msg, ...)
+xmlRaiseError(xmlStructuredErrorFunc schannel,
+              xmlGenericErrorFunc channel, void *data, void *ctx,
+              xmlNode *node, int domain, int code, xmlErrorLevel level,
+              const char *file, int line, const char *str1,
+              const char *str2, const char *str3, int int1, int col,
+              const char *msg, ...)
 {
     va_list ap;
     int res;
@@ -800,13 +812,13 @@ xmlVFormatLegacyError(void *ctx, const char *level,
     xmlChar *str = NULL;
 
     if (ctxt != NULL) {
-    input = ctxt->input;
-    if ((input != NULL) && (input->filename == NULL) &&
-        (ctxt->inputNr > 1)) {
-        cur = input;
-        input = ctxt->inputTab[ctxt->inputNr - 2];
-    }
-    xmlParserPrintFileInfo(input);
+        input = ctxt->input;
+        if ((input != NULL) && (input->filename == NULL) &&
+            (ctxt->inputNr > 1)) {
+            cur = input;
+            input = ctxt->inputTab[ctxt->inputNr - 2];
+        }
+        xmlParserPrintFileInfo(input);
     }
 
     xmlGenericError(xmlGenericErrorContext, "%s: ", level);
@@ -814,16 +826,16 @@ xmlVFormatLegacyError(void *ctx, const char *level,
     xmlStrVASPrintf(&str, MAX_ERR_MSG_SIZE, fmt, ap);
     if (str != NULL) {
         xmlGenericError(xmlGenericErrorContext, "%s", (char *) str);
-    xmlFree(str);
+        xmlFree(str);
     }
 
     if (ctxt != NULL) {
-    xmlParserPrintFileContext(input);
-    if (cur != NULL) {
-        xmlParserPrintFileInfo(cur);
-        xmlGenericError(xmlGenericErrorContext, "\n");
-        xmlParserPrintFileContext(cur);
-    }
+        xmlParserPrintFileContext(input);
+        if (cur != NULL) {
+            xmlParserPrintFileInfo(cur);
+            xmlGenericError(xmlGenericErrorContext, "\n");
+            xmlParserPrintFileContext(cur);
+        }
     }
 }
 
@@ -905,9 +917,9 @@ xmlParserValidityWarning(void *ctx, const char *msg ATTRIBUTE_UNUSED, ...)
 
 
 /************************************************************************
- *                                    *
- *            Extended Error Handling                *
- *                                    *
+ *                                                                      *
+ *                      Extended Error Handling                         *
+ *                                                                      *
  ************************************************************************/
 
 /**
@@ -921,9 +933,11 @@ xmlParserValidityWarning(void *ctx, const char *msg ATTRIBUTE_UNUSED, ...)
 const xmlError *
 xmlGetLastError(void)
 {
-    if (xmlLastError.code == XML_ERR_OK)
-        return (NULL);
-    return (&xmlLastError);
+    const xmlError *error = xmlGetLastErrorInternal();
+
+    if (error->code == XML_ERR_OK)
+        return(NULL);
+    return(error);
 }
 
 /**
@@ -962,49 +976,10 @@ xmlResetError(xmlErrorPtr err)
 void
 xmlResetLastError(void)
 {
-    if (xmlLastError.code == XML_ERR_OK)
-        return;
-    xmlResetError(&xmlLastError);
-}
+    xmlError *error = xmlGetLastErrorInternal();
 
-/**
- * xmlCtxtGetLastError:
- * @ctx:  an XML parser context
- *
- * Get the last parsing error registered.
- *
- * Returns NULL if no error occurred or a pointer to the error
- */
-const xmlError *
-xmlCtxtGetLastError(void *ctx)
-{
-    xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
-
-    if (ctxt == NULL)
-        return (NULL);
-    if (ctxt->lastError.code == XML_ERR_OK)
-        return (NULL);
-    return (&ctxt->lastError);
-}
-
-/**
- * xmlCtxtResetLastError:
- * @ctx:  an XML parser context
- *
- * Cleanup the last global error registered. For parsing error
- * this does not change the well-formedness result.
- */
-void
-xmlCtxtResetLastError(void *ctx)
-{
-    xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
-
-    if (ctxt == NULL)
-        return;
-    ctxt->errNo = XML_ERR_OK;
-    if (ctxt->lastError.code == XML_ERR_OK)
-        return;
-    xmlResetError(&ctxt->lastError);
+    if (error->code != XML_ERR_OK)
+        xmlResetError(error);
 }
 
 /**
@@ -1366,3 +1341,49 @@ xmlErrString(xmlParserErrors code) {
 
     return(errmsg);
 }
+
+/**
+ * xmlVPrintErrorMessage:
+ * @fmt:  printf format string
+ * @ap:  arguments
+ *
+ * Prints to stderr.
+ */
+void
+xmlVPrintErrorMessage(const char *fmt, va_list ap) {
+    vfprintf(stderr, fmt, ap);
+}
+
+/**
+ * xmlPrintErrorMessage:
+ * @fmt:  printf format string
+ * @...:  arguments
+ *
+ * Prints to stderr.
+ */
+void
+xmlPrintErrorMessage(const char *fmt, ...) {
+    va_list ap;
+
+    va_start(ap, fmt);
+    xmlVPrintErrorMessage(fmt, ap);
+    va_end(ap);
+}
+
+/**
+ * xmlAbort:
+ * @fmt:  printf format string
+ * @...:  arguments
+ *
+ * Print message to stderr and abort.
+ */
+void
+xmlAbort(const char *fmt, ...) {
+    va_list ap;
+
+    va_start(ap, fmt);
+    xmlVPrintErrorMessage(fmt, ap);
+    va_end(ap);
+
+    abort();
+}
