@@ -54,7 +54,7 @@ xmlStrndup(const xmlChar *cur, int len) {
     xmlChar *ret;
 
     if ((cur == NULL) || (len < 0)) return(NULL);
-    ret = (xmlChar *) xmlMallocAtomic((size_t) len + 1);
+    ret = xmlMalloc((size_t) len + 1);
     if (ret == NULL) {
         return(NULL);
     }
@@ -98,7 +98,7 @@ xmlCharStrndup(const char *cur, int len) {
     xmlChar *ret;
 
     if ((cur == NULL) || (len < 0)) return(NULL);
-    ret = (xmlChar *) xmlMallocAtomic((size_t) len + 1);
+    ret = xmlMalloc((size_t) len + 1);
     if (ret == NULL) {
         return(NULL);
     }
@@ -460,7 +460,7 @@ xmlStrncat(xmlChar *cur, const xmlChar *add, int len) {
     if ((add == NULL) || (len == 0))
         return(cur);
     if (len < 0)
-    return(NULL);
+        return(NULL);
     if (cur == NULL)
         return(xmlStrndup(add, len));
 
@@ -908,7 +908,7 @@ xmlGetUTF8Char(const unsigned char *utf, int *len) {
 
 error:
     if (len != NULL)
-    *len = 0;
+        *len = 0;
     return(-1);
 }
 
@@ -943,25 +943,25 @@ xmlCheckUTF8(const unsigned char *utf)
      */
     while ((c = utf[0])) {      /* string is 0-terminated */
         ix = 0;
-        if ((c & 0x80) == 0x00) {    /* 1-byte code, starts with 10 */
+        if ((c & 0x80) == 0x00) {       /* 1-byte code, starts with 10 */
             ix = 1;
-    } else if ((c & 0xe0) == 0xc0) {/* 2-byte code, starts with 110 */
-        if ((utf[1] & 0xc0 ) != 0x80)
+        } else if ((c & 0xe0) == 0xc0) {/* 2-byte code, starts with 110 */
+            if ((utf[1] & 0xc0 ) != 0x80)
+                return 0;
+            ix = 2;
+        } else if ((c & 0xf0) == 0xe0) {/* 3-byte code, starts with 1110 */
+            if (((utf[1] & 0xc0) != 0x80) ||
+                ((utf[2] & 0xc0) != 0x80))
+                    return 0;
+            ix = 3;
+        } else if ((c & 0xf8) == 0xf0) {/* 4-byte code, starts with 11110 */
+            if (((utf[1] & 0xc0) != 0x80) ||
+                ((utf[2] & 0xc0) != 0x80) ||
+                ((utf[3] & 0xc0) != 0x80))
+                    return 0;
+            ix = 4;
+        } else                          /* unknown encoding */
             return 0;
-        ix = 2;
-    } else if ((c & 0xf0) == 0xe0) {/* 3-byte code, starts with 1110 */
-        if (((utf[1] & 0xc0) != 0x80) ||
-            ((utf[2] & 0xc0) != 0x80))
-            return 0;
-        ix = 3;
-    } else if ((c & 0xf8) == 0xf0) {/* 4-byte code, starts with 11110 */
-        if (((utf[1] & 0xc0) != 0x80) ||
-            ((utf[2] & 0xc0) != 0x80) ||
-        ((utf[3] & 0xc0) != 0x80))
-            return 0;
-        ix = 4;
-    } else                /* unknown encoding */
-        return 0;
         utf += ix;
       }
       return(1);
@@ -994,11 +994,12 @@ xmlUTF8Strsize(const xmlChar *utf, int len) {
     while ( len-- > 0) {
         if ( !*ptr )
             break;
-        if ( (ch = *ptr++) & 0x80)
+        ch = *ptr++;
+        if ((ch & 0x80))
             while ((ch<<=1) & 0x80 ) {
-        if (*ptr == 0) break;
+                if (*ptr == 0) break;
                 ptr++;
-        }
+            }
     }
     ret = ptr - utf;
     return (ret > INT_MAX ? 0 : ret);
@@ -1021,7 +1022,7 @@ xmlUTF8Strndup(const xmlChar *utf, int len) {
 
     if ((utf == NULL) || (len < 0)) return(NULL);
     i = xmlUTF8Strsize(utf, len);
-    ret = (xmlChar *) xmlMallocAtomic((size_t) i + 1);
+    ret = xmlMalloc((size_t) i + 1);
     if (ret == NULL) {
         return(NULL);
     }
@@ -1048,7 +1049,9 @@ xmlUTF8Strpos(const xmlChar *utf, int pos) {
     if (pos < 0)
         return(NULL);
     while (pos--) {
-        if ((ch=*utf++) == 0) return(NULL);
+        ch = *utf++;
+        if (ch == 0)
+            return(NULL);
         if ( ch & 0x80 ) {
             /* if not simple ascii, verify proper format */
             if ( (ch & 0xc0) != 0xc0 )
@@ -1175,7 +1178,7 @@ xmlEscapeFormatString(xmlChar **msg)
     if ((count > INT_MAX) || (msgLen > INT_MAX - count))
         return(NULL);
     resultLen = msgLen + count + 1;
-    result = (xmlChar *) xmlMallocAtomic(resultLen);
+    result = xmlMalloc(resultLen);
     if (result == NULL) {
         /* Clear *msg to prevent format string vulnerabilities in
            out-of-memory situations. */
