@@ -34,6 +34,7 @@
 #include "numbersInternals.h"
 #include "keys.h"
 #include "documents.h"
+#include "transformInternals.h"
 
 #ifdef WITH_XSLT_DEBUG
 #define WITH_XSLT_DEBUG_FUNCTION
@@ -125,7 +126,20 @@ xsltDocumentFunctionLoadDocument(xmlXPathParserContextPtr ctxt,
         /*
         * This selects the stylesheet's doc itself.
         */
-        doc = tctxt->style->doc;
+    doc = xmlCopyDoc(tctxt->style->doc, 1);
+    if (doc == NULL) {
+        xsltTransformError(tctxt, NULL, NULL,
+            "document() : failed to copy style doc\n");
+        goto out_fragment;
+    }
+    xsltCleanupSourceDoc(doc); /* Remove psvi fields. */
+    idoc = xsltNewDocument(tctxt, doc);
+    if (idoc == NULL) {
+        xsltTransformError(tctxt, NULL, NULL,
+            "document() : failed to create xsltDocument\n");
+        xmlFreeDoc(doc);
+        goto out_fragment;
+        }
     } else {
             goto out_fragment;
     }
