@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -33,16 +33,16 @@ import com.sun.webkit.WebPage;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Random;
-import org.junit.After;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.Ignore;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Disabled;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
-@Ignore("JDK-8290292")
+@Disabled("JDK-8290292")
 public class SharedBufferTest {
 
     private static final int SEGMENT_SIZE = 0x1000;
@@ -52,7 +52,7 @@ public class SharedBufferTest {
     private SharedBuffer sb = SharedBufferShim.createSharedBuffer();
 
 
-    @BeforeClass
+    @BeforeAll
     public static void beforeClass() throws ClassNotFoundException {
         if (PlatformUtil.isWindows()) {
             // Must load Microsoft libs before loading jfxwebkit.dll
@@ -458,7 +458,7 @@ public class SharedBufferTest {
     }
 
 
-    @After
+    @AfterEach
     public void after() {
         if (sb != null) {
             SharedBufferShim.dispose(sb);
@@ -484,7 +484,7 @@ public class SharedBufferTest {
         int extraLength = random.nextBoolean() ? random.nextInt(200) : 0;
         byte[] buffer = g(0, offset + length + extraLength);
         int len = SharedBufferShim.getSomeData(sb, (long) position, buffer, offset, length);
-        assertTrue("Unexpected len: " + len, len >= 0);
+        assertTrue(len >= 0, "Unexpected len: " + len);
         for (int i = 0; i < offset; i++) {
             assertEquals((byte) (i & 0xff), buffer[i]);
         }
