@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,13 +26,11 @@
 package test.javafx.scene.web;
 
 import static javafx.concurrent.Worker.State.SUCCEEDED;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.atomic.AtomicReference;
-
 import javafx.application.Application;
 import javafx.application.Platform;
 import javafx.event.Event;
@@ -45,15 +43,12 @@ import javafx.scene.text.Font;
 import javafx.scene.web.HTMLEditor;
 import javafx.scene.web.WebView;
 import javafx.stage.Stage;
-
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
-import org.junit.Test;
-
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import com.sun.javafx.PlatformUtil;
-
 import test.com.sun.javafx.scene.control.infrastructure.KeyEventFirer;
 import test.com.sun.javafx.scene.control.infrastructure.KeyModifier;
 import test.util.Util;
@@ -94,17 +89,17 @@ public class HTMLEditorTest {
         }
     }
 
-    @BeforeClass
+    @BeforeAll
     public static void setupOnce() {
         Util.launch(launchLatch, HTMLEditorTestApp.class);
     }
 
-    @AfterClass
+    @AfterAll
     public static void tearDownOnce() {
         Util.shutdown();
     }
 
-    @Before
+    @BeforeEach
     public void setupTestObjects() {
         Platform.runLater(() -> {
             htmlEditor = new HTMLEditor();
@@ -128,7 +123,8 @@ public class HTMLEditorTest {
     // Currently ignoring this test case due to regression (JDK-8200418).
     // The newly cloned issue (JDK-8202542) needs to be fixed before
     // re-enabling this test case.
-    @Test @Ignore("JDK-8202542")
+    @Test
+    @Disabled("JDK-8202542")
     public void checkFocusChange() throws Exception {
         final CountDownLatch editorStateLatch = new CountDownLatch(1);
         final AtomicReference<String> result = new AtomicReference<>();
@@ -169,8 +165,8 @@ public class HTMLEditorTest {
 
         });
 
-        assertTrue("Timeout when waiting for focus change ", Util.await(editorStateLatch));
-        assertEquals("Focus Change with design mode enabled ", "red", result.get());
+        assertTrue(Util.await(editorStateLatch), "Timeout when waiting for focus change ");
+        assertEquals("red", result.get(), "Focus Change with design mode enabled ");
     }
 
     /**
@@ -219,7 +215,7 @@ public class HTMLEditorTest {
 
         });
 
-        assertTrue("Timeout when waiting for focus change ", Util.await(editorStateLatch));
+        assertTrue(Util.await(editorStateLatch), "Timeout when waiting for focus change ");
 
         Util.runAndWait(() -> {
             webView.getEngine().executeScript("document.body.focus();");
@@ -302,9 +298,9 @@ public class HTMLEditorTest {
 
         });
 
-        assertTrue("Timeout when waiting for focus change ", Util.await(editorStateLatch));
+        assertTrue(Util.await(editorStateLatch), "Timeout when waiting for focus change ");
         assertNotNull("result must have a valid reference ", result.get());
-        assertEquals("document.body.style.fontWeight must be bold ", "bold", result.get());
+        assertEquals("bold", result.get(), "document.body.style.fontWeight must be bold ");
     }
 
     /**
@@ -335,11 +331,13 @@ public class HTMLEditorTest {
                     for (Node comboBox : htmlEditor.lookupAll(".font-menu-button")) {
                         // 0 - Format, 1 - Font Family, 2 - Font Size
                         if (i == 1) {
-                            assertTrue("fontFamilyComboBox must be ComboBox",
-                                comboBox instanceof ComboBox);
+                            assertTrue(
+                                comboBox instanceof ComboBox,
+                                "fontFamilyComboBox must be ComboBox");
                             fontFamilyComboBox = (ComboBox<String>) comboBox;
-                            assertNotNull("fontFamilyComboBox must not be null",
-                                fontFamilyComboBox);
+                            assertNotNull(
+                                fontFamilyComboBox,
+                                "fontFamilyComboBox must not be null");
                         }
                         i++;
                     }
@@ -352,10 +350,9 @@ public class HTMLEditorTest {
             });
         });
 
-        assertTrue("Timeout when waiting for focus change ", Util.await(editorStateLatch));
-        assertNotNull("result must have a valid reference ", result.get());
-        assertTrue("font-family must be 'WebKit Layout Test 2' ", result.get().
-            contains("font-family: &quot;WebKit Layout Tests 2&quot;"));
+        assertTrue(Util.await(editorStateLatch), "Timeout when waiting for focus change ");
+        assertNotNull(result.get(), "result must have a valid reference ");
+        assertTrue(result.get().contains("font-family: &quot;WebKit Layout Tests 2&quot;"), "font-family must be 'WebKit Layout Test 2' ");
     }
 
     /**
@@ -395,7 +392,7 @@ public class HTMLEditorTest {
             });
         });
 
-        assertTrue("Timeout while waiting for test html text setup", Util.await(editorStateLatch));
+        assertTrue(Util.await(editorStateLatch), "Timeout while waiting for test html text setup");
 
         String expectedHtmlText = htmlEditor.getHtmlText();
 
@@ -409,7 +406,7 @@ public class HTMLEditorTest {
 
         String actualHtmlText = htmlEditor.getHtmlText();
 
-        assertEquals("Expected and Actual HTML text does not match. ", expectedHtmlText, actualHtmlText);
+        assertEquals(expectedHtmlText, actualHtmlText, "Expected and Actual HTML text does not match. ");
     }
 
 
@@ -445,7 +442,7 @@ public class HTMLEditorTest {
             });
         });
 
-        assertTrue("Timeout while waiting for test html text setup", Util.await(editorStateLatch));
+        assertTrue(Util.await(editorStateLatch), "Timeout while waiting for test html text setup");
 
         String expectedHtmlText = htmlEditor.getHtmlText();
 
@@ -459,6 +456,6 @@ public class HTMLEditorTest {
 
         String actualHtmlText = htmlEditor.getHtmlText();
 
-        assertEquals("Expected and Actual HTML text does not match. ", expectedHtmlText, actualHtmlText);
+        assertEquals(expectedHtmlText, actualHtmlText, "Expected and Actual HTML text does not match. ");
     }
 }
