@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,15 +24,13 @@
 
 package test.robot.javafx.scene.layout;
 
-import static org.junit.Assume.assumeTrue;
-
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+import java.util.concurrent.TimeUnit;
 import javafx.geometry.Bounds;
 import javafx.scene.paint.Color;
-
-import org.junit.Ignore;
-import org.junit.Test;
-
-import com.sun.javafx.PlatformUtil;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 
 /**************************************************************************
  *                                                                        *
@@ -40,9 +38,10 @@ import com.sun.javafx.PlatformUtil;
  * to align naturally with the edge of the test region.                   *
  *                                                                        *
  *************************************************************************/
+@Timeout(value=20000, unit=TimeUnit.MILLISECONDS)
 public class RegionBackgroundImageUITest extends RegionUITestBase {
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -51,7 +50,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkCompletelyFilled(20);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_RepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -61,7 +60,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongTop(20, LEFT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_RepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -71,7 +70,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongLeft(20, TOP);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_Space() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -81,7 +80,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkCompletelyFilled(20);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_Round() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -91,7 +90,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkCompletelyFilled(20);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_RoundSpace() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -101,7 +100,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkCompletelyFilled(20);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenter() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -111,7 +110,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(20, WIDTH / 2, HEIGHT / 2, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterFiftyPercent() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -121,7 +120,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(20, WIDTH / 2, HEIGHT / 2, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterLeft() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -134,7 +133,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         assertColorEquals(SCENE_FILL, centerX - 11, HEIGHT / 2, TOLERANCE);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterRight() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -147,7 +146,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         assertColorEquals(SCENE_FILL, centerX + 10, HEIGHT / 2, TOLERANCE);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterTop() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -160,7 +159,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         assertColorEquals(SCENE_FILL, WIDTH / 2, centerY - 11, TOLERANCE);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterBottom() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -174,7 +173,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         assertColorEquals(SCENE_FILL, WIDTH / 2, centerY + 10, TOLERANCE);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionBottomRight() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -191,7 +190,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         assertColorEquals(SCENE_FILL, centerX, centerY + 10, TOLERANCE);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -201,7 +200,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterFiftyPercentRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -211,7 +210,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterLeftRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -221,7 +220,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(20, LEFT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterRightRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -230,7 +229,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(20, LEFT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterTopRepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -241,7 +240,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongTop(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterBottomRepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -252,7 +251,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongBottom(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionBottomRightRepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -263,7 +262,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongBottom(20, LEFT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -274,7 +273,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterFiftyPercentRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -285,7 +284,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterLeftRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -296,7 +295,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongLeft(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterRightRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -307,7 +306,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongRight(20, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterTopRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -318,7 +317,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(20, TOP);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionCenterBottomRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -329,7 +328,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(20, TOP);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_PositionBottomRightRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -340,7 +339,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongRight(20, TOP);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_Position25PercentLeft() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -353,7 +352,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
                 (REGION_TOP +  (int) (.5 * REGION_HEIGHT)), true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_Position25PercentRight() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -369,7 +368,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
     // TODO should do from the top & bottom
 
     // TODO should test that cover causes other properties to be ignored
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_Cover() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -380,7 +379,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
     }
 
     // TODO should test that contain causes other properties to be ignored
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_Contain() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -392,7 +391,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(200, REGION_LEFT + 300, REGION_TOP + 100, false);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void alignedImage_ContainNoRepeat() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test20x20.png');" +
@@ -402,7 +401,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(200, REGION_LEFT + 100, REGION_TOP + 100, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -410,7 +409,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkCompletelyFilled(48);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_RepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -420,7 +419,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongTop(48, LEFT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_RepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -430,8 +429,8 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongLeft(48, TOP);
     }
 
-    @Ignore("RT-33411: Doesn't work at present because of Prism bug where the gaps between rows are inconsistent")
-    @Test(timeout = 20000)
+    @Disabled("JDK-8088544: Doesn't work at present because of Prism bug where the gaps between rows are inconsistent")
+    @Test
     public void unalignedImage_Space() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -440,7 +439,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkEvenlyFilled(48);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_Round() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -450,8 +449,8 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkCompletelyFilled(50); // rounded up from 48 to 50
     }
 
-    @Ignore("RT-33411: Doesn't work at present because of Prism bug where the gaps between rows are inconsistent")
-    @Test(timeout = 20000)
+    @Disabled("JDK-8088544: Doesn't work at present because of Prism bug where the gaps between rows are inconsistent")
+    @Test
     public void unalignedImage_RoundSpace() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -461,7 +460,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         // even in one dimension and spaced in the other
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenter() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -470,7 +469,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, WIDTH / 2, HEIGHT / 2, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterFiftyPercent() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -479,7 +478,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, WIDTH / 2, HEIGHT / 2, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterLeft() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -488,7 +487,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, REGION_LEFT + 24, HEIGHT / 2, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterRight() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -497,7 +496,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, REGION_RIGHT - 24, HEIGHT / 2, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterTop() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -506,7 +505,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, WIDTH / 2, REGION_TOP + 24, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterBottom() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -515,7 +514,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, WIDTH / 2, REGION_BOTTOM - 24, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionBottomRight() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -524,7 +523,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(48, REGION_RIGHT - 24, REGION_BOTTOM - 24, true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -534,7 +533,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterFiftyPercentRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -544,7 +543,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterLeftRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -554,7 +553,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(48, LEFT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterRightRepeatX() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -564,7 +563,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongCenter(48, RIGHT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterTopRepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -575,7 +574,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongTop(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterBottomRepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -586,7 +585,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongBottom(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionBottomRightRepeatX() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -597,7 +596,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkHorizontalStripAlongBottom(48, RIGHT);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -608,7 +607,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterFiftyPercentRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -619,7 +618,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterLeftRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -630,7 +629,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongLeft(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterRightRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -641,7 +640,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongRight(48, CENTER);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterTopRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -652,7 +651,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(48, TOP);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionCenterBottomRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -663,7 +662,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongCenter(48, BOTTOM);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_PositionBottomRightRepeatY() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -674,7 +673,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkVerticalStripAlongRight(48, BOTTOM);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_Position25PercentLeft() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -687,7 +686,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
                 (REGION_TOP +  (int) (.5 * REGION_HEIGHT)), true);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_Position25PercentRight() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -704,10 +703,9 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
 
     // TODO should test that cover causes other properties to be ignored
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_Cover() {
         assumeTrue(checkIntegralUIScale());
-        assumeTrue(!PlatformUtil.isMac()); // JDK-8255679
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
                 "-fx-background-size: cover;");
@@ -717,7 +715,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
     }
 
     // TODO should test that contain causes other properties to be ignored
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_Contain() {
         assumeTrue(checkIntegralUIScale());
         setStyle("-fx-background-color: black;" +
@@ -729,7 +727,7 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
         checkNonRepeating(200, REGION_LEFT + 300, REGION_TOP + 100, false);
     }
 
-    @Test(timeout = 20000)
+    @Test
     public void unalignedImage_ContainNoRepeat() {
         setStyle("-fx-background-color: black;" +
                 "-fx-background-image: url('test/robot/javafx/scene/layout/test48x48.png');" +
@@ -1056,13 +1054,14 @@ public class RegionBackgroundImageUITest extends RegionUITestBase {
 
     private void checkNonRepeating(int size, int centerX, int centerY, boolean checkForBlack) {
         final int halfSize = size / 2;
-        final int quarterSize = size / 4;
+        final int redCenterDelta = (int)(size / 2.2f);
+        final int greenCenterDelta = (int)(size / 3.3f);
         // The image
-        int x = centerX - halfSize;
-        int y = centerY - halfSize;
+        int x = centerX - redCenterDelta;
+        int y = centerY - redCenterDelta;
         assertColorEquals(contains(x, y) ? Color.RED : SCENE_FILL, x, y, TOLERANCE);
-        x = centerX - quarterSize;
-        y = centerY - quarterSize;
+        x = centerX - greenCenterDelta;
+        y = centerY - greenCenterDelta;
         assertColorEquals(contains(x, y) ? Color.rgb(0, 255, 0) : SCENE_FILL, x, y, TOLERANCE);
         x = centerX;
         y = centerY;
